pub enum Cow<'a, B>{
Borrowed(&'a B),
Owned(<B as ToOwned>::Owned),
}alloc only.Expand description
🫗 🍃 💱
alloc
A clone-on-write smart pointer.
📍sys/mem re-exported from alloc::borrow
📜
A clone-on-write smart pointer.
The type Cow is a smart pointer providing clone-on-write functionality: it
can enclose and provide immutable access to borrowed data, and clone the
data lazily when mutation or ownership is required. The type is designed to
work with general borrowed data via the Borrow trait.
Cow implements Deref, which means that you can call
non-mutating methods directly on the data it encloses. If mutation
is desired, to_mut will obtain a mutable reference to an owned
value, cloning if necessary.
If you need reference-counting pointers, note that
Rc::make_mut and
Arc::make_mut can provide clone-on-write
functionality as well.
Examples
use std::borrow::Cow;
fn abs_all(input: &mut Cow<'_, [i32]>) {
for i in 0..input.len() {
let v = input[i];
if v < 0 {
// Clones into a vector if not already owned.
input.to_mut()[i] = -v;
}
}
}
// No clone occurs because `input` doesn't need to be mutated.
let slice = [0, 1, 2];
let mut input = Cow::from(&slice[..]);
abs_all(&mut input);
// Clone occurs because `input` needs to be mutated.
let slice = [-1, 0, 1];
let mut input = Cow::from(&slice[..]);
abs_all(&mut input);
// No clone occurs because `input` is already owned.
let mut input = Cow::from(vec![-1, 0, 1]);
abs_all(&mut input);Another example showing how to keep Cow in a struct:
use std::borrow::Cow;
struct Items<'a, X> where [X]: ToOwned<Owned = Vec<X>> {
values: Cow<'a, [X]>,
}
impl<'a, X: Clone + 'a> Items<'a, X> where [X]: ToOwned<Owned = Vec<X>> {
fn new(v: Cow<'a, [X]>) -> Self {
Items { values: v }
}
}
// Creates a container from borrowed values of a slice
let readonly = [1, 2];
let borrowed = Items::new((&readonly[..]).into());
match borrowed {
Items { values: Cow::Borrowed(b) } => println!("borrowed {b:?}"),
_ => panic!("expect borrowed value"),
}
let mut clone_on_write = borrowed;
// Mutates the data from slice into owned vec and pushes a new value on top
clone_on_write.values.to_mut().push(3);
println!("clone_on_write = {:?}", clone_on_write.values);
// The data was mutated. Let's check it out.
match clone_on_write {
Items { values: Cow::Owned(_) } => println!("clone_on_write contains owned data"),
_ => panic!("expect owned data"),
}Variants
Implementations
Sourceimpl<B> Cow<'_, B>
impl<B> Cow<'_, B>
Sourcepub const fn is_borrowed(c: &Cow<'_, B>) -> bool
🔬This is a nightly-only experimental API. (cow_is_borrowed)
pub const fn is_borrowed(c: &Cow<'_, B>) -> bool
cow_is_borrowed)Returns true if the data is borrowed, i.e. if to_mut would require additional work.
Note: this is an associated function, which means that you have to call
it as Cow::is_borrowed(&c) instead of c.is_borrowed(). This is so
that there is no conflict with a method on the inner type.
Examples
#![feature(cow_is_borrowed)]
use std::borrow::Cow;
let cow = Cow::Borrowed("moo");
assert!(Cow::is_borrowed(&cow));
let bull: Cow<'_, str> = Cow::Owned("...moo?".to_string());
assert!(!Cow::is_borrowed(&bull));Sourcepub const fn is_owned(c: &Cow<'_, B>) -> bool
🔬This is a nightly-only experimental API. (cow_is_borrowed)
pub const fn is_owned(c: &Cow<'_, B>) -> bool
cow_is_borrowed)Returns true if the data is owned, i.e. if to_mut would be a no-op.
Note: this is an associated function, which means that you have to call
it as Cow::is_owned(&c) instead of c.is_owned(). This is so that
there is no conflict with a method on the inner type.
Examples
#![feature(cow_is_borrowed)]
use std::borrow::Cow;
let cow: Cow<'_, str> = Cow::Owned("moo".to_string());
assert!(Cow::is_owned(&cow));
let bull = Cow::Borrowed("...moo?");
assert!(!Cow::is_owned(&bull));1.0.0 · Sourcepub fn to_mut(&mut self) -> &mut <B as ToOwned>::Owned
pub fn to_mut(&mut self) -> &mut <B as ToOwned>::Owned
Acquires a mutable reference to the owned form of the data.
Clones the data if it is not already owned.
Examples
use std::borrow::Cow;
let mut cow = Cow::Borrowed("foo");
cow.to_mut().make_ascii_uppercase();
assert_eq!(
cow,
Cow::Owned(String::from("FOO")) as Cow<'_, str>
);1.0.0 · Sourcepub fn into_owned(self) -> <B as ToOwned>::Owned
pub fn into_owned(self) -> <B as ToOwned>::Owned
Extracts the owned data.
Clones the data if it is not already owned.
Examples
Calling into_owned on a Cow::Borrowed returns a clone of the borrowed data:
use std::borrow::Cow;
let s = "Hello world!";
let cow = Cow::Borrowed(s);
assert_eq!(
cow.into_owned(),
String::from(s)
);Calling into_owned on a Cow::Owned returns the owned data. The data is moved out of the
Cow without being cloned.
use std::borrow::Cow;
let s = "Hello world!";
let cow: Cow<'_, str> = Cow::Owned(String::from(s));
assert_eq!(
cow.into_owned(),
String::from(s)
);Trait Implementations
1.14.0 · Sourceimpl<'a> AddAssign<&'a str> for Cow<'a, str>
Available on non-no_global_oom_handling only.
impl<'a> AddAssign<&'a str> for Cow<'a, str>
no_global_oom_handling only.Sourcefn add_assign(&mut self, rhs: &'a str)
fn add_assign(&mut self, rhs: &'a str)
+= operation. Read moreimpl<T> DerefPure for Cow<'_, T>where
T: Clone,
impl DerefPure for Cow<'_, str>
no_global_oom_handling only.impl<T> DerefPure for Cow<'_, [T]>where
T: Clone,
no_global_oom_handling only.impl<B> Eq for Cow<'_, B>
1.52.0 · Sourceimpl<'a> Extend<Cow<'a, OsStr>> for OsString
impl<'a> Extend<Cow<'a, OsStr>> for OsString
Sourcefn extend<T>(&mut self, iter: T)
fn extend<T>(&mut self, iter: T)
Sourcefn extend_one(&mut self, item: A)
fn extend_one(&mut self, item: A)
extend_one)Sourcefn extend_reserve(&mut self, additional: usize)
fn extend_reserve(&mut self, additional: usize)
extend_one)1.19.0 · Sourceimpl<'a> Extend<Cow<'a, str>> for String
Available on non-no_global_oom_handling only.
impl<'a> Extend<Cow<'a, str>> for String
no_global_oom_handling only.Sourcefn extend<I>(&mut self, iter: I)
fn extend<I>(&mut self, iter: I)
Sourcefn extend_one(&mut self, s: Cow<'a, str>)
fn extend_one(&mut self, s: Cow<'a, str>)
extend_one)Sourcefn extend_reserve(&mut self, additional: usize)
fn extend_reserve(&mut self, additional: usize)
extend_one)1.28.0 · Sourceimpl<'a> From<&'a String> for Cow<'a, str>
Available on non-no_global_oom_handling only.
impl<'a> From<&'a String> for Cow<'a, str>
no_global_oom_handling only.1.45.0 · Sourceimpl<T> From<Cow<'_, [T]>> for Box<[T]>where
T: Clone,
Available on non-no_global_oom_handling only.
impl<T> From<Cow<'_, [T]>> for Box<[T]>where
T: Clone,
no_global_oom_handling only.1.45.0 · Sourceimpl From<Cow<'_, str>> for Box<str>
Available on non-no_global_oom_handling only.
impl From<Cow<'_, str>> for Box<str>
no_global_oom_handling only.Sourcefn from(cow: Cow<'_, str>) -> Box<str>
fn from(cow: Cow<'_, str>) -> Box<str>
Converts a Cow<'_, str> into a Box<str>
When cow is the Cow::Borrowed variant, this
conversion allocates on the heap and copies the
underlying str. Otherwise, it will try to reuse the owned
String’s allocation.
Examples
use std::borrow::Cow;
let unboxed = Cow::Borrowed("hello");
let boxed: Box<str> = Box::from(unboxed);
println!("{boxed}");let unboxed = Cow::Owned("hello".to_string());
let boxed: Box<str> = Box::from(unboxed);
println!("{boxed}");impl<'a, B> From<Cow<'a, B>> for Arc<B>
impl<'a, B> From<Cow<'a, B>> for Arc<B>
fn from(cow: Cow<'a, B>) -> Arc<B>
fn from(cow: Cow<'a, B>) -> Arc<B>
Creates an atomically reference-counted pointer from a clone-on-write pointer by copying its content.
Example
use std::borrow::Cow;
use portable_atomic_util::Arc;
let cow: Cow<'_, str> = Cow::Borrowed("eggplant");
let shared: Arc<str> = Arc::from(cow);
assert_eq!("eggplant", &shared[..]);1.14.0 · Sourceimpl<'a, T> From<Cow<'a, [T]>> for Vec<T>
impl<'a, T> From<Cow<'a, [T]>> for Vec<T>
Sourcefn from(s: Cow<'a, [T]>) -> Vec<T> ⓘ
fn from(s: Cow<'a, [T]>) -> Vec<T> ⓘ
Converts a clone-on-write slice into a vector.
If s already owns a Vec<T>, it will be returned directly.
If s is borrowing a slice, a new Vec<T> will be allocated and
filled by cloning s’s items into it.
Examples
let o: Cow<'_, [i32]> = Cow::Owned(vec![1, 2, 3]);
let b: Cow<'_, [i32]> = Cow::Borrowed(&[1, 2, 3]);
assert_eq!(Vec::from(o), Vec::from(b));1.14.0 · Sourceimpl<'a> From<Cow<'a, str>> for String
Available on non-no_global_oom_handling only.
impl<'a> From<Cow<'a, str>> for String
no_global_oom_handling only.Sourcefn from(s: Cow<'a, str>) -> String ⓘ
fn from(s: Cow<'a, str>) -> String ⓘ
Converts a clone-on-write string to an owned
instance of String.
This extracts the owned string, clones the string if it is not already owned.
Example
// If the string is not owned...
let cow: Cow<'_, str> = Cow::Borrowed("eggplant");
// It will allocate on the heap and copy the string.
let owned: String = String::from(cow);
assert_eq!(&owned[..], "eggplant");1.22.0 · Sourceimpl<'a, 'b> From<Cow<'b, str>> for Box<dyn Error + Send + Sync + 'a>
Available on non-no_global_oom_handling only.
impl<'a, 'b> From<Cow<'b, str>> for Box<dyn Error + Send + Sync + 'a>
no_global_oom_handling only.Sourcefn from(err: Cow<'b, str>) -> Box<dyn Error + Send + Sync + 'a>
fn from(err: Cow<'b, str>) -> Box<dyn Error + Send + Sync + 'a>
Converts a Cow into a box of dyn Error + Send + Sync.
Examples
use std::error::Error;
use std::borrow::Cow;
let a_cow_str_error = Cow::from("a str error");
let a_boxed_error = Box::<dyn Error + Send + Sync>::from(a_cow_str_error);
assert!(
size_of::<Box<dyn Error + Send + Sync>>() == size_of_val(&a_boxed_error))1.22.0 · Sourceimpl<'a, 'b> From<Cow<'b, str>> for Box<dyn Error + 'a>
Available on non-no_global_oom_handling only.
impl<'a, 'b> From<Cow<'b, str>> for Box<dyn Error + 'a>
no_global_oom_handling only.1.12.0 · Sourceimpl<'a, 'b> FromIterator<&'b str> for Cow<'a, str>
Available on non-no_global_oom_handling only.
impl<'a, 'b> FromIterator<&'b str> for Cow<'a, str>
no_global_oom_handling only.Sourceimpl<'a> FromIterator<AsciiChar> for Cow<'a, str>
Available on non-no_global_oom_handling only.
impl<'a> FromIterator<AsciiChar> for Cow<'a, str>
no_global_oom_handling only.1.80.0 · Sourceimpl<'a> FromIterator<Cow<'a, str>> for Box<str>
Available on non-no_global_oom_handling only.
impl<'a> FromIterator<Cow<'a, str>> for Box<str>
no_global_oom_handling only.1.19.0 · Sourceimpl<'a> FromIterator<Cow<'a, str>> for String
Available on non-no_global_oom_handling only.
impl<'a> FromIterator<Cow<'a, str>> for String
no_global_oom_handling only.1.12.0 · Sourceimpl<'a> FromIterator<String> for Cow<'a, str>
Available on non-no_global_oom_handling only.
impl<'a> FromIterator<String> for Cow<'a, str>
no_global_oom_handling only.1.12.0 · Sourceimpl<'a> FromIterator<char> for Cow<'a, str>
Available on non-no_global_oom_handling only.
impl<'a> FromIterator<char> for Cow<'a, str>
no_global_oom_handling only.1.0.0 · Sourceimpl<B> Ord for Cow<'_, B>
impl<B> Ord for Cow<'_, B>
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
1.90.0 · Sourceimpl PartialEq<&CStr> for Cow<'_, CStr>
Available on non-no_global_oom_handling only.
impl PartialEq<&CStr> for Cow<'_, CStr>
no_global_oom_handling only.Sourceimpl PartialEq<ByteString> for Cow<'_, ByteStr>
impl PartialEq<ByteString> for Cow<'_, ByteStr>
Sourcefn eq(&self, other: &ByteString) -> bool
fn eq(&self, other: &ByteString) -> bool
self and other values to be equal, and is used by ==.Sourceimpl PartialEq<ByteString> for Cow<'_, str>
impl PartialEq<ByteString> for Cow<'_, str>
Sourcefn eq(&self, other: &ByteString) -> bool
fn eq(&self, other: &ByteString) -> bool
self and other values to be equal, and is used by ==.Sourceimpl PartialEq<ByteString> for Cow<'_, [u8]>
impl PartialEq<ByteString> for Cow<'_, [u8]>
Sourcefn eq(&self, other: &ByteString) -> bool
fn eq(&self, other: &ByteString) -> bool
self and other values to be equal, and is used by ==.1.90.0 · Sourceimpl PartialEq<CString> for Cow<'_, CStr>
Available on non-no_global_oom_handling only.
impl PartialEq<CString> for Cow<'_, CStr>
no_global_oom_handling only.Sourceimpl PartialEq<Cow<'_, ByteStr>> for ByteString
impl PartialEq<Cow<'_, ByteStr>> for ByteString
Sourceimpl PartialEq<Cow<'_, ByteStr>> for &ByteStr
impl PartialEq<Cow<'_, ByteStr>> for &ByteStr
1.90.0 · Sourceimpl PartialEq<Cow<'_, CStr>> for CString
Available on non-no_global_oom_handling only.
impl PartialEq<Cow<'_, CStr>> for CString
no_global_oom_handling only.1.8.0 · Sourceimpl PartialEq<Cow<'_, OsStr>> for OsStr
impl PartialEq<Cow<'_, OsStr>> for OsStr
1.8.0 · Sourceimpl PartialEq<Cow<'_, OsStr>> for &OsStr
impl PartialEq<Cow<'_, OsStr>> for &OsStr
1.8.0 · Sourceimpl PartialEq<Cow<'_, OsStr>> for OsString
impl PartialEq<Cow<'_, OsStr>> for OsString
1.8.0 · Sourceimpl PartialEq<Cow<'_, OsStr>> for PathBuf
impl PartialEq<Cow<'_, OsStr>> for PathBuf
1.8.0 · Sourceimpl PartialEq<Cow<'_, OsStr>> for Path
impl PartialEq<Cow<'_, OsStr>> for Path
1.8.0 · Sourceimpl PartialEq<Cow<'_, OsStr>> for &Path
impl PartialEq<Cow<'_, OsStr>> for &Path
1.6.0 · Sourceimpl PartialEq<Cow<'_, Path>> for Path
impl PartialEq<Cow<'_, Path>> for Path
1.6.0 · Sourceimpl PartialEq<Cow<'_, Path>> for &Path
impl PartialEq<Cow<'_, Path>> for &Path
1.6.0 · Sourceimpl PartialEq<Cow<'_, Path>> for PathBuf
impl PartialEq<Cow<'_, Path>> for PathBuf
1.8.0 · Sourceimpl PartialEq<Cow<'_, Path>> for OsStr
impl PartialEq<Cow<'_, Path>> for OsStr
1.8.0 · Sourceimpl PartialEq<Cow<'_, Path>> for &OsStr
impl PartialEq<Cow<'_, Path>> for &OsStr
1.8.0 · Sourceimpl PartialEq<Cow<'_, Path>> for OsString
impl PartialEq<Cow<'_, Path>> for OsString
Sourceimpl PartialEq<Cow<'_, [u8]>> for ByteString
impl PartialEq<Cow<'_, [u8]>> for ByteString
Sourceimpl PartialEq<Cow<'_, [u8]>> for &ByteStr
impl PartialEq<Cow<'_, [u8]>> for &ByteStr
Sourceimpl PartialEq<Cow<'_, str>> for ByteString
impl PartialEq<Cow<'_, str>> for ByteString
Sourceimpl PartialEq<Cow<'_, str>> for &ByteStr
impl PartialEq<Cow<'_, str>> for &ByteStr
1.0.0 · Sourceimpl<'a, 'b, B, C> PartialEq<Cow<'b, C>> for Cow<'a, B>
impl<'a, 'b, B, C> PartialEq<Cow<'b, C>> for Cow<'a, B>
1.0.0 · Sourceimpl<'a, B> PartialOrd for Cow<'a, B>
impl<'a, B> PartialOrd for Cow<'a, B>
Sourceimpl PartialOrd<&ByteStr> for Cow<'_, ByteStr>
impl PartialOrd<&ByteStr> for Cow<'_, ByteStr>
Sourceimpl PartialOrd<&ByteStr> for Cow<'_, str>
impl PartialOrd<&ByteStr> for Cow<'_, str>
Sourceimpl PartialOrd<&ByteStr> for Cow<'_, [u8]>
impl PartialOrd<&ByteStr> for Cow<'_, [u8]>
1.8.0 · Sourceimpl PartialOrd<&OsStr> for Cow<'_, OsStr>
impl PartialOrd<&OsStr> for Cow<'_, OsStr>
1.8.0 · Sourceimpl PartialOrd<&OsStr> for Cow<'_, Path>
impl PartialOrd<&OsStr> for Cow<'_, Path>
1.8.0 · Sourceimpl PartialOrd<&Path> for Cow<'_, Path>
impl PartialOrd<&Path> for Cow<'_, Path>
1.8.0 · Sourceimpl PartialOrd<&Path> for Cow<'_, OsStr>
impl PartialOrd<&Path> for Cow<'_, OsStr>
Sourceimpl PartialOrd<ByteString> for Cow<'_, ByteStr>
impl PartialOrd<ByteString> for Cow<'_, ByteStr>
Sourceimpl PartialOrd<ByteString> for Cow<'_, str>
impl PartialOrd<ByteString> for Cow<'_, str>
Sourceimpl PartialOrd<ByteString> for Cow<'_, [u8]>
impl PartialOrd<ByteString> for Cow<'_, [u8]>
Sourceimpl PartialOrd<Cow<'_, ByteStr>> for ByteString
impl PartialOrd<Cow<'_, ByteStr>> for ByteString
Sourceimpl PartialOrd<Cow<'_, ByteStr>> for &ByteStr
impl PartialOrd<Cow<'_, ByteStr>> for &ByteStr
1.8.0 · Sourceimpl PartialOrd<Cow<'_, OsStr>> for OsStr
impl PartialOrd<Cow<'_, OsStr>> for OsStr
1.8.0 · Sourceimpl PartialOrd<Cow<'_, OsStr>> for &OsStr
impl PartialOrd<Cow<'_, OsStr>> for &OsStr
1.8.0 · Sourceimpl PartialOrd<Cow<'_, OsStr>> for OsString
impl PartialOrd<Cow<'_, OsStr>> for OsString
1.8.0 · Sourceimpl PartialOrd<Cow<'_, OsStr>> for PathBuf
impl PartialOrd<Cow<'_, OsStr>> for PathBuf
1.8.0 · Sourceimpl PartialOrd<Cow<'_, OsStr>> for Path
impl PartialOrd<Cow<'_, OsStr>> for Path
1.8.0 · Sourceimpl PartialOrd<Cow<'_, OsStr>> for &Path
impl PartialOrd<Cow<'_, OsStr>> for &Path
1.8.0 · Sourceimpl PartialOrd<Cow<'_, Path>> for Path
impl PartialOrd<Cow<'_, Path>> for Path
1.8.0 · Sourceimpl PartialOrd<Cow<'_, Path>> for &Path
impl PartialOrd<Cow<'_, Path>> for &Path
1.8.0 · Sourceimpl PartialOrd<Cow<'_, Path>> for PathBuf
impl PartialOrd<Cow<'_, Path>> for PathBuf
1.8.0 · Sourceimpl PartialOrd<Cow<'_, Path>> for OsStr
impl PartialOrd<Cow<'_, Path>> for OsStr
1.8.0 · Sourceimpl PartialOrd<Cow<'_, Path>> for &OsStr
impl PartialOrd<Cow<'_, Path>> for &OsStr
1.8.0 · Sourceimpl PartialOrd<Cow<'_, Path>> for OsString
impl PartialOrd<Cow<'_, Path>> for OsString
Sourceimpl PartialOrd<Cow<'_, [u8]>> for ByteString
impl PartialOrd<Cow<'_, [u8]>> for ByteString
Sourceimpl PartialOrd<Cow<'_, [u8]>> for &ByteStr
impl PartialOrd<Cow<'_, [u8]>> for &ByteStr
Sourceimpl PartialOrd<Cow<'_, str>> for ByteString
impl PartialOrd<Cow<'_, str>> for ByteString
Sourceimpl PartialOrd<Cow<'_, str>> for &ByteStr
impl PartialOrd<Cow<'_, str>> for &ByteStr
1.8.0 · Sourceimpl PartialOrd<OsStr> for Cow<'_, OsStr>
impl PartialOrd<OsStr> for Cow<'_, OsStr>
1.8.0 · Sourceimpl PartialOrd<OsStr> for Cow<'_, Path>
impl PartialOrd<OsStr> for Cow<'_, Path>
1.8.0 · Sourceimpl PartialOrd<OsString> for Cow<'_, OsStr>
impl PartialOrd<OsString> for Cow<'_, OsStr>
1.8.0 · Sourceimpl PartialOrd<OsString> for Cow<'_, Path>
impl PartialOrd<OsString> for Cow<'_, Path>
1.8.0 · Sourceimpl PartialOrd<Path> for Cow<'_, Path>
impl PartialOrd<Path> for Cow<'_, Path>
1.8.0 · Sourceimpl PartialOrd<Path> for Cow<'_, OsStr>
impl PartialOrd<Path> for Cow<'_, OsStr>
1.8.0 · Sourceimpl PartialOrd<PathBuf> for Cow<'_, Path>
impl PartialOrd<PathBuf> for Cow<'_, Path>
1.8.0 · Sourceimpl PartialOrd<PathBuf> for Cow<'_, OsStr>
impl PartialOrd<PathBuf> for Cow<'_, OsStr>