#[repr(u8)]pub enum GraphemePropInCb {
None = 0,
Consonant = 16,
Extend = 32,
Linker = 48,
}Available on crate feature
grapheme only.Expand description
๐ Break property for Indic scripts that prevents splitting within orthographic syllables.
Used by grapheme boundary rule GB9c to avoid inappropriate breaks in conjunct sequences.
Based on the Indic_Conjunct_Break property from Unicode.
Vendored
This is adapted work from grapheme_machine.
Variants
None = 0
Code point is not part of an Indic conjunct sequence.
Consonant = 16
An Indic consonant code point.
Extend = 32
An extending code point in an Indic sequence.
Linker = 48
A linker code point in an Indic sequence.
Implementations