KeyFfi

Enum KeyFfi 

#[non_exhaustive]
#[repr(C)]
pub enum KeyFfi {
Show 77 variants Backspace, Enter, Tab, Escape, Space, Left, Right, Up, Down, Home, End, PageUp, PageDown, Delete, Insert, CapsLock, ScrollLock, NumLock, PrintScreen, Pause, Menu, Pad(KeyPad), Media(KeyMedia), Mod(KeyMod), Fn(u8), Char(u32), Dead(KeyDead), A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, Digit1, Digit2, Digit3, Digit4, Digit5, Digit6, Digit7, Digit8, Digit9, Digit0, Backquote, Minus, Equal, BracketLeft, BracketRight, Semicolon, Quote, Backslash, IntlBackslash, Comma, Dot, Slash, Scancode(u16), Unknown,
}
Available on ffiยทยท only.
๐ŸŽฎ ๐Ÿ›ก๏ธ An FFI-safe version of Key, used in EventKeyFfi.


๐Ÿ“ ui/event

๐Ÿ“ฆ size_of::<KeyFfi>() == 8 bytes / 64 bits โš—๏ธOption<T>


Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Backspace



Enter



Tab



Escape



Space



Left



Right



Up



Down



Home



End



PageUp



PageDown



Delete



Insert



CapsLock



ScrollLock



NumLock



PrintScreen



Pause



Menu



Pad(KeyPad)

A keypad key.



Media(KeyMedia)

A multimedia key.



Mod(KeyMod)

A modifier key.



Fn(u8)

Function keys (F1-F48).



Char(u32)

๐Ÿ›ก๏ธ A unicode character (FFI-safe, stored as u32).



Dead(KeyDead)

A dead key (accent prefix, composition).



A



B



C



D



E



F



G



H



I



J



K



L



M



N



O



P



Q



R



S



T



U



V



W



X



Y



Z



Digit1



Digit2



Digit3



Digit4



Digit5



Digit6



Digit7



Digit8



Digit9



Digit0



Backquote

Physical key left of โ€˜1โ€™



Minus

Physical - key.



Equal

Physical = key.



BracketLeft

Physical [ key.



BracketRight

Physical ] key.



Semicolon

Physical ; key.



Quote

Physical ' key.



Backslash

Physical \ key.



IntlBackslash

ISO-102 extra key.



Comma

Physical , key.



Dot

Physical . key.



Slash

Physical / key.



Scancode(u16)

A physical scancode key.



Unknown