NicheValueError

Enum NicheValueError 

pub enum NicheValueError {
    Overflow(Option<Sign>),
    InvalidValue,
}
๐Ÿšฉ+ Invalid or problematic values for niche types.


๐Ÿ“ num


Variants



Overflow(Option<Sign>)

โ…€ ๐Ÿšฉ An arithmetic overflow error, with an optional associated sign.



InvalidValue

๐Ÿšฉ An invalid value was received for the given type or operation.

Implementations

Source

impl NicheValueError

pub const fn from_overflow(_f: Overflow) -> NicheValueError

const method equivalent to From<Overflow> for NicheValueError.

Source

impl NicheValueError

pub const fn from_invalid_value(_f: InvalidValue) -> NicheValueError

const method equivalent to From<InvalidValue> for NicheValueError.