pub enum PcmLayout {
Interleaved,
Planar,
}Available on crate feature
audio only.Expand description
๐ ๐งฑ Sample arrangement of a PCM buffer.
๐ media/audio
๐ฆ size_of::<PcmLayout>() == 1 bytes / 8 bits
A PCM layout describes how channel samples are placed in memory.
It is independent from PcmSpec: the same sample type, channel layout,
and sample rate can be represented as either interleaved or planar data.
Variants
Interleaved
Channel samples are mixed by frame: LRLRLRโฆ.
Planar
Channel samples are stored in separate planes: [LLLLโฆ], [RRRRโฆ].
Implementations