TextError

Enum TextError 

#[non_exhaustive]
pub enum TextError { ElementNotFound, InvalidChar(char), InvalidUtf8 { valid_up_to: usize, error_len: Option<usize>, }, MismatchedCapacity { bound: Boundary1d, value: Option<usize>, limit: Option<usize>, }, }
๐“ ๐Ÿšฉ+ A text-related composite error.


๐Ÿ“ text


Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ElementNotFound

๐Ÿšฉ The requested element has not been found.



InvalidChar(char)

๐Ÿšฉ An invalid given character was found.



InvalidUtf8

๐Ÿšฉ Invalid UTF-8 found while interpreting a byte sequence.

This is basically a replication of core::str::Utf8Error`.

Fields

valid_up_to: usize

The index in the given string up to which valid UTF-8 was verified.

error_len: Option<usize>

The length of the error in bytes, if known.



MismatchedCapacity

๐Ÿšฉ The operation did not satisfy a finite capacity constraint.

Fields

bound: Boundary1d

Which boundary of the capacity constraint applies.

value: Option<usize>

The value involved in the capacity check, if known.

limit: Option<usize>

The capacity limit involved in the check, if known.

Implementations

Source

impl TextError

pub const fn from_element_not_found(_f: ElementNotFound) -> TextError

const method equivalent to From<ElementNotFound> for TextError.

Source

impl TextError

pub const fn from_invalid_char(_f: InvalidChar) -> TextError

const method equivalent to From<InvalidChar> for TextError.

Source

impl TextError

pub const fn from_invalid_utf8(_f: InvalidUtf8) -> TextError

const method equivalent to From<InvalidUtf8> for TextError.

Source

impl TextError

pub const fn from_mismatched_capacity(_f: MismatchedCapacity) -> TextError

const method equivalent to From<MismatchedCapacity> for TextError.