array_from_mut

Function array_from_mut 

1.53.0 (const: 1.83.0) ยท Source
pub const fn array_from_mut<T>(s: &mut T) -> &mut [T; 1]
๐Ÿ—ƒ๏ธ core Converts a mutable reference to T into &mut [T; 1] (without copying).


๐Ÿ“data/layout/array re-exported from core::array ::from_mut as array_from_mut



๐Ÿ“œ
Converts a mutable reference to T into a mutable reference to an array of length 1 (without copying).