vec_

Macro vec_ 

macro_rules! vec_ {
    ($($tt:tt)*) => { ... };
}
Available on crate feature alloc only.
πŸ—οΈ πŸ—ƒοΈ alloc Creates a Vec containing the arguments.


πŸ“ data/layout/array


Re-exported from alloc::vec.


The reason of the _ suffix is to avoid conflicting with Rust’s prelude when glob importing from this crate. Since this macro has the same name as its sibling module std::vec, in order to be able to re-export only the macro we have to wrap it with our own.