BitSpan

Struct BitSpan 

pub struct BitSpan<T> {
    pub start: u32,
    pub end: u32,
    pub width: u32,
    pub mask: T,
    pub max: T,
}
▫️ 🗃️ A contiguous span of bits in an integer carrier.


📍 bin


Stores the bounds and derived masks for a packed field.

Fields

start: u32

First bit in the span.

end: u32

Last bit in the span.

width: u32

Number of bits in the span.

mask: T

Shifted mask covering the span.

max: T

Maximum value that fits in the span.

Implementations

Source

impl<T> BitSpan<T>

pub const fn from_parts(start: u32, end: u32, mask: T, max: T) -> Self

Returns a new bit span from precomputed metadata.

Panics

Panics if start > end.

Source

impl<T: Copy> BitSpan<T>

pub const fn is_single(self) -> bool

Returns whether the span occupies exactly one bit.

pub const fn contains_bit(self, bit: u32) -> bool

Returns whether bit is inside the span.

pub const fn contains_span(self, other: Self) -> bool

Returns whether other is fully inside self.

pub const fn overlaps(self, other: Self) -> bool

Returns whether both spans share any bits.

pub const fn is_disjoint(self, other: Self) -> bool

Returns whether both spans share no bits.

pub const fn fits_in(self, bits: u32) -> bool

Returns whether the span fits in a carrier with bits bits.

Source

impl BitSpan<u8>

pub const fn new(start: u32, end: u32) -> Self

Returns a new bit span.

Panics

Panics if start > end or if end exceeds the carrier width.

pub const fn try_new(start: u32, end: u32) -> Result<Self, MismatchedBounds>

Returns a new checked bit span.

Errors

Returns an error if start > end or if end exceeds the carrier width.

pub const fn value_fits(self, value: u8) -> bool

Returns whether value fits in this span.

pub const fn get_value(self, bits: u8) -> u8

Extracts the span value from bits.

pub const fn set_value(self, bits: u8, value: u8) -> u8

Returns bits with the span value replaced.

The value is masked to fit the span width.

pub const fn try_set_value( self, bits: u8, value: u8, ) -> Result<u8, MismatchedBounds>

Returns bits with the checked span value replaced.

Errors

Returns an error if the span is invalid or if value does not fit within the span width.

pub const fn clear_in(self, bits: u8) -> u8

Clears the span bits in bits.

pub const fn is_full_in(self, bits: u8) -> bool

Returns whether every span bit is set in bits.

pub const fn is_zero_in(self, bits: u8) -> bool

Returns whether no span bit is set in bits.

Source

impl BitSpan<u16>

pub const fn new(start: u32, end: u32) -> Self

Returns a new bit span.

Panics

Panics if start > end or if end exceeds the carrier width.

pub const fn try_new(start: u32, end: u32) -> Result<Self, MismatchedBounds>

Returns a new checked bit span.

Errors

Returns an error if start > end or if end exceeds the carrier width.

pub const fn value_fits(self, value: u16) -> bool

Returns whether value fits in this span.

pub const fn get_value(self, bits: u16) -> u16

Extracts the span value from bits.

pub const fn set_value(self, bits: u16, value: u16) -> u16

Returns bits with the span value replaced.

The value is masked to fit the span width.

pub const fn try_set_value( self, bits: u16, value: u16, ) -> Result<u16, MismatchedBounds>

Returns bits with the checked span value replaced.

Errors

Returns an error if the span is invalid or if value does not fit within the span width.

pub const fn clear_in(self, bits: u16) -> u16

Clears the span bits in bits.

pub const fn is_full_in(self, bits: u16) -> bool

Returns whether every span bit is set in bits.

pub const fn is_zero_in(self, bits: u16) -> bool

Returns whether no span bit is set in bits.

Source

impl BitSpan<u32>

pub const fn new(start: u32, end: u32) -> Self

Returns a new bit span.

Panics

Panics if start > end or if end exceeds the carrier width.

pub const fn try_new(start: u32, end: u32) -> Result<Self, MismatchedBounds>

Returns a new checked bit span.

Errors

Returns an error if start > end or if end exceeds the carrier width.

pub const fn value_fits(self, value: u32) -> bool

Returns whether value fits in this span.

pub const fn get_value(self, bits: u32) -> u32

Extracts the span value from bits.

pub const fn set_value(self, bits: u32, value: u32) -> u32

Returns bits with the span value replaced.

The value is masked to fit the span width.

pub const fn try_set_value( self, bits: u32, value: u32, ) -> Result<u32, MismatchedBounds>

Returns bits with the checked span value replaced.

Errors

Returns an error if the span is invalid or if value does not fit within the span width.

pub const fn clear_in(self, bits: u32) -> u32

Clears the span bits in bits.

pub const fn is_full_in(self, bits: u32) -> bool

Returns whether every span bit is set in bits.

pub const fn is_zero_in(self, bits: u32) -> bool

Returns whether no span bit is set in bits.

Source

impl BitSpan<u64>

pub const fn new(start: u32, end: u32) -> Self

Returns a new bit span.

Panics

Panics if start > end or if end exceeds the carrier width.

pub const fn try_new(start: u32, end: u32) -> Result<Self, MismatchedBounds>

Returns a new checked bit span.

Errors

Returns an error if start > end or if end exceeds the carrier width.

pub const fn value_fits(self, value: u64) -> bool

Returns whether value fits in this span.

pub const fn get_value(self, bits: u64) -> u64

Extracts the span value from bits.

pub const fn set_value(self, bits: u64, value: u64) -> u64

Returns bits with the span value replaced.

The value is masked to fit the span width.

pub const fn try_set_value( self, bits: u64, value: u64, ) -> Result<u64, MismatchedBounds>

Returns bits with the checked span value replaced.

Errors

Returns an error if the span is invalid or if value does not fit within the span width.

pub const fn clear_in(self, bits: u64) -> u64

Clears the span bits in bits.

pub const fn is_full_in(self, bits: u64) -> bool

Returns whether every span bit is set in bits.

pub const fn is_zero_in(self, bits: u64) -> bool

Returns whether no span bit is set in bits.

Source

impl BitSpan<u128>

pub const fn new(start: u32, end: u32) -> Self

Returns a new bit span.

Panics

Panics if start > end or if end exceeds the carrier width.

pub const fn try_new(start: u32, end: u32) -> Result<Self, MismatchedBounds>

Returns a new checked bit span.

Errors

Returns an error if start > end or if end exceeds the carrier width.

pub const fn value_fits(self, value: u128) -> bool

Returns whether value fits in this span.

pub const fn get_value(self, bits: u128) -> u128

Extracts the span value from bits.

pub const fn set_value(self, bits: u128, value: u128) -> u128

Returns bits with the span value replaced.

The value is masked to fit the span width.

pub const fn try_set_value( self, bits: u128, value: u128, ) -> Result<u128, MismatchedBounds>

Returns bits with the checked span value replaced.

Errors

Returns an error if the span is invalid or if value does not fit within the span width.

pub const fn clear_in(self, bits: u128) -> u128

Clears the span bits in bits.

pub const fn is_full_in(self, bits: u128) -> bool

Returns whether every span bit is set in bits.

pub const fn is_zero_in(self, bits: u128) -> bool

Returns whether no span bit is set in bits.

Source

impl BitSpan<usize>

pub const fn new(start: u32, end: u32) -> Self

Returns a new bit span.

Panics

Panics if start > end or if end exceeds the carrier width.

pub const fn try_new(start: u32, end: u32) -> Result<Self, MismatchedBounds>

Returns a new checked bit span.

Errors

Returns an error if start > end or if end exceeds the carrier width.

pub const fn value_fits(self, value: usize) -> bool

Returns whether value fits in this span.

pub const fn get_value(self, bits: usize) -> usize

Extracts the span value from bits.

pub const fn set_value(self, bits: usize, value: usize) -> usize

Returns bits with the span value replaced.

The value is masked to fit the span width.

pub const fn try_set_value( self, bits: usize, value: usize, ) -> Result<usize, MismatchedBounds>

Returns bits with the checked span value replaced.

Errors

Returns an error if the span is invalid or if value does not fit within the span width.

pub const fn clear_in(self, bits: usize) -> usize

Clears the span bits in bits.

pub const fn is_full_in(self, bits: usize) -> bool

Returns whether every span bit is set in bits.

pub const fn is_zero_in(self, bits: usize) -> bool

Returns whether no span bit is set in bits.