BufferRingStaticExample

Struct BufferRingStaticExample 

pub struct BufferRingStaticExample<T, S> { /* private fields */ }
Available on crate features _docs_examples only.
🗃️ A static ring buffer over contiguous storage, made with buffer_ring!.


📍 data/layout/buffer


Methods

Implementations

Source

impl<T, S> BufferRingStaticExample<T, S>

Common methods.

pub const fn len(&self) -> NonValueU8<{ u8::MAX }>

Returns the number of elements currently stored in the ring.

pub const fn len_prim(&self) -> u8

Returns the number of elements currently stored in the ring.

pub const fn is_empty(&self) -> bool

Returns true if the ring contains no elements.

Source

impl<T, const CAP: usize> BufferRingStaticExample<T, [T; CAP]>

Fully initialized ring array.

Invariants

  • All CAP slots always contain a valid T.
  • len controls logical membership, not initialization.
  • head is the physical start of the logical range.
  • The tail is derived as (head + len) % CAP.
  • Dropping the ring drops all CAP stored values.

Consequences

  • Pushing can overwrite inactive initialized slots.
  • Popping by value needs Copy, Clone, or a replacement value.
  • Shrinking len does not drop elements immediately.
pub const CAP: NonValueU8<{ u8::MAX }>

The fixed capacity of the ring as the index type.

pub const CAP_PRIM: u8

The fixed capacity of the ring as the primitive type.

pub const fn new(array: [T; CAP]) -> Self

Creates an empty ring from already initialized storage.

pub const fn new_init() -> Self
where T: ConstInit,

Creates an empty ring initialized with T::INIT.

pub const fn from_array_empty(array: [T; CAP]) -> Self

Creates an empty ring from already initialized storage.

pub const fn from_array_full(array: [T; CAP]) -> Self

Creates a full ring from already initialized storage.

pub fn from_array_ring( array: [T; CAP], head: NonValueU8<{ u8::MAX }>, len: NonValueU8<{ u8::MAX }>, ) -> Option<Self>

Creates a ring from an array and explicit ring state.

Returns None if:

  • len > CAP
  • head >= CAP while len > 0
pub fn from_array_ring_prim(array: [T; CAP], head: u8, len: u8) -> Option<Self>

Primitive-index variant of from_array_ring.

pub fn from_slice_clone(src: &[T], init: T) -> Option<Self>
where T: Clone,

Creates a ring by cloning all elements from src, after initializing the remaining capacity with init.

pub const fn from_slice_copy(src: &[T], init: T) -> Option<Self>
where T: Copy,

Creates a ring by copying all elements from src, after initializing the remaining capacity with init.

pub const fn capacity(&self) -> NonValueU8<{ u8::MAX }>

Returns the fixed capacity of the ring.

pub const fn capacity_prim(&self) -> u8

Returns the fixed capacity of the ring.

pub const fn remaining_capacity(&self) -> NonValueU8<{ u8::MAX }>

Returns the number of additional elements that fit within the current capacity.

pub const fn remaining_capacity_prim(&self) -> u8

Returns the number of additional elements that fit within the current capacity.

pub const fn is_full(&self) -> bool

Returns true if the ring has reached its capacity.

pub const fn clear(&mut self)

Sets the logical length to zero.

Does not drop elements. The array remains fully initialized.

pub const fn truncate(&mut self, new_len: NonValueU8<{ u8::MAX }>)

Sets the logical length to min(new_len, len).

If new_len >= len, this is a no-op.

pub const fn truncate_prim(&mut self, new_len: u8) -> Result<(), InvalidValue>

Primitive-index variant of truncate.

pub fn push_back(&mut self, value: T) -> Result<(), T>

Appends a value to the back of the ring.

Returns Err(value) if the ring is full.

pub const fn push_back_copy(&mut self, value: T) -> Result<(), T>
where T: Copy,

Appends a copy of value to the back of the ring.

Returns Err(value) if the ring is full.

pub fn push_back_slice(&mut self, src: &[T]) -> usize
where T: Clone,

Appends as many cloned elements from src as fit at the back.

Elements keep their slice order.

pub const fn push_back_slice_copy(&mut self, src: &[T]) -> usize
where T: Copy,

Appends as many copied elements from src as fit at the back.

Elements keep their slice order.

pub const fn push_back_slice_copy_exact( &mut self, src: &[T], ) -> Result<(), usize>
where T: Copy,

Appends all copied elements from src, or none if insufficient capacity.

Returns Err(remaining_capacity) if not enough space is available.

pub fn push_front(&mut self, value: T) -> Result<(), T>

Prepends a value to the front of the ring.

Returns Err(value) if the ring is full.

pub const fn push_front_copy(&mut self, value: T) -> Result<(), T>
where T: Copy,

Prepends a copy of value to the front of the ring.

Returns Err(value) if the ring is full.

pub fn push_front_slice(&mut self, src: &[T]) -> usize
where T: Clone,

Prepends as many cloned elements from src as fit at the front.

Elements keep their slice order. If the ring contains [10, 20], then pushing [1, 2, 3] to the front makes the logical order [1, 2, 3, 10, 20].

pub const fn push_front_slice_copy(&mut self, src: &[T]) -> usize
where T: Copy,

Prepends as many copied elements from src as fit at the front.

Elements keep their slice order. If the ring contains [10, 20], then pushing [1, 2, 3] to the front makes the logical order [1, 2, 3, 10, 20].

pub const fn push_front_slice_copy_exact( &mut self, src: &[T], ) -> Result<(), usize>
where T: Copy,

Prepends all copied elements from src, or none if insufficient capacity.

Returns Err(remaining_capacity) if not enough space is available.

pub fn pop_front_clone(&mut self) -> Option<T>
where T: Clone,

Removes and returns a cloned value from the front of the ring.

pub const fn pop_front_copy(&mut self) -> Option<T>
where T: Copy,

Removes and returns a copied value from the front of the ring.

pub fn pop_front_with(&mut self, replacement: T) -> Option<T>

Removes and returns a value from the front, replacing its storage slot with replacement.

pub fn pop_front_default(&mut self) -> Option<T>
where T: Default,

Removes and returns a value from the front, replacing its storage slot with T::default().

pub const fn pop_front_copy_with(&mut self, replacement: T) -> Option<T>
where T: Copy,

Removes and returns a copied value from the front, replacing its storage slot with replacement.

pub const fn pop_front_init(&mut self) -> Option<T>
where T: ConstInit + Copy,

Removes and returns a copied value from the front, replacing its storage slot with T::INIT.

pub fn pop_back_clone(&mut self) -> Option<T>
where T: Clone,

Removes and returns a cloned value from the back of the ring.

pub const fn pop_back_copy(&mut self) -> Option<T>
where T: Copy,

Removes and returns a copied value from the back of the ring.

pub fn pop_back_with(&mut self, replacement: T) -> Option<T>

Removes and returns a value from the back, replacing its storage slot with replacement.

pub fn pop_back_default(&mut self) -> Option<T>
where T: Default,

Removes and returns a value from the back, replacing its storage slot with T::default().

pub const fn pop_back_copy_with(&mut self, replacement: T) -> Option<T>
where T: Copy,

Removes and returns a copied value from the back, replacing its storage slot with replacement.

pub const fn pop_back_init(&mut self) -> Option<T>
where T: ConstInit + Copy,

Removes and returns a copied value from the back, replacing its storage slot with T::INIT.

pub const fn peek_front(&self) -> Option<&T>

Returns a reference to the front element without removing it.

pub const fn peek_mut_front(&mut self) -> Option<&mut T>

Returns an exclusive reference to the front element without removing it.

pub const fn peek_back(&self) -> Option<&T>

Returns a reference to the back element without removing it.

pub const fn peek_mut_back(&mut self) -> Option<&mut T>

Returns an exclusive reference to the back element without removing it.

pub const fn get(&self, index: NonValueU8<{ u8::MAX }>) -> Option<&T>

Returns a shared reference to the element at logical index.

pub const fn get_prim(&self, index: u8) -> Result<Option<&T>, InvalidValue>

Primitive-index variant of get.

pub const fn get_mut( &mut self, index: NonValueU8<{ u8::MAX }>, ) -> Option<&mut T>

Returns an exclusive reference to the element at logical index.

pub const fn get_mut_prim( &mut self, index: u8, ) -> Result<Option<&mut T>, InvalidValue>

Primitive-index variant of get_mut.

pub fn take_with( &mut self, index: NonValueU8<{ u8::MAX }>, replacement: T, ) -> Option<T>

Takes the value at logical index, replacing it with replacement.

Does not change the logical length.

pub fn take_with_prim( &mut self, index: u8, replacement: T, ) -> Result<Option<T>, InvalidValue>

Primitive-index variant of take_with.

pub fn take_default(&mut self, index: NonValueU8<{ u8::MAX }>) -> Option<T>
where T: Default,

Takes the value at logical index, replacing it with T::default().

Does not change the logical length.

pub fn take_default_prim( &mut self, index: u8, ) -> Result<Option<T>, InvalidValue>
where T: Default,

Primitive-index variant of take_default.

pub const fn take_copy_with( &mut self, index: NonValueU8<{ u8::MAX }>, replacement: T, ) -> Option<T>
where T: Copy,

Takes a copied value at logical index, replacing it with replacement.

Does not change the logical length.

pub const fn take_copy_with_prim( &mut self, index: u8, replacement: T, ) -> Result<Option<T>, InvalidValue>
where T: Copy,

Primitive-index variant of take_copy_with.

pub const fn take_init(&mut self, index: NonValueU8<{ u8::MAX }>) -> Option<T>
where T: ConstInit,

Takes the value at logical index, replacing it with T::INIT.

Does not change the logical length.

pub const fn take_init_prim( &mut self, index: u8, ) -> Result<Option<T>, InvalidValue>
where T: ConstInit,

Primitive-index variant of take_init.

pub fn swap_remove_with( &mut self, index: NonValueU8<{ u8::MAX }>, replacement: T, ) -> Option<T>

Removes and returns the value at logical index, filling the gap with the logical back element and replacing the old back slot with replacement.

Decrements len. Does not preserve order.

pub fn swap_remove_with_prim( &mut self, index: u8, replacement: T, ) -> Result<Option<T>, InvalidValue>

Primitive-index variant of swap_remove_with.

pub fn swap_remove_default( &mut self, index: NonValueU8<{ u8::MAX }>, ) -> Option<T>
where T: Default,

Removes and returns the value at logical index, replacing the old back slot with T::default().

Decrements len. Does not preserve order.

pub fn swap_remove_default_prim( &mut self, index: u8, ) -> Result<Option<T>, InvalidValue>
where T: Default,

Primitive-index variant of swap_remove_default.

pub const fn swap_remove_copy( &mut self, index: NonValueU8<{ u8::MAX }>, ) -> Option<T>
where T: Copy,

Removes and returns a copied value at logical index, filling the gap with the logical back element.

Decrements len. Does not preserve order.

The vacated physical back slot is left unchanged but outside the active logical range.

pub const fn swap_remove_copy_prim( &mut self, index: u8, ) -> Result<Option<T>, InvalidValue>
where T: Copy,

Primitive-index variant of swap_remove_copy.

pub const fn swap_remove_copy_with( &mut self, index: NonValueU8<{ u8::MAX }>, replacement: T, ) -> Option<T>
where T: Copy,

Removes and returns a copied value at logical index, filling the gap with the logical back element and replacing the old back slot with replacement.

Decrements len. Does not preserve order.

pub const fn swap_remove_copy_with_prim( &mut self, index: u8, replacement: T, ) -> Result<Option<T>, InvalidValue>
where T: Copy,

Primitive-index variant of swap_remove_copy_with.

pub const fn swap_remove_init( &mut self, index: NonValueU8<{ u8::MAX }>, ) -> Option<T>
where T: ConstInit + Copy,

Removes and returns a copied value at logical index, replacing the old back slot with T::INIT.

Decrements len. Does not preserve order.

pub const fn swap_remove_init_prim( &mut self, index: u8, ) -> Result<Option<T>, InvalidValue>
where T: ConstInit + Copy,

Primitive-index variant of swap_remove_init.

pub fn as_slices(&self) -> (&[T], &[T])

Returns the active logical range as two slices.

The first slice starts at head. The second slice is non-empty only when the active range wraps around the end of storage.

pub fn as_mut_slices(&mut self) -> (&mut [T], &mut [T])

Returns the active logical range as two mutable slices.

The first slice starts at head. The second slice is non-empty only when the active range wraps around the end of storage.

pub fn iter(&self) -> impl Iterator<Item = &T>

Iterates over the active elements in logical order.

pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut T>

Iterates mutably over the active elements in logical order.

pub fn visit_each<F>(&self, f: F)
where for<'v> F: Fn(&'v T),

Visits each active element without exposing borrow identity.

pub fn visit_each_mut<F>(&mut self, f: F)
where for<'v> F: Fn(&'v mut T),

Visits each active element mutably without exposing borrow identity.

pub fn visit_slices<F, R>(&self, f: F) -> R
where for<'v> F: FnOnce(&'v [T], &'v [T]) -> R,

Visits the active logical range as two shared slices.

pub fn visit_mut_slices<F, R>(&mut self, f: F) -> R
where for<'v> F: FnOnce(&'v mut [T], &'v mut [T]) -> R,

Visits the active logical range as two exclusive slices.

Source

impl<T, const CAP: usize> BufferRingStaticExample<T, [Option<T>; CAP]>

Ring buffer backed by [Option<T>; CAP].

Invariants

  • len <= CAP.
  • If len == 0, head == 0.
  • If len > 0, head < CAP.
  • The occupied logical range 0 .. len maps through (head + logical_index) % CAP.
  • Occupied physical slots are Some(T).
  • Unoccupied physical slots are None.

Notes

  • Option<T> is used to control occupancy and dropping, not sparsity.
  • tail is derived as (head + len) % CAP.
pub const CAP: NonValueU8<{ u8::MAX }>

The fixed capacity of the ring as the index type.

pub const CAP_PRIM: u8

The fixed capacity of the ring as the primitive type.

pub const fn new() -> Self

Creates an empty ring.

pub fn from_array_ring( array: [Option<T>; CAP], head: NonValueU8<{ u8::MAX }>, len: NonValueU8<{ u8::MAX }>, ) -> Option<Self>

Creates a ring from an array of options and explicit ring state.

Returns None if the occupied slots do not match head and len.

pub fn from_array_ring_prim( array: [Option<T>; CAP], head: u8, len: u8, ) -> Option<Self>

Primitive-index variant of from_array_ring.

Returns None if the occupied slots do not match head and len, or if any of the given primitive values are invalid.

pub fn from_array_linear(array: [Option<T>; CAP]) -> Option<Self>

Creates a ring from an array of options with a linear prefix layout.

The ring head is 0, and the logical length is inferred as the index of the first None.

Returns None if a Some appears after the first None.

pub fn from_slice_clone(src: &[T]) -> Option<Self>
where T: Clone,

Creates a ring by cloning all elements from src.

pub const fn from_slice_copy(src: &[T]) -> Option<Self>
where T: Copy,

Creates a ring by copying all elements from src.

pub fn from_array_clone<const N: usize>(src: [T; N]) -> Option<Self>
where T: Clone,

Creates a ring by cloning all elements from an array.

pub const fn from_array_copy<const N: usize>(src: [T; N]) -> Option<Self>
where T: Copy,

Creates a ring by copying all elements from an array.

pub const fn capacity(&self) -> NonValueU8<{ u8::MAX }>

Returns the fixed capacity of the ring.

pub const fn capacity_prim(&self) -> u8

Returns the fixed capacity of the ring.

pub const fn remaining_capacity(&self) -> NonValueU8<{ u8::MAX }>

Returns the number of additional elements that fit within the current capacity.

pub const fn remaining_capacity_prim(&self) -> u8

Returns the number of additional elements that fit within the current capacity.

pub const fn is_full(&self) -> bool

Returns true if the ring has reached its capacity.

pub fn clear(&mut self)

Clears the ring, dropping all elements.

pub fn truncate(&mut self, new_len: NonValueU8<{ u8::MAX }>)

Truncates the ring to new_len, dropping elements from the back.

If new_len >= len, this is a no-op.

pub fn push_back(&mut self, value: T) -> Result<(), T>

Appends a value to the back of the ring.

Returns Err(value) if the ring is full.

pub const fn push_back_copy(&mut self, value: T) -> Result<(), T>
where T: Copy,

Appends a copy of value to the back of the ring.

Returns Err(value) if the ring is full.

pub fn push_back_slice(&mut self, src: &[T]) -> usize
where T: Clone,

Appends as many elements cloned from src as fit at the back of the ring.

Elements keep their slice order. After pushing [a, b, c], c becomes the logical back element.

pub const fn push_back_slice_copy(&mut self, src: &[T]) -> usize
where T: Copy,

Appends as many elements copied from src as fit at the back of the ring.

Elements keep their slice order. After pushing [a, b, c], c becomes the logical back element.

pub const fn push_back_slice_copy_exact( &mut self, src: &[T], ) -> Result<(), usize>
where T: Copy,

Appends all copied from src at the back of the ring, or none if insufficient capacity.

Returns Err(remaining_capacity) if not enough space is available.

Elements keep their slice order. After pushing [a, b, c], c becomes the logical back element.

pub fn push_front(&mut self, value: T) -> Result<(), T>

Prepends a value to the front of the ring.

Returns Err(value) if the ring is full.

pub const fn push_front_copy(&mut self, value: T) -> Result<(), T>
where T: Copy,

Prepends a copy of value to the front of the ring.

Returns Err(value) if the ring is full.

pub fn push_front_slice(&mut self, src: &[T]) -> usize
where T: Clone,

Prepends as many elements cloned from src as fit.

Elements keep their slice order. If the ring contains [10, 20], then pushing [1, 2, 3] to the front makes the logical order [1, 2, 3, 10, 20].

Returns the number of elements prepended.

pub const fn push_front_slice_copy(&mut self, src: &[T]) -> usize
where T: Copy,

Prepends as many copied elements from src as fit.

Elements keep their slice order. If the ring contains [10, 20], then pushing [1, 2, 3] to the front makes the logical order [1, 2, 3, 10, 20].

Returns the number of elements prepended.

pub const fn push_front_slice_copy_exact( &mut self, src: &[T], ) -> Result<(), usize>
where T: Copy,

Prepends all copied elements from src, or none if insufficient capacity.

Elements keep their slice order. Returns Err(remaining_capacity) if not enough space is available.

pub fn pop_front(&mut self) -> Option<T>

Removes and returns a value from the front of the ring.

pub const fn pop_front_copy(&mut self) -> Option<T>
where T: Copy,

Removes and returns a copy from the front of the ring.

pub fn pop_back(&mut self) -> Option<T>

Removes and returns a value from the back of the ring.

pub const fn pop_back_copy(&mut self) -> Option<T>
where T: Copy,

Removes and returns a copy from the back of the ring.

pub const fn peek_front(&self) -> Option<&T>

Returns a reference to the front element without removing it.

pub fn peek_mut_front(&mut self) -> Option<&mut T>

Returns an exclusive reference to the front element without removing it.

pub const fn peek_back(&self) -> Option<&T>

Returns a reference to the back element without removing it.

pub fn peek_mut_back(&mut self) -> Option<&mut T>

Returns an exclusive reference to the back element without removing it.

pub const fn get(&self, index: NonValueU8<{ u8::MAX }>) -> Option<&T>

Returns a shared reference to the element at logical index.

pub const fn get_prim(&self, index: u8) -> Result<Option<&T>, InvalidValue>

Primitive-index variant of get.

pub const fn get_mut( &mut self, index: NonValueU8<{ u8::MAX }>, ) -> Option<&mut T>

Returns an exclusive reference to the element at logical index.

pub const fn get_mut_prim( &mut self, index: u8, ) -> Result<Option<&mut T>, InvalidValue>

Primitive-index variant of get_mut.

pub fn swap_remove(&mut self, index: NonValueU8<{ u8::MAX }>) -> Option<T>

Removes and returns the value at logical index, filling the gap with the logical back element.

Decrements len. Does not preserve order.

pub fn swap_remove_prim(&mut self, index: u8) -> Result<Option<T>, InvalidValue>

Primitive-index variant of swap_remove.

pub const fn swap_remove_copy( &mut self, index: NonValueU8<{ u8::MAX }>, ) -> Option<T>
where T: Copy,

Removes and returns a copy of the value at logical index, filling the gap with the logical back element.

Decrements len. Does not preserve order.

pub fn swap_remove_copy_prim( &mut self, index: u8, ) -> Result<Option<T>, InvalidValue>
where T: Copy,

Primitive-index variant of swap_remove_copy.

pub fn as_slices(&self) -> (&[Option<T>], &[Option<T>])

Returns the active logical range as two option slices.

The first slice starts at head. The second slice is non-empty only when the active range wraps around the end of storage.

pub fn as_mut_slices(&mut self) -> (&mut [Option<T>], &mut [Option<T>])

Returns the active logical range as two mutable option slices.

The first slice starts at head. The second slice is non-empty only when the active range wraps around the end of storage.

pub fn iter(&self) -> impl Iterator<Item = &T>

Iterates over the initialized elements in logical order.

pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut T>

Iterates mutably over the initialized elements in logical order.

pub fn visit_each<F>(&self, f: F)
where for<'v> F: Fn(&'v T),

Visits each initialized element without exposing borrow identity.

pub fn visit_each_mut<F>(&mut self, f: F)
where for<'v> F: Fn(&'v mut T),

Visits each initialized element mutably without exposing borrow identity.

pub fn visit_slices<F, R>(&self, f: F) -> R
where for<'v> F: FnOnce(&'v [Option<T>], &'v [Option<T>]) -> R,

Visits the active logical range as two shared option slices.

pub fn visit_mut_slices<F, R>(&mut self, f: F) -> R
where for<'v> F: FnOnce(&'v mut [Option<T>], &'v mut [Option<T>]) -> R,

Visits the active logical range as two exclusive option slices.