Cmp

Struct Cmp 

#[repr(transparent)]
pub struct Cmp<T>(pub T);
🛠️ Provides comparing methods for T.


📍 num/fin/ord


This wrapper exposes comparison operations as value methods, enabling uniform and const-evaluable comparisons across primitives.

It provides the non-const methods pclamp, pmax, pmin for comparing PartialOrdered values.

It provides the following const methods for comparing primitives: clamp, max, min, eq, ne, lt, le, gt, ge.

It also allows compile-time comparison between Orderings.

In the case of floating-point primitives:

  • total ordering is used.
  • additional methods are provided: is_positive, is_negative, is_finite, is_infinite, is_nan.

See also the cmp! macro for an operation-first syntax.

Tuple Fields

0: T

Implementations

Source

impl<T: PartialOrd> Cmp<T>

pub fn pclamp(self, min: T, max: T) -> Option<T>

Compares and returns a PartialOrdered value clamped between min and max.

Returns None if comparisons are indeterminate.

Examples
assert_eq![Some(0.4), Cmp(1.0).pclamp(0.2, 0.4)];
assert_eq![Some(0.2), Cmp(0.0).pclamp(0.2, 0.4)];
//
assert_eq![None, Cmp(1.0).pclamp(f32::NAN, f32::NAN)];
assert_eq![None, Cmp(1.0).pclamp(f32::NAN, 0.4)];
assert_eq![None, Cmp(1.0).pclamp(0.2, f32::NAN)];
pub fn pmax(self, other: T) -> Option<T>

Compares and returns the maximum of two PartialOrdered values.

Returns None if comparisons are indeterminate.

Complements core::cmp::max which requires Ord

Examples
assert_eq![Some(0.4), Cmp(0.2).pmax(0.4)];
//
assert_eq![None, Cmp(0.2).pmax(f32::NAN)];
assert_eq![None, Cmp(f32::NAN).pmax(0.4)];
pub fn pmin(self, other: T) -> Option<T>

Compares and returns the minimum of two PartialOrdered values.

Returns None if comparisons are indeterminate.

Complements core::cmp::min which requires Ord

Examples
assert_eq![Some(0.2), Cmp(0.2).pmin(0.4)];
//
assert_eq![None, Cmp(0.2).pmin(f32::NAN)];
assert_eq![None, Cmp(f32::NAN).pmin(0.4)];
pub fn pminmax(self, other: T) -> Option<(T, T)>

Compares, orders, and returns both (minimum, maximum) PartialOrdered values.

Returns None if comparisons are indeterminate.

Examples
assert_eq![Some((0.2, 0.4)), Cmp(0.4).pminmax(0.2)];
//
assert_eq![None, Cmp(0.2).pminmax(f32::NAN)];
assert_eq![None, Cmp(f32::NAN).pminmax(0.4)];
Source

impl Cmp<u8>

pub const fn total_cmp(self, other: u8) -> Ordering

Compares self and other using total order.

For integer types, ordering is already total; this method exists for consistency with floating-point comparisons.

pub const fn clamp(self, min: u8, max: u8) -> u8

Compares and returns self clamped between min and max.

pub const fn max(self, other: u8) -> u8

Compares and returns the maximum between self and other.

pub const fn min(self, other: u8) -> u8

Compares and returns the minimum between self and other.

pub const fn minmax(self, other: u8) -> (u8, u8)

Compares, orders and returns the (minimum, maximum) self and other.

pub const fn eq(self, other: u8) -> bool

Returns true if self == other.

pub const fn ne(self, other: u8) -> bool

Returns true if self != other.

pub const fn lt(self, other: u8) -> bool

Returns true if self < other.

pub const fn le(self, other: u8) -> bool

Returns true if self <= other.

pub const fn gt(self, other: u8) -> bool

Returns true if self > other.

pub const fn ge(self, other: u8) -> bool

Returns true if self >= other.

Source

impl Cmp<u16>

pub const fn total_cmp(self, other: u16) -> Ordering

Compares self and other using total order.

For integer types, ordering is already total; this method exists for consistency with floating-point comparisons.

pub const fn clamp(self, min: u16, max: u16) -> u16

Compares and returns self clamped between min and max.

pub const fn max(self, other: u16) -> u16

Compares and returns the maximum between self and other.

pub const fn min(self, other: u16) -> u16

Compares and returns the minimum between self and other.

pub const fn minmax(self, other: u16) -> (u16, u16)

Compares, orders and returns the (minimum, maximum) self and other.

pub const fn eq(self, other: u16) -> bool

Returns true if self == other.

pub const fn ne(self, other: u16) -> bool

Returns true if self != other.

pub const fn lt(self, other: u16) -> bool

Returns true if self < other.

pub const fn le(self, other: u16) -> bool

Returns true if self <= other.

pub const fn gt(self, other: u16) -> bool

Returns true if self > other.

pub const fn ge(self, other: u16) -> bool

Returns true if self >= other.

Source

impl Cmp<u32>

pub const fn total_cmp(self, other: u32) -> Ordering

Compares self and other using total order.

For integer types, ordering is already total; this method exists for consistency with floating-point comparisons.

pub const fn clamp(self, min: u32, max: u32) -> u32

Compares and returns self clamped between min and max.

pub const fn max(self, other: u32) -> u32

Compares and returns the maximum between self and other.

pub const fn min(self, other: u32) -> u32

Compares and returns the minimum between self and other.

pub const fn minmax(self, other: u32) -> (u32, u32)

Compares, orders and returns the (minimum, maximum) self and other.

pub const fn eq(self, other: u32) -> bool

Returns true if self == other.

pub const fn ne(self, other: u32) -> bool

Returns true if self != other.

pub const fn lt(self, other: u32) -> bool

Returns true if self < other.

pub const fn le(self, other: u32) -> bool

Returns true if self <= other.

pub const fn gt(self, other: u32) -> bool

Returns true if self > other.

pub const fn ge(self, other: u32) -> bool

Returns true if self >= other.

Source

impl Cmp<u64>

pub const fn total_cmp(self, other: u64) -> Ordering

Compares self and other using total order.

For integer types, ordering is already total; this method exists for consistency with floating-point comparisons.

pub const fn clamp(self, min: u64, max: u64) -> u64

Compares and returns self clamped between min and max.

pub const fn max(self, other: u64) -> u64

Compares and returns the maximum between self and other.

pub const fn min(self, other: u64) -> u64

Compares and returns the minimum between self and other.

pub const fn minmax(self, other: u64) -> (u64, u64)

Compares, orders and returns the (minimum, maximum) self and other.

pub const fn eq(self, other: u64) -> bool

Returns true if self == other.

pub const fn ne(self, other: u64) -> bool

Returns true if self != other.

pub const fn lt(self, other: u64) -> bool

Returns true if self < other.

pub const fn le(self, other: u64) -> bool

Returns true if self <= other.

pub const fn gt(self, other: u64) -> bool

Returns true if self > other.

pub const fn ge(self, other: u64) -> bool

Returns true if self >= other.

Source

impl Cmp<u128>

pub const fn total_cmp(self, other: u128) -> Ordering

Compares self and other using total order.

For integer types, ordering is already total; this method exists for consistency with floating-point comparisons.

pub const fn clamp(self, min: u128, max: u128) -> u128

Compares and returns self clamped between min and max.

pub const fn max(self, other: u128) -> u128

Compares and returns the maximum between self and other.

pub const fn min(self, other: u128) -> u128

Compares and returns the minimum between self and other.

pub const fn minmax(self, other: u128) -> (u128, u128)

Compares, orders and returns the (minimum, maximum) self and other.

pub const fn eq(self, other: u128) -> bool

Returns true if self == other.

pub const fn ne(self, other: u128) -> bool

Returns true if self != other.

pub const fn lt(self, other: u128) -> bool

Returns true if self < other.

pub const fn le(self, other: u128) -> bool

Returns true if self <= other.

pub const fn gt(self, other: u128) -> bool

Returns true if self > other.

pub const fn ge(self, other: u128) -> bool

Returns true if self >= other.

Source

impl Cmp<usize>

pub const fn total_cmp(self, other: usize) -> Ordering

Compares self and other using total order.

For integer types, ordering is already total; this method exists for consistency with floating-point comparisons.

pub const fn clamp(self, min: usize, max: usize) -> usize

Compares and returns self clamped between min and max.

pub const fn max(self, other: usize) -> usize

Compares and returns the maximum between self and other.

pub const fn min(self, other: usize) -> usize

Compares and returns the minimum between self and other.

pub const fn minmax(self, other: usize) -> (usize, usize)

Compares, orders and returns the (minimum, maximum) self and other.

pub const fn eq(self, other: usize) -> bool

Returns true if self == other.

pub const fn ne(self, other: usize) -> bool

Returns true if self != other.

pub const fn lt(self, other: usize) -> bool

Returns true if self < other.

pub const fn le(self, other: usize) -> bool

Returns true if self <= other.

pub const fn gt(self, other: usize) -> bool

Returns true if self > other.

pub const fn ge(self, other: usize) -> bool

Returns true if self >= other.

Source

impl Cmp<i8>

pub const fn total_cmp(self, other: i8) -> Ordering

Compares self and other using total order.

For integer types, ordering is already total; this method exists for consistency with floating-point comparisons.

pub const fn clamp(self, min: i8, max: i8) -> i8

Compares and returns self clamped between min and max.

pub const fn max(self, other: i8) -> i8

Compares and returns the maximum between self and other.

pub const fn min(self, other: i8) -> i8

Compares and returns the minimum between self and other.

pub const fn minmax(self, other: i8) -> (i8, i8)

Compares, orders and returns the (minimum, maximum) self and other.

pub const fn eq(self, other: i8) -> bool

Returns true if self == other.

pub const fn ne(self, other: i8) -> bool

Returns true if self != other.

pub const fn lt(self, other: i8) -> bool

Returns true if self < other.

pub const fn le(self, other: i8) -> bool

Returns true if self <= other.

pub const fn gt(self, other: i8) -> bool

Returns true if self > other.

pub const fn ge(self, other: i8) -> bool

Returns true if self >= other.

Source

impl Cmp<i16>

pub const fn total_cmp(self, other: i16) -> Ordering

Compares self and other using total order.

For integer types, ordering is already total; this method exists for consistency with floating-point comparisons.

pub const fn clamp(self, min: i16, max: i16) -> i16

Compares and returns self clamped between min and max.

pub const fn max(self, other: i16) -> i16

Compares and returns the maximum between self and other.

pub const fn min(self, other: i16) -> i16

Compares and returns the minimum between self and other.

pub const fn minmax(self, other: i16) -> (i16, i16)

Compares, orders and returns the (minimum, maximum) self and other.

pub const fn eq(self, other: i16) -> bool

Returns true if self == other.

pub const fn ne(self, other: i16) -> bool

Returns true if self != other.

pub const fn lt(self, other: i16) -> bool

Returns true if self < other.

pub const fn le(self, other: i16) -> bool

Returns true if self <= other.

pub const fn gt(self, other: i16) -> bool

Returns true if self > other.

pub const fn ge(self, other: i16) -> bool

Returns true if self >= other.

Source

impl Cmp<i32>

pub const fn total_cmp(self, other: i32) -> Ordering

Compares self and other using total order.

For integer types, ordering is already total; this method exists for consistency with floating-point comparisons.

pub const fn clamp(self, min: i32, max: i32) -> i32

Compares and returns self clamped between min and max.

pub const fn max(self, other: i32) -> i32

Compares and returns the maximum between self and other.

pub const fn min(self, other: i32) -> i32

Compares and returns the minimum between self and other.

pub const fn minmax(self, other: i32) -> (i32, i32)

Compares, orders and returns the (minimum, maximum) self and other.

pub const fn eq(self, other: i32) -> bool

Returns true if self == other.

pub const fn ne(self, other: i32) -> bool

Returns true if self != other.

pub const fn lt(self, other: i32) -> bool

Returns true if self < other.

pub const fn le(self, other: i32) -> bool

Returns true if self <= other.

pub const fn gt(self, other: i32) -> bool

Returns true if self > other.

pub const fn ge(self, other: i32) -> bool

Returns true if self >= other.

Source

impl Cmp<i64>

pub const fn total_cmp(self, other: i64) -> Ordering

Compares self and other using total order.

For integer types, ordering is already total; this method exists for consistency with floating-point comparisons.

pub const fn clamp(self, min: i64, max: i64) -> i64

Compares and returns self clamped between min and max.

pub const fn max(self, other: i64) -> i64

Compares and returns the maximum between self and other.

pub const fn min(self, other: i64) -> i64

Compares and returns the minimum between self and other.

pub const fn minmax(self, other: i64) -> (i64, i64)

Compares, orders and returns the (minimum, maximum) self and other.

pub const fn eq(self, other: i64) -> bool

Returns true if self == other.

pub const fn ne(self, other: i64) -> bool

Returns true if self != other.

pub const fn lt(self, other: i64) -> bool

Returns true if self < other.

pub const fn le(self, other: i64) -> bool

Returns true if self <= other.

pub const fn gt(self, other: i64) -> bool

Returns true if self > other.

pub const fn ge(self, other: i64) -> bool

Returns true if self >= other.

Source

impl Cmp<i128>

pub const fn total_cmp(self, other: i128) -> Ordering

Compares self and other using total order.

For integer types, ordering is already total; this method exists for consistency with floating-point comparisons.

pub const fn clamp(self, min: i128, max: i128) -> i128

Compares and returns self clamped between min and max.

pub const fn max(self, other: i128) -> i128

Compares and returns the maximum between self and other.

pub const fn min(self, other: i128) -> i128

Compares and returns the minimum between self and other.

pub const fn minmax(self, other: i128) -> (i128, i128)

Compares, orders and returns the (minimum, maximum) self and other.

pub const fn eq(self, other: i128) -> bool

Returns true if self == other.

pub const fn ne(self, other: i128) -> bool

Returns true if self != other.

pub const fn lt(self, other: i128) -> bool

Returns true if self < other.

pub const fn le(self, other: i128) -> bool

Returns true if self <= other.

pub const fn gt(self, other: i128) -> bool

Returns true if self > other.

pub const fn ge(self, other: i128) -> bool

Returns true if self >= other.

Source

impl Cmp<isize>

pub const fn total_cmp(self, other: isize) -> Ordering

Compares self and other using total order.

For integer types, ordering is already total; this method exists for consistency with floating-point comparisons.

pub const fn clamp(self, min: isize, max: isize) -> isize

Compares and returns self clamped between min and max.

pub const fn max(self, other: isize) -> isize

Compares and returns the maximum between self and other.

pub const fn min(self, other: isize) -> isize

Compares and returns the minimum between self and other.

pub const fn minmax(self, other: isize) -> (isize, isize)

Compares, orders and returns the (minimum, maximum) self and other.

pub const fn eq(self, other: isize) -> bool

Returns true if self == other.

pub const fn ne(self, other: isize) -> bool

Returns true if self != other.

pub const fn lt(self, other: isize) -> bool

Returns true if self < other.

pub const fn le(self, other: isize) -> bool

Returns true if self <= other.

pub const fn gt(self, other: isize) -> bool

Returns true if self > other.

pub const fn ge(self, other: isize) -> bool

Returns true if self >= other.

Source

impl Cmp<f32>

pub const fn total_cmp(self, other: f32) -> Ordering

A (const) port of f32::total_cmp.

pub const fn clamp(self, min: f32, max: f32) -> f32

Compares and returns a clamped total ordered self between min and max.

Examples
assert_eq![2.0, Cmp(5.0f32).clamp(-1.0, 2.0)];
assert_eq![-1.0, Cmp(-5.0f32).clamp(-1.0, 2.0)];
pub const fn max(self, other: f32) -> f32

Compares and returns the total ordered maximum between self and other.

Examples
assert_eq![2.0, Cmp(2.0f32).max(-1.0)];
assert_eq![2.0, Cmp(1.0f32).max(2.0)];
assert_eq![0.0, Cmp(-0.0f32).max(0.0)];
assert_eq![f32::INFINITY, Cmp(f32::INFINITY).max(f32::NEG_INFINITY)];
pub const fn min(self, other: f32) -> f32

Compares and returns the total ordered minimum between self and other.

Examples
assert_eq![-1.0, Cmp(2.0f32).min(-1.0)];
assert_eq![1.0, Cmp(1.0f32).min(2.0)];
assert_eq![-0.0, Cmp(-0.0f32).min(0.0)];
assert_eq![f32::NEG_INFINITY, Cmp(f32::INFINITY).min(f32::NEG_INFINITY)];
pub const fn eq(self, other: f32) -> bool

Returns true if self == other using total order.

pub const fn ne(self, other: f32) -> bool

Returns true if self != other using total order.

pub const fn lt(self, other: f32) -> bool

Returns true if self < other using total order.

pub const fn le(self, other: f32) -> bool

Returns true if self <= other using total order.

pub const fn gt(self, other: f32) -> bool

Returns true if self > other using total order.

pub const fn ge(self, other: f32) -> bool

Returns true if self >= other using total order.

pub const fn is_positive(self) -> bool

Returns true if self is sign positive.

pub const fn is_negative(self) -> bool

Returns true if self is sign negative.

pub const fn is_infinite(self) -> bool

Returns true if self is infinite (either negative or positive).

pub const fn is_finite(self) -> bool

Returns true if self is neither infinite nor NaN.

pub const fn is_nan(self) -> bool

Returns true if self is NaN.

pub const fn is_subnormal(self) -> bool

Returns true if self is subnormal.

pub const fn is_normal(self) -> bool

Returns true if self is neither zero, infinite, subnormal, or NaN.

Source

impl Cmp<f64>

pub const fn total_cmp(self, other: f64) -> Ordering

A (const) port of f64::total_cmp.

pub const fn clamp(self, min: f64, max: f64) -> f64

Compares and returns a clamped total ordered self between min and max.

Examples
assert_eq![2.0, Cmp(5.0f64).clamp(-1.0, 2.0)];
assert_eq![-1.0, Cmp(-5.0f64).clamp(-1.0, 2.0)];
pub const fn max(self, other: f64) -> f64

Compares and returns the total ordered maximum between self and other.

Examples
assert_eq![2.0, Cmp(2.0f64).max(-1.0)];
assert_eq![2.0, Cmp(1.0f64).max(2.0)];
assert_eq![0.0, Cmp(-0.0f64).max(0.0)];
assert_eq![f64::INFINITY, Cmp(f64::INFINITY).max(f64::NEG_INFINITY)];
pub const fn min(self, other: f64) -> f64

Compares and returns the total ordered minimum between self and other.

Examples
assert_eq![-1.0, Cmp(2.0f64).min(-1.0)];
assert_eq![1.0, Cmp(1.0f64).min(2.0)];
assert_eq![-0.0, Cmp(-0.0f64).min(0.0)];
assert_eq![f64::NEG_INFINITY, Cmp(f64::INFINITY).min(f64::NEG_INFINITY)];
pub const fn eq(self, other: f64) -> bool

Returns true if self == other using total order.

pub const fn ne(self, other: f64) -> bool

Returns true if self != other using total order.

pub const fn lt(self, other: f64) -> bool

Returns true if self < other using total order.

pub const fn le(self, other: f64) -> bool

Returns true if self <= other using total order.

pub const fn gt(self, other: f64) -> bool

Returns true if self > other using total order.

pub const fn ge(self, other: f64) -> bool

Returns true if self >= other using total order.

pub const fn is_positive(self) -> bool

Returns true if self is sign positive.

pub const fn is_negative(self) -> bool

Returns true if self is sign negative.

pub const fn is_infinite(self) -> bool

Returns true if self is infinite (either negative or positive).

pub const fn is_finite(self) -> bool

Returns true if self is neither infinite nor NaN.

pub const fn is_nan(self) -> bool

Returns true if self is NaN.

pub const fn is_subnormal(self) -> bool

Returns true if self is subnormal.

pub const fn is_normal(self) -> bool

Returns true if self is neither zero, infinite, subnormal, or NaN.

Source

impl Cmp<f16>

pub const fn total_cmp(self, other: f16) -> Ordering

A (const) port of f16::total_cmp.

pub const fn clamp(self, min: f16, max: f16) -> f16

Compares and returns a clamped total ordered self between min and max.

Examples
assert_eq![2.0, Cmp(5.0f16).clamp(-1.0, 2.0)];
assert_eq![-1.0, Cmp(-5.0f16).clamp(-1.0, 2.0)];
pub const fn max(self, other: f16) -> f16

Compares and returns the total ordered maximum between self and other.

Examples
assert_eq![2.0, Cmp(2.0f16).max(-1.0)];
assert_eq![2.0, Cmp(1.0f16).max(2.0)];
assert_eq![0.0, Cmp(-0.0f16).max(0.0)];
assert_eq![f16::INFINITY, Cmp(f16::INFINITY).max(f16::NEG_INFINITY)];
pub const fn min(self, other: f16) -> f16

Compares and returns the total ordered minimum between self and other.

Examples
assert_eq![-1.0, Cmp(2.0f16).min(-1.0)];
assert_eq![1.0, Cmp(1.0f16).min(2.0)];
assert_eq![-0.0, Cmp(-0.0f16).min(0.0)];
assert_eq![f16::NEG_INFINITY, Cmp(f16::INFINITY).min(f16::NEG_INFINITY)];
pub const fn eq(self, other: f16) -> bool

Returns true if self == other using total order.

pub const fn ne(self, other: f16) -> bool

Returns true if self != other using total order.

pub const fn lt(self, other: f16) -> bool

Returns true if self < other using total order.

pub const fn le(self, other: f16) -> bool

Returns true if self <= other using total order.

pub const fn gt(self, other: f16) -> bool

Returns true if self > other using total order.

pub const fn ge(self, other: f16) -> bool

Returns true if self >= other using total order.

pub const fn is_positive(self) -> bool

Returns true if self is sign positive.

pub const fn is_negative(self) -> bool

Returns true if self is sign negative.

pub const fn is_infinite(self) -> bool

Returns true if self is infinite (either negative or positive).

pub const fn is_finite(self) -> bool

Returns true if self is neither infinite nor NaN.

pub const fn is_nan(self) -> bool

Returns true if self is NaN.

pub const fn is_subnormal(self) -> bool

Returns true if self is subnormal.

pub const fn is_normal(self) -> bool

Returns true if self is neither zero, infinite, subnormal, or NaN.

Source

impl Cmp<f128>

pub const fn total_cmp(self, other: f128) -> Ordering

A (const) port of f128::total_cmp.

pub const fn clamp(self, min: f128, max: f128) -> f128

Compares and returns a clamped total ordered self between min and max.

Examples
assert_eq![2.0, Cmp(5.0f128).clamp(-1.0, 2.0)];
assert_eq![-1.0, Cmp(-5.0f128).clamp(-1.0, 2.0)];
pub const fn max(self, other: f128) -> f128

Compares and returns the total ordered maximum between self and other.

Examples
assert_eq![2.0, Cmp(2.0f128).max(-1.0)];
assert_eq![2.0, Cmp(1.0f128).max(2.0)];
assert_eq![0.0, Cmp(-0.0f128).max(0.0)];
assert_eq![f128::INFINITY, Cmp(f128::INFINITY).max(f128::NEG_INFINITY)];
pub const fn min(self, other: f128) -> f128

Compares and returns the total ordered minimum between self and other.

Examples
assert_eq![-1.0, Cmp(2.0f128).min(-1.0)];
assert_eq![1.0, Cmp(1.0f128).min(2.0)];
assert_eq![-0.0, Cmp(-0.0f128).min(0.0)];
assert_eq![f128::NEG_INFINITY, Cmp(f128::INFINITY).min(f128::NEG_INFINITY)];
pub const fn eq(self, other: f128) -> bool

Returns true if self == other using total order.

pub const fn ne(self, other: f128) -> bool

Returns true if self != other using total order.

pub const fn lt(self, other: f128) -> bool

Returns true if self < other using total order.

pub const fn le(self, other: f128) -> bool

Returns true if self <= other using total order.

pub const fn gt(self, other: f128) -> bool

Returns true if self > other using total order.

pub const fn ge(self, other: f128) -> bool

Returns true if self >= other using total order.

pub const fn is_positive(self) -> bool

Returns true if self is sign positive.

pub const fn is_negative(self) -> bool

Returns true if self is sign negative.

pub const fn is_infinite(self) -> bool

Returns true if self is infinite (either negative or positive).

pub const fn is_finite(self) -> bool

Returns true if self is neither infinite nor NaN.

pub const fn is_nan(self) -> bool

Returns true if self is NaN.

pub const fn is_subnormal(self) -> bool

Returns true if self is subnormal.

pub const fn is_normal(self) -> bool

Returns true if self is neither zero, infinite, subnormal, or NaN.

Source

impl Cmp<Ordering>

pub const fn total_cmp(self, other: Ordering) -> Ordering

Compares self and other using total order.

Ordering is already totally ordered as: Less < Equal < Greater.

pub const fn clamp(self, min: Ordering, max: Ordering) -> Ordering

Compares and returns self clamped between min and max.

pub const fn max(self, other: Ordering) -> Ordering

Compares and returns the maximum between self and other.

pub const fn min(self, other: Ordering) -> Ordering

Compares and returns the minimum between self and other.

pub const fn eq(self, other: Ordering) -> bool

Returns true if self == other.

pub const fn ne(self, other: Ordering) -> bool

Returns true if self != other.

pub const fn lt(self, other: Ordering) -> bool

Returns true if self < other.

pub const fn le(self, other: Ordering) -> bool

Returns true if self <= other.

pub const fn gt(self, other: Ordering) -> bool

Returns true if self > other.

pub const fn ge(self, other: Ordering) -> bool

Returns true if self >= other.