GameSession

Struct GameSession 

pub struct GameSession<Rs, As, Os> {
    pub roles: Rs,
    pub actions: As,
    pub outcomes: Os,
}
๐Ÿ€„ A bounded instance of enacted play.


๐Ÿ“ vita/play/game


Represents one occurrence of play as a whole.

A session contains the active structure of play and may contribute to a legacy.

Uses

One sitting, one match, one run, one playthrough, one active game instanceโ€ฆ

Fields

roles: Rs

The participating roles in the session.

actions: As

The actions declared in the session.

outcomes: Os

The outcomes resolved in the session.