Iter

Struct Iter 

pub struct Iter;
๐Ÿ”„ ๐Ÿ› ๏ธ Iterator-related namespaced operations.


๐Ÿ“ data/access/iter


Implementations

Source

impl Iter

Core methods.

pub const fn empty<T>() -> Empty<T> โ“˜

Creates an iterator that yields nothing.

See core::iter::empty.

pub fn from_coroutine<G>(coroutine: G) -> FromCoroutine<G> โ“˜
where G: Coroutine<Return = ()> + Unpin,

Available on nightly_coro only.

Creates a new iterator where each iteration calls the provided coroutine.

See core::iter::from_coroutine.

pub fn from_fn<T, F>(f: F) -> FromFn<F> โ“˜
where F: FnMut() -> Option<T>,

Creates an iterator that calls the given closure F: FnMut() -> Option<T>.

See core::iter::from_fn.

pub fn once<T>(value: T) -> Once<T> โ“˜

Creates an iterator that yields an element exactly once.

See core::iter::once.

pub fn once_with<A, F>(make: F) -> OnceWith<F> โ“˜
where F: FnOnce() -> A,

Creates an iterator that lazily generates a value exactly once.

See core::iter::once_with.

pub fn repeat<T>(elt: T) -> Repeat<T> โ“˜
where T: Clone,

Creates an iterator that endlessly repeats a single element.

See core::iter::repeat.

pub fn repeat_n<T>(element: T, count: usize) -> RepeatN<T> โ“˜
where T: Clone,

Creates a new iterator that repeats a single element a given number of times.

See core::iter::repeat_n.

pub fn repeat_with<A, F>(repeater: F) -> RepeatWith<F> โ“˜
where F: FnMut() -> A,

Creates an iterator that endlessly repeats calling F: FnMut() -> A.

See core::iter::repeat_with.

pub fn successors<T, F>(first: Option<T>, succ: F) -> Successors<T, F> โ“˜
where F: FnMut(&T) -> Option<T>,

Creates an iterator where each successive item is computed based on the previous.

See core::iter::successors.

pub fn zip<A, B>( a: A, b: B, ) -> Zip<<A as IntoIterator>::IntoIter, <B as IntoIterator>::IntoIter> โ“˜

Converts the arguments to iterators and zips them.

See core::iter::zip.