LinuxTermiosControlFlags

Struct LinuxTermiosControlFlags 

pub struct LinuxTermiosControlFlags { /* private fields */ }
Available on crate feature linux only.
๐Ÿง ๐Ÿฎ– โІ LinuxTermios control flags.


๐Ÿ“ sys/os/linux/io/term

๐Ÿ“ฆ size_of::<LinuxTermiosControlFlags>() == 2 bytes / 16 bits


NOTE: CSIZE/CS5/CS6/CS7/CS8 are a masked character-size field, not independent flags. Prefer LinuxTermios::set_char_size when changing it.

Implementations

Source

impl LinuxTermiosControlFlags

pub const CS5: Self

Character size 5 bits.

pub const fn from_c_uint(bits: c_uint) -> Self

Returns flags from the raw Linux c_cflag word.

pub const fn as_c_uint(self) -> c_uint

Returns flags as a raw Linux c_cflag word.

Source

impl LinuxTermiosControlFlags

Named constants

pub const CSIZE: Self

+ Character size mask.

pub const CS6: Self

1 Character size 6 bits.

pub const CS7: Self

1 Character size 7 bits.

pub const CS8: Self

+ Character size 8 bits.

pub const CSTOPB: Self

1 Set two stop bits, rather than one.

pub const CREAD: Self

1 Enable receiver.

pub const PARENB: Self

1 Enable parity generation and checking.

pub const PARODD: Self

1 Odd parity instead of even parity.

pub const HUPCL: Self

1 Hang up on last close.

pub const CLOCAL: Self

1 Ignore modem control lines.

Source

impl LinuxTermiosControlFlags

Convenience methods derived from each named constant.

pub const fn contains_csize(self) -> bool

Returns true if the set contains all bits in CSIZE.

pub const fn intersects_csize(self) -> bool

Returns true if the set shares any bit with CSIZE.

pub const fn with_csize(self) -> Self

Returns self with CSIZE inserted.

pub const fn with_csize_if(self, condition: bool) -> Self

Returns self with CSIZE inserted if condition is true.

pub const fn without_csize(self) -> Self

Returns self with CSIZE removed.

pub const fn set_csize(&mut self)

Sets CSIZE.

pub const fn set_csize_if(&mut self, condition: bool)

Sets CSIZE if condition is true.

pub const fn unset_csize(&mut self)

Unsets CSIZE.

pub const fn has_cs6(self) -> bool

Returns true if CS6 is present.

pub const fn contains_cs6(self) -> bool

Returns true if all bits in CS6 are present.

pub const fn intersects_cs6(self) -> bool

Returns true if the set shares any bit with CS6.

pub const fn with_cs6(self) -> Self

Returns self with CS6 inserted.

pub const fn with_cs6_if(self, condition: bool) -> Self

Returns self with CS6 inserted if condition is true.

pub const fn without_cs6(self) -> Self

Returns self with CS6 removed.

pub const fn set_cs6(&mut self)

Sets CS6.

pub const fn set_cs6_if(&mut self, condition: bool)

Sets CS6 if condition is true.

pub const fn unset_cs6(&mut self)

Unsets CS6.

pub const fn has_cs7(self) -> bool

Returns true if CS7 is present.

pub const fn contains_cs7(self) -> bool

Returns true if all bits in CS7 are present.

pub const fn intersects_cs7(self) -> bool

Returns true if the set shares any bit with CS7.

pub const fn with_cs7(self) -> Self

Returns self with CS7 inserted.

pub const fn with_cs7_if(self, condition: bool) -> Self

Returns self with CS7 inserted if condition is true.

pub const fn without_cs7(self) -> Self

Returns self with CS7 removed.

pub const fn set_cs7(&mut self)

Sets CS7.

pub const fn set_cs7_if(&mut self, condition: bool)

Sets CS7 if condition is true.

pub const fn unset_cs7(&mut self)

Unsets CS7.

pub const fn contains_cs8(self) -> bool

Returns true if the set contains all bits in CS8.

pub const fn intersects_cs8(self) -> bool

Returns true if the set shares any bit with CS8.

pub const fn with_cs8(self) -> Self

Returns self with CS8 inserted.

pub const fn with_cs8_if(self, condition: bool) -> Self

Returns self with CS8 inserted if condition is true.

pub const fn without_cs8(self) -> Self

Returns self with CS8 removed.

pub const fn set_cs8(&mut self)

Sets CS8.

pub const fn set_cs8_if(&mut self, condition: bool)

Sets CS8 if condition is true.

pub const fn unset_cs8(&mut self)

Unsets CS8.

pub const fn has_cstopb(self) -> bool

Returns true if CSTOPB is present.

pub const fn contains_cstopb(self) -> bool

Returns true if all bits in CSTOPB are present.

pub const fn intersects_cstopb(self) -> bool

Returns true if the set shares any bit with CSTOPB.

pub const fn with_cstopb(self) -> Self

Returns self with CSTOPB inserted.

pub const fn with_cstopb_if(self, condition: bool) -> Self

Returns self with CSTOPB inserted if condition is true.

pub const fn without_cstopb(self) -> Self

Returns self with CSTOPB removed.

pub const fn set_cstopb(&mut self)

Sets CSTOPB.

pub const fn set_cstopb_if(&mut self, condition: bool)

Sets CSTOPB if condition is true.

pub const fn unset_cstopb(&mut self)

Unsets CSTOPB.

pub const fn has_cread(self) -> bool

Returns true if CREAD is present.

pub const fn contains_cread(self) -> bool

Returns true if all bits in CREAD are present.

pub const fn intersects_cread(self) -> bool

Returns true if the set shares any bit with CREAD.

pub const fn with_cread(self) -> Self

Returns self with CREAD inserted.

pub const fn with_cread_if(self, condition: bool) -> Self

Returns self with CREAD inserted if condition is true.

pub const fn without_cread(self) -> Self

Returns self with CREAD removed.

pub const fn set_cread(&mut self)

Sets CREAD.

pub const fn set_cread_if(&mut self, condition: bool)

Sets CREAD if condition is true.

pub const fn unset_cread(&mut self)

Unsets CREAD.

pub const fn has_parenb(self) -> bool

Returns true if PARENB is present.

pub const fn contains_parenb(self) -> bool

Returns true if all bits in PARENB are present.

pub const fn intersects_parenb(self) -> bool

Returns true if the set shares any bit with PARENB.

pub const fn with_parenb(self) -> Self

Returns self with PARENB inserted.

pub const fn with_parenb_if(self, condition: bool) -> Self

Returns self with PARENB inserted if condition is true.

pub const fn without_parenb(self) -> Self

Returns self with PARENB removed.

pub const fn set_parenb(&mut self)

Sets PARENB.

pub const fn set_parenb_if(&mut self, condition: bool)

Sets PARENB if condition is true.

pub const fn unset_parenb(&mut self)

Unsets PARENB.

pub const fn has_parodd(self) -> bool

Returns true if PARODD is present.

pub const fn contains_parodd(self) -> bool

Returns true if all bits in PARODD are present.

pub const fn intersects_parodd(self) -> bool

Returns true if the set shares any bit with PARODD.

pub const fn with_parodd(self) -> Self

Returns self with PARODD inserted.

pub const fn with_parodd_if(self, condition: bool) -> Self

Returns self with PARODD inserted if condition is true.

pub const fn without_parodd(self) -> Self

Returns self with PARODD removed.

pub const fn set_parodd(&mut self)

Sets PARODD.

pub const fn set_parodd_if(&mut self, condition: bool)

Sets PARODD if condition is true.

pub const fn unset_parodd(&mut self)

Unsets PARODD.

pub const fn has_hupcl(self) -> bool

Returns true if HUPCL is present.

pub const fn contains_hupcl(self) -> bool

Returns true if all bits in HUPCL are present.

pub const fn intersects_hupcl(self) -> bool

Returns true if the set shares any bit with HUPCL.

pub const fn with_hupcl(self) -> Self

Returns self with HUPCL inserted.

pub const fn with_hupcl_if(self, condition: bool) -> Self

Returns self with HUPCL inserted if condition is true.

pub const fn without_hupcl(self) -> Self

Returns self with HUPCL removed.

pub const fn set_hupcl(&mut self)

Sets HUPCL.

pub const fn set_hupcl_if(&mut self, condition: bool)

Sets HUPCL if condition is true.

pub const fn unset_hupcl(&mut self)

Unsets HUPCL.

pub const fn has_clocal(self) -> bool

Returns true if CLOCAL is present.

pub const fn contains_clocal(self) -> bool

Returns true if all bits in CLOCAL are present.

pub const fn intersects_clocal(self) -> bool

Returns true if the set shares any bit with CLOCAL.

pub const fn with_clocal(self) -> Self

Returns self with CLOCAL inserted.

pub const fn with_clocal_if(self, condition: bool) -> Self

Returns self with CLOCAL inserted if condition is true.

pub const fn without_clocal(self) -> Self

Returns self with CLOCAL removed.

pub const fn set_clocal(&mut self)

Sets CLOCAL.

pub const fn set_clocal_if(&mut self, condition: bool)

Sets CLOCAL if condition is true.

pub const fn unset_clocal(&mut self)

Unsets CLOCAL.

Source

impl LinuxTermiosControlFlags

Common set methods

pub const fn new() -> Self

Returns an empty set.

pub const fn from_bits(bits: u16) -> Self

Returns a set from raw bits.

pub const fn bits(self) -> u16

Returns the raw backing bits.

pub const fn all() -> Self

Returns the union of all declared sets.

pub const fn is_empty(self) -> bool

Returns true if no bits are set.

pub const fn is_full(self) -> bool

Returns true if all the declared bits are set.

pub const fn contains(self, other: Self) -> bool

Returns true if all bits in other are also set in self.

pub const fn has(self, other: Self) -> bool

An alias of contains.

pub const fn with(self, other: Self) -> Self

Returns self with other inserted.

pub const fn with_if(self, condition: bool, other: Self) -> Self

Returns self with other inserted if condition is true.

pub const fn without(self, other: Self) -> Self

Returns self with other removed.

pub const fn toggled(self, other: Self) -> Self

Returns self with other toggled.

Source

impl LinuxTermiosControlFlags

Set operations

pub const fn intersects(self, other: Self) -> bool

Returns true if self and other share any bit.

pub const fn is_subset(self, other: Self) -> bool

Returns true if all bits in self are also set in other.

pub const fn is_superset(self, other: Self) -> bool

Returns true if all bits in other are also set in self.

pub const fn union(self, other: Self) -> Self

Returns the union of self and other.

pub const fn intersection(self, other: Self) -> Self

Returns the intersection of self and other.

pub const fn difference(self, other: Self) -> Self

Returns the difference of self and other.

pub const fn symmetric_difference(self, other: Self) -> Self

Returns the symmetric difference of self and other.

Source

impl LinuxTermiosControlFlags

Mutating set operations

pub const fn clear(&mut self)

Clears the set.

pub const fn insert(&mut self, other: Self)

Inserts all bits from other.

pub const fn remove(&mut self, other: Self)

Removes all bits from other.

pub const fn toggle(&mut self, other: Self)

Toggles all bits from other.