MutexGuard

Struct MutexGuard 

1.0.0 ยท Source
pub struct MutexGuard<'a, T>
where T: 'a + ?Sized,
{ /* private fields */ }
Available on crate features std only.
๐Ÿงต ๐Ÿ”’ std An RAII implementation of a โ€œscoped lockโ€ of a mutex.


๐Ÿ“work/sync re-exported from std::sync



๐Ÿ“œ
An RAII implementation of a โ€œscoped lockโ€ of a mutex. When this structure is dropped (falls out of scope), the lock will be unlocked.

The data protected by the mutex can be accessed through this guard via its Deref and DerefMut implementations.

This structure is created by the lock and try_lock methods on Mutex.

Implementations

Source

impl<'a, T> MutexGuard<'a, T>
where T: ?Sized,

pub fn map<U, F>(orig: MutexGuard<'a, T>, f: F) -> MappedMutexGuard<'a, U>
where F: FnOnce(&mut T) -> &mut U, U: ?Sized,

๐Ÿ”ฌThis is a nightly-only experimental API. (mapped_lock_guards)

Makes a MappedMutexGuard for a component of the borrowed data, e.g. an enum variant.

The Mutex is already locked, so this cannot fail.

This is an associated function that needs to be used as MutexGuard::map(...). A method would interfere with methods of the same name on the contents of the MutexGuard used through Deref.

pub fn filter_map<U, F>( orig: MutexGuard<'a, T>, f: F, ) -> Result<MappedMutexGuard<'a, U>, MutexGuard<'a, T>> โ“˜
where F: FnOnce(&mut T) -> Option<&mut U>, U: ?Sized,

๐Ÿ”ฌThis is a nightly-only experimental API. (mapped_lock_guards)

Makes a MappedMutexGuard for a component of the borrowed data. The original guard is returned as an Err(...) if the closure returns None.

The Mutex is already locked, so this cannot fail.

This is an associated function that needs to be used as MutexGuard::filter_map(...). A method would interfere with methods of the same name on the contents of the MutexGuard used through Deref.