NonValueU32

Struct NonValueU32 

pub struct NonValueU32<const V: u32>(/* private fields */);
⚗️ An unsigned integer that is known not to equal some specific value.


📍 num/grain/niche


It has the same memory layout optimization as NonZero<u32>, so that Option<NonValueU32> is the same size as NonValueU32.

Examples

assert![NonValueI8::<13>::new(13).is_none()];
assert![NonValueI8::<13>::new(12).unwrap().get() == 12];

See also NonMaxU32.

Implementations

Source

impl<const V: u32> NonValueU32<V>

pub const MAX: Self

Returns the maximum possible value.

pub const MIN: Self

Returns the minimum possible value.

pub const VALID_VALUES: u32 = u32::MAX

Returns the number of valid values.

pub const INVALID_VALUES: u32 = 1

Returns the number of invalid values.

pub const fn new(value: u32) -> Option<Self>

Returns a NonValueU32 with the given value, if it is not equal to V.

pub const fn new_lossy(value: u32) -> Self

Creates a non-value integer, automatically converting the prohibited value V to the closest valid number (V-1 for most cases, V+1 for MIN).

Guarantees
  • For unsigned MAX: V-1 → stored as !(V-1)
  • For signed MIN: V+1 → stored as (V+1) ^ MIN
  • All others: V-1 → stored as (V-1) ^ V
Features
  • Can use the unsafe_niche feature internally.
Examples
let x = assert_eq![NonValueU8::<255>::new_lossy(255).get(), 254];
let y = assert_eq![NonValueI8::<-128>::new_lossy(-128).get(), -127];
pub const unsafe fn new_unchecked(value: u32) -> Self

Available on crate feature unsafe_niche only.

Returns a NonValueU32 if the given value if it is not equal to V.

Panics

Panics in debug if the given value is equal to V.

Safety

The given value must never be equal to V.

pub const fn get(&self) -> u32

Returns the value as a primitive type.

pub const fn is_max(&self) -> bool

Returns true if it is equal to the maximum value (MAX).

pub const fn is_min(&self) -> bool

Returns true if it is equal to the minimum value (MIN).

pub const fn checked_add(&self, other: u32) -> Result<Self, NicheValueError>

Checked integer addition. Computes self + rhs.

Errors

Returns Overflow if the operations overflows, or InvalidValue if the result equals the forbidden value V.

pub const fn checked_sub(&self, other: u32) -> Result<Self, NicheValueError>

Checked integer substration. Computes self - rhs.

Errors

Returns Overflow if the operations overflows, or InvalidValue if the result equals the forbidden value V.

pub const fn strict_add(&self, other: u32) -> Self

Strict integer addition. Computes self + rhs.

Panics

Panics on overflow or if the result equals the forbidden value V.

pub const fn strict_sub(&self, other: u32) -> Self

Strict integer substration. Computes self - rhs.

Panics

Panics on overflow or if the result equals the forbidden value V.

pub const fn saturating_add(&self, other: u32) -> Self

Saturating integer addition. Computes self + rhs.

Saturates at the numeric bounds instead of overflowing. If the result would equal V it will return V - 1.

pub const fn saturating_sub(&self, other: u32) -> Self

Saturating integer substration. Computes self - rhs.

Saturates at the numeric bounds instead of overflowing. If the result would equal V it will return V + 1.

pub const fn wrapping_add(&self, other: u32) -> Self

Wraping integer addition. Computes self + rhs.

Wraps at the numeric bounds instead of overflowing. If the result would equal V it will return V + 1.

pub const fn wrapping_sub(&self, other: u32) -> Self

Wraping integer subtraction. Computes self - rhs.

Wraps at the numeric bounds instead of overflowing. If the result would equal V it will return V - 1.