pub struct PartiallyAdded(pub Option<usize>);Expand description
๐ชช ๐ฉ The operation could only add a subset of the elements.
๐ data/error
Optionally contains the number of elements that were added.
Tuple Fields
0: Option<usize>Trait Implementations
Sourceimpl Clone for PartiallyAdded
impl Clone for PartiallyAdded
Sourcefn clone(&self) -> PartiallyAdded
fn clone(&self) -> PartiallyAdded
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) ยท Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PartiallyAdded
Sourceimpl Debug for PartiallyAdded
impl Debug for PartiallyAdded
Sourceimpl Default for PartiallyAdded
impl Default for PartiallyAdded
Sourcefn default() -> PartiallyAdded
fn default() -> PartiallyAdded
Returns the โdefault valueโ for a type. Read more
Sourceimpl Display for PartiallyAdded
impl Display for PartiallyAdded
impl Eq for PartiallyAdded
Sourceimpl Error for PartiallyAdded
impl Error for PartiallyAdded
1.30.0 ยท Sourcefn source(&self) -> Option<&(dyn Error + 'static)> โ
fn source(&self) -> Option<&(dyn Error + 'static)> โ
Returns the lower-level source of this error, if any. Read more
1.0.0 ยท Sourcefn description(&self) -> &str โ
fn description(&self) -> &str โ
๐Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl From<PartiallyAdded> for PartialSpace
impl From<PartiallyAdded> for PartialSpace
Sourcefn from(_f: PartiallyAdded) -> PartialSpace
fn from(_f: PartiallyAdded) -> PartialSpace
Converts to this type from the input type.
Sourceimpl Hash for PartiallyAdded
impl Hash for PartiallyAdded
Sourceimpl PartialEq for PartiallyAdded
impl PartialEq for PartiallyAdded
Sourcefn eq(&self, other: &PartiallyAdded) -> bool
fn eq(&self, other: &PartiallyAdded) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PartiallyAdded
Sourceimpl TryFrom<PartialSpace> for PartiallyAdded
impl TryFrom<PartialSpace> for PartiallyAdded
Sourcetype Error = FailedErrorConversion
type Error = FailedErrorConversion
The type returned in the event of a conversion error.
Sourcefn try_from(_f: PartialSpace) -> Result<PartiallyAdded, Self::Error> โ
fn try_from(_f: PartialSpace) -> Result<PartiallyAdded, Self::Error> โ
Performs the conversion.