RcWeak

Struct RcWeak 

1.4.0 ยท Source
pub struct RcWeak<T, A = Global>
where A: Allocator, T: ?Sized,
{ /* private fields */ }
Available on crate features alloc only.
๐Ÿซ— ๐Ÿƒ alloc A version of Rc that holds a non-owning ref to the managed allocation.


๐Ÿ“sys::mem re-exported from alloc::rc ::Weak as RcWeak



๐Ÿ“œ
Weak is a version of Rc that holds a non-owning reference to the managed allocation.

The allocation is accessed by calling upgrade on the Weak pointer, which returns an Option<Rc<T>>.

Since a Weak reference does not count towards ownership, it will not prevent the value stored in the allocation from being dropped, and Weak itself makes no guarantees about the value still being present. Thus it may return None when upgraded. Note however that a Weak reference does prevent the allocation itself (the backing store) from being deallocated.

A Weak pointer is useful for keeping a temporary reference to the allocation managed by Rc without preventing its inner value from being dropped. It is also used to prevent circular references between Rc pointers, since mutual owning references would never allow either Rc to be dropped. For example, a tree could have strong Rc pointers from parent nodes to children, and Weak pointers from children back to their parents.

The typical way to obtain a Weak pointer is to call Rc::downgrade.

Implementations

Source

impl<T> Weak<T>

1.10.0 (const: 1.73.0) ยท Source

pub const fn new() -> Weak<T>

Constructs a new Weak<T>, without allocating any memory. Calling upgrade on the return value always gives None.

Examples
use std::rc::Weak;

let empty: Weak<i64> = Weak::new();
assert!(empty.upgrade().is_none());
Source

impl<T, A> Weak<T, A>
where A: Allocator,

pub fn new_in(alloc: A) -> Weak<T, A>

๐Ÿ”ฌThis is a nightly-only experimental API. (allocator_api)

Constructs a new Weak<T>, without allocating any memory, technically in the provided allocator. Calling upgrade on the return value always gives None.

Examples
use std::rc::Weak;

let empty: Weak<i64> = Weak::new();
assert!(empty.upgrade().is_none());
Source

impl<T> Weak<T>
where T: ?Sized,

1.45.0 ยท Source

pub unsafe fn from_raw(ptr: *const T) -> Weak<T>

Converts a raw pointer previously created by into_raw back into Weak<T>.

This can be used to safely get a strong reference (by calling upgrade later) or to deallocate the weak count by dropping the Weak<T>.

It takes ownership of one weak reference (with the exception of pointers created by new, as these donโ€™t own anything; the method still works on them).

Safety

The pointer must have originated from the into_raw and must still own its potential weak reference, and ptr must point to a block of memory allocated by the global allocator.

It is allowed for the strong count to be 0 at the time of calling this. Nevertheless, this takes ownership of one weak reference currently represented as a raw pointer (the weak count is not modified by this operation) and therefore it must be paired with a previous call to into_raw.

Examples
use std::rc::{Rc, Weak};

let strong = Rc::new("hello".to_owned());

let raw_1 = Rc::downgrade(&strong).into_raw();
let raw_2 = Rc::downgrade(&strong).into_raw();

assert_eq!(2, Rc::weak_count(&strong));

assert_eq!("hello", &*unsafe { Weak::from_raw(raw_1) }.upgrade().unwrap());
assert_eq!(1, Rc::weak_count(&strong));

drop(strong);

// Decrement the last weak count.
assert!(unsafe { Weak::from_raw(raw_2) }.upgrade().is_none());
1.45.0 ยท Source

pub fn into_raw(self) -> *const T

Consumes the Weak<T> and turns it into a raw pointer.

This converts the weak pointer into a raw pointer, while still preserving the ownership of one weak reference (the weak count is not modified by this operation). It can be turned back into the Weak<T> with from_raw.

The same restrictions of accessing the target of the pointer as with as_ptr apply.

Examples
use std::rc::{Rc, Weak};

let strong = Rc::new("hello".to_owned());
let weak = Rc::downgrade(&strong);
let raw = weak.into_raw();

assert_eq!(1, Rc::weak_count(&strong));
assert_eq!("hello", unsafe { &*raw });

drop(unsafe { Weak::from_raw(raw) });
assert_eq!(0, Rc::weak_count(&strong));
Source

impl<T, A> Weak<T, A>
where A: Allocator, T: ?Sized,

pub fn allocator(&self) -> &A

๐Ÿ”ฌThis is a nightly-only experimental API. (allocator_api)

Returns a reference to the underlying allocator.

1.45.0 ยท Source

pub fn as_ptr(&self) -> *const T

Returns a raw pointer to the object T pointed to by this Weak<T>.

The pointer is valid only if there are some strong references. The pointer may be dangling, unaligned or even null otherwise.

Examples
use std::rc::Rc;
use std::ptr;

let strong = Rc::new("hello".to_owned());
let weak = Rc::downgrade(&strong);
// Both point to the same object
assert!(ptr::eq(&*strong, weak.as_ptr()));
// The strong here keeps it alive, so we can still access the object.
assert_eq!("hello", unsafe { &*weak.as_ptr() });

drop(strong);
// But not any more. We can do weak.as_ptr(), but accessing the pointer would lead to
// undefined behavior.
// assert_eq!("hello", unsafe { &*weak.as_ptr() });
pub fn into_raw_with_allocator(self) -> (*const T, A) โ“˜

๐Ÿ”ฌThis is a nightly-only experimental API. (allocator_api)

Consumes the Weak<T>, returning the wrapped pointer and allocator.

This converts the weak pointer into a raw pointer, while still preserving the ownership of one weak reference (the weak count is not modified by this operation). It can be turned back into the Weak<T> with from_raw_in.

The same restrictions of accessing the target of the pointer as with as_ptr apply.

Examples
#![feature(allocator_api)]
use std::rc::{Rc, Weak};
use std::alloc::System;

let strong = Rc::new_in("hello".to_owned(), System);
let weak = Rc::downgrade(&strong);
let (raw, alloc) = weak.into_raw_with_allocator();

assert_eq!(1, Rc::weak_count(&strong));
assert_eq!("hello", unsafe { &*raw });

drop(unsafe { Weak::from_raw_in(raw, alloc) });
assert_eq!(0, Rc::weak_count(&strong));
pub unsafe fn from_raw_in(ptr: *const T, alloc: A) -> Weak<T, A>

๐Ÿ”ฌThis is a nightly-only experimental API. (allocator_api)

Converts a raw pointer previously created by into_raw back into Weak<T>.

This can be used to safely get a strong reference (by calling upgrade later) or to deallocate the weak count by dropping the Weak<T>.

It takes ownership of one weak reference (with the exception of pointers created by new, as these donโ€™t own anything; the method still works on them).

Safety

The pointer must have originated from the into_raw and must still own its potential weak reference, and ptr must point to a block of memory allocated by alloc.

It is allowed for the strong count to be 0 at the time of calling this. Nevertheless, this takes ownership of one weak reference currently represented as a raw pointer (the weak count is not modified by this operation) and therefore it must be paired with a previous call to into_raw.

Examples
use std::rc::{Rc, Weak};

let strong = Rc::new("hello".to_owned());

let raw_1 = Rc::downgrade(&strong).into_raw();
let raw_2 = Rc::downgrade(&strong).into_raw();

assert_eq!(2, Rc::weak_count(&strong));

assert_eq!("hello", &*unsafe { Weak::from_raw(raw_1) }.upgrade().unwrap());
assert_eq!(1, Rc::weak_count(&strong));

drop(strong);

// Decrement the last weak count.
assert!(unsafe { Weak::from_raw(raw_2) }.upgrade().is_none());
1.4.0 ยท Source

pub fn upgrade(&self) -> Option<Rc<T, A>> โ“˜
where A: Clone,

Attempts to upgrade the Weak pointer to an Rc, delaying dropping of the inner value if successful.

Returns None in the following cases:

  1. The inner value has since been dropped or moved out.

  2. This Weak does not point to an allocation.

  3. The owning reference this Weak is associated with is either not fully-constructed or does not allow an upgrade.

Examples
use std::rc::Rc;

let five = Rc::new(5);

let weak_five = Rc::downgrade(&five);

let strong_five: Option<Rc<_>> = weak_five.upgrade();
assert!(strong_five.is_some());

// Destroy all strong pointers.
drop(strong_five);
drop(five);

assert!(weak_five.upgrade().is_none());
1.41.0 ยท Source

pub fn strong_count(&self) -> usize

Gets the number of strong (Rc) pointers pointing to this allocation.

If self was created using Weak::new, this will return 0.

1.41.0 ยท Source

pub fn weak_count(&self) -> usize

Gets the number of Weak pointers pointing to this allocation.

If no strong pointers remain, this will return zero.

1.39.0 ยท Source

pub fn ptr_eq(&self, other: &Weak<T, A>) -> bool

Returns true if the two Weaks point to the same allocation similar to ptr::eq, or if both donโ€™t point to any allocation (because they were created with Weak::new()). However, this function ignores the metadata of dyn Trait pointers.

Notes

Since this compares pointers it means that Weak::new() will equal each other, even though they donโ€™t point to any allocation.

Examples
use std::rc::Rc;

let first_rc = Rc::new(5);
let first = Rc::downgrade(&first_rc);
let second = Rc::downgrade(&first_rc);

assert!(first.ptr_eq(&second));

let third_rc = Rc::new(5);
let third = Rc::downgrade(&third_rc);

assert!(!first.ptr_eq(&third));

Comparing Weak::new.

use std::rc::{Rc, Weak};

let first = Weak::new();
let second = Weak::new();
assert!(first.ptr_eq(&second));

let third_rc = Rc::new(());
let third = Rc::downgrade(&third_rc);
assert!(!first.ptr_eq(&third));