SliceIterMut

Struct SliceIterMut 

pub struct SliceIterMut<'s, T> { /* private fields */ }
๐Ÿ”„ ๐Ÿƒ A lending iterator over an exclusive slice.


๐Ÿ“ sys/mem/view

๐Ÿ“ฆ size_of::<SliceIterMut<'_, char>>() == 16 bytes / 128 bits #๏ธโƒฃ #[cfg(target_pointer_width = โ€œ32โ€)]

๐Ÿ“ฆ size_of::<SliceIterMut<'_, char>>() == 32 bytes / 256 bits #๏ธโƒฃ #[cfg(target_pointer_width = โ€œ64โ€)]


Yields &mut T references in index order.

The returned reference is tied to the temporary mutable borrow of the iterator taken by next, matching the IteratorLending contract.

Examples

let mut array = [0, 1, 2, 3];
let mut it = SliceIterMut::new(&mut array);
while let Some(x) = it.next() {
    *x += 1;
}
assert_eq![array.as_slice(), &[1, 2, 3, 4]];

Implementations

Source

impl<'s, T> SliceIterMut<'s, T>

pub fn new(slice: &'s mut [T]) -> Self

Creates an iterator over the given exclusive slice starting at index 0.