pub struct Stdio(/* private fields */);std only.Expand description
🖥️ ⬡ 🔌
std
Specifies how to handle standard I/O streams in Command.
📍work/process re-exported from std::process
📜
Describes what to do with a standard I/O stream for a child process when
passed to the stdin, stdout, and stderr methods of Command.
Implementations
Sourceimpl Stdio
impl Stdio
1.0.0 · Sourcepub fn piped() -> Stdio
pub fn piped() -> Stdio
A new pipe should be arranged to connect the parent and child processes.
Examples
With stdout:
use std::process::{Command, Stdio};
let output = Command::new("echo")
.arg("Hello, world!")
.stdout(Stdio::piped())
.output()
.expect("Failed to execute command");
assert_eq!(String::from_utf8_lossy(&output.stdout), "Hello, world!\n");
// Nothing echoed to consoleWith stdin:
use std::io::Write;
use std::process::{Command, Stdio};
let mut child = Command::new("rev")
.stdin(Stdio::piped())
.stdout(Stdio::piped())
.spawn()
.expect("Failed to spawn child process");
let mut stdin = child.stdin.take().expect("Failed to open stdin");
std::thread::spawn(move || {
stdin.write_all("Hello, world!".as_bytes()).expect("Failed to write to stdin");
});
let output = child.wait_with_output().expect("Failed to read stdout");
assert_eq!(String::from_utf8_lossy(&output.stdout), "!dlrow ,olleH");Writing more than a pipe buffer’s worth of input to stdin without also reading stdout and stderr at the same time may cause a deadlock. This is an issue when running any program that doesn’t guarantee that it reads its entire stdin before writing more than a pipe buffer’s worth of output. The size of a pipe buffer varies on different targets.
1.0.0 · Sourcepub fn inherit() -> Stdio
pub fn inherit() -> Stdio
The child inherits from the corresponding parent descriptor.
Examples
With stdout:
use std::process::{Command, Stdio};
let output = Command::new("echo")
.arg("Hello, world!")
.stdout(Stdio::inherit())
.output()
.expect("Failed to execute command");
assert_eq!(String::from_utf8_lossy(&output.stdout), "");
// "Hello, world!" echoed to consoleWith stdin:
use std::process::{Command, Stdio};
use std::io::{self, Write};
let output = Command::new("rev")
.stdin(Stdio::inherit())
.stdout(Stdio::piped())
.output()?;
print!("You piped in the reverse of: ");
io::stdout().write_all(&output.stdout)?;1.0.0 · Sourcepub fn null() -> Stdio
pub fn null() -> Stdio
This stream will be ignored. This is the equivalent of attaching the
stream to /dev/null.
Examples
With stdout:
use std::process::{Command, Stdio};
let output = Command::new("echo")
.arg("Hello, world!")
.stdout(Stdio::null())
.output()
.expect("Failed to execute command");
assert_eq!(String::from_utf8_lossy(&output.stdout), "");
// Nothing echoed to consoleWith stdin:
use std::process::{Command, Stdio};
let output = Command::new("rev")
.stdin(Stdio::null())
.stdout(Stdio::piped())
.output()
.expect("Failed to execute command");
assert_eq!(String::from_utf8_lossy(&output.stdout), "");
// Ignores any piped-in inputSourcepub fn makes_pipe(&self) -> bool
🔬This is a nightly-only experimental API. (stdio_makes_pipe)
pub fn makes_pipe(&self) -> bool
stdio_makes_pipe)Trait Implementations
1.20.0 · Sourceimpl From<ChildStderr> for Stdio
impl From<ChildStderr> for Stdio
Sourcefn from(child: ChildStderr) -> Stdio
fn from(child: ChildStderr) -> Stdio
Converts a ChildStderr into a Stdio.
Examples
use std::process::{Command, Stdio};
let reverse = Command::new("rev")
.arg("non_existing_file.txt")
.stderr(Stdio::piped())
.spawn()
.expect("failed reverse command");
let cat = Command::new("cat")
.arg("-")
.stdin(reverse.stderr.unwrap()) // Converted into a Stdio here
.output()
.expect("failed echo command");
assert_eq!(
String::from_utf8_lossy(&cat.stdout),
"rev: cannot open non_existing_file.txt: No such file or directory\n"
);1.20.0 · Sourceimpl From<ChildStdin> for Stdio
impl From<ChildStdin> for Stdio
Sourcefn from(child: ChildStdin) -> Stdio
fn from(child: ChildStdin) -> Stdio
Converts a ChildStdin into a Stdio.
Examples
ChildStdin will be converted to Stdio using Stdio::from under the hood.
use std::process::{Command, Stdio};
let reverse = Command::new("rev")
.stdin(Stdio::piped())
.spawn()
.expect("failed reverse command");
let _echo = Command::new("echo")
.arg("Hello, world!")
.stdout(reverse.stdin.unwrap()) // Converted into a Stdio here
.output()
.expect("failed echo command");
// "!dlrow ,olleH" echoed to console1.20.0 · Sourceimpl From<ChildStdout> for Stdio
impl From<ChildStdout> for Stdio
Sourcefn from(child: ChildStdout) -> Stdio
fn from(child: ChildStdout) -> Stdio
Converts a ChildStdout into a Stdio.
Examples
ChildStdout will be converted to Stdio using Stdio::from under the hood.
use std::process::{Command, Stdio};
let hello = Command::new("echo")
.arg("Hello, world!")
.stdout(Stdio::piped())
.spawn()
.expect("failed echo command");
let reverse = Command::new("rev")
.stdin(hello.stdout.unwrap()) // Converted into a Stdio here
.output()
.expect("failed reverse command");
assert_eq!(reverse.stdout, b"!dlrow ,olleH\n");1.20.0 · Sourceimpl From<File> for Stdio
impl From<File> for Stdio
Sourcefn from(file: File) -> Stdio
fn from(file: File) -> Stdio
Examples
File will be converted to Stdio using Stdio::from under the hood.
use std::fs::File;
use std::process::Command;
// With the `foo.txt` file containing "Hello, world!"
let file = File::open("foo.txt")?;
let reverse = Command::new("rev")
.stdin(file) // Implicit File conversion into a Stdio
.output()?;
assert_eq!(reverse.stdout, b"!dlrow ,olleH");1.87.0 · Sourceimpl From<PipeReader> for Stdio
impl From<PipeReader> for Stdio
Sourcefn from(pipe: PipeReader) -> Stdio
fn from(pipe: PipeReader) -> Stdio
1.87.0 · Sourceimpl From<PipeWriter> for Stdio
impl From<PipeWriter> for Stdio
Sourcefn from(pipe: PipeWriter) -> Stdio
fn from(pipe: PipeWriter) -> Stdio