SystemInstant

Struct SystemInstant 

1.8.0 ยท Source
pub struct SystemInstant(/* private fields */);
Available on crate features std only.
๐Ÿ•˜ std A measurement of a monotonically nondecreasing clock.


๐Ÿ“phys/time/source re-exported from std::time ::Instant as SystemInstant



๐Ÿ“œ
A measurement of a monotonically nondecreasing clock. Opaque and useful only with Duration.

Instants are always guaranteed, barring platform bugs, to be no less than any previously measured instant when created, and are often useful for tasks such as measuring benchmarks or timing how long an operation takes.

Note, however, that instants are not guaranteed to be steady. In other words, each tick of the underlying clock might not be the same length (e.g. some seconds may be longer than others). An instant may jump forwards or experience time dilation (slow down or speed up), but it will never go backwards. As part of this non-guarantee it is also not specified whether system suspends count as elapsed time or not. The behavior varies across platforms and Rust versions.

Instants are opaque types that can only be compared to one another. There is no method to get โ€œthe number of secondsโ€ from an instant. Instead, it only allows measuring the duration between two instants (or comparing two instants).

The size of an Instant struct may vary depending on the target operating system.

Example:

use std::time::{Duration, Instant};
use std::thread::sleep;

fn main() {
   let now = Instant::now();

   // we sleep for 2 seconds
   sleep(Duration::new(2, 0));
   // it prints '2'
   println!("{}", now.elapsed().as_secs());
}

OS-specific behaviors

An Instant is a wrapper around system-specific types and it may behave differently depending on the underlying operating system. For example, the following snippet is fine on Linux but panics on macOS:

use std::time::{Instant, Duration};

let now = Instant::now();
let days_per_10_millennia = 365_2425;
let solar_seconds_per_day = 60 * 60 * 24;
let millennium_in_solar_seconds = 31_556_952_000;
assert_eq!(millennium_in_solar_seconds, days_per_10_millennia * solar_seconds_per_day / 10);

let duration = Duration::new(millennium_in_solar_seconds, 0);
println!("{:?}", now + duration);

For cross-platform code, you can comfortably use durations of up to around one hundred years.

Underlying System calls

The following system calls are currently being used by now() to find out the current time:

PlatformSystem call
SGXinsecure_time usercall. More information on timekeeping in SGX
UNIXclock_gettime with CLOCK_MONOTONIC
WASIclock_gettime with CLOCK_MONOTONIC
Darwinclock_gettime with CLOCK_UPTIME_RAW
VXWorksclock_gettime with CLOCK_MONOTONIC
SOLIDget_tim
WindowsQueryPerformanceCounter

Disclaimer: These system calls might change over time.

Note: mathematical operations like add may panic if the underlying structure cannot represent the new point in time.

Monotonicity

On all platforms Instant will try to use an OS API that guarantees monotonic behavior if available, which is the case for all tier 1 platforms. In practice such guarantees are โ€“ under rare circumstances โ€“ broken by hardware, virtualization or operating system bugs. To work around these bugs and platforms not offering monotonic clocks duration_since, elapsed and sub saturate to zero. In older Rust versions this lead to a panic instead. checked_duration_since can be used to detect and handle situations where monotonicity is violated, or Instants are subtracted in the wrong order.

This workaround obscures programming errors where earlier and later instants are accidentally swapped. For this reason future Rust versions may reintroduce panics.

Implementations

Source

impl Instant

1.8.0 ยท Source

pub fn now() -> Instant

Returns an instant corresponding to โ€œnowโ€.

Examples
use std::time::Instant;

let now = Instant::now();
1.8.0 ยท Source

pub fn duration_since(&self, earlier: Instant) -> Duration

Returns the amount of time elapsed from another instant to this one, or zero duration if that instant is later than this one.

Panics

Previous Rust versions panicked when earlier was later than self. Currently this method saturates. Future versions may reintroduce the panic in some circumstances. See Monotonicity.

Examples
use std::time::{Duration, Instant};
use std::thread::sleep;

let now = Instant::now();
sleep(Duration::new(1, 0));
let new_now = Instant::now();
println!("{:?}", new_now.duration_since(now));
println!("{:?}", now.duration_since(new_now)); // 0ns
1.39.0 ยท Source

pub fn checked_duration_since(&self, earlier: Instant) -> Option<Duration> โ“˜

Returns the amount of time elapsed from another instant to this one, or None if that instant is later than this one.

Due to monotonicity bugs, even under correct logical ordering of the passed Instants, this method can return None.

Examples
use std::time::{Duration, Instant};
use std::thread::sleep;

let now = Instant::now();
sleep(Duration::new(1, 0));
let new_now = Instant::now();
println!("{:?}", new_now.checked_duration_since(now));
println!("{:?}", now.checked_duration_since(new_now)); // None
1.39.0 ยท Source

pub fn saturating_duration_since(&self, earlier: Instant) -> Duration

Returns the amount of time elapsed from another instant to this one, or zero duration if that instant is later than this one.

Examples
use std::time::{Duration, Instant};
use std::thread::sleep;

let now = Instant::now();
sleep(Duration::new(1, 0));
let new_now = Instant::now();
println!("{:?}", new_now.saturating_duration_since(now));
println!("{:?}", now.saturating_duration_since(new_now)); // 0ns
1.8.0 ยท Source

pub fn elapsed(&self) -> Duration

Returns the amount of time elapsed since this instant.

Panics

Previous Rust versions panicked when the current time was earlier than self. Currently this method returns a Duration of zero in that case. Future versions may reintroduce the panic. See Monotonicity.

Examples
use std::thread::sleep;
use std::time::{Duration, Instant};

let instant = Instant::now();
let three_secs = Duration::from_secs(3);
sleep(three_secs);
assert!(instant.elapsed() >= three_secs);
1.34.0 ยท Source

pub fn checked_add(&self, duration: Duration) -> Option<Instant> โ“˜

Returns Some(t) where t is the time self + duration if t can be represented as Instant (which means itโ€™s inside the bounds of the underlying data structure), None otherwise.

1.34.0 ยท Source

pub fn checked_sub(&self, duration: Duration) -> Option<Instant> โ“˜

Returns Some(t) where t is the time self - duration if t can be represented as Instant (which means itโ€™s inside the bounds of the underlying data structure), None otherwise.