pub struct TryFromIntError(/* private fields */);Expand description
⅀ 🚩
core
The error type returned when a checked integral type conversion fails.
📍num/grain/niche re-exported from core::num
📜
The error type returned when a checked integral type conversion fails.
Implementations
Sourceimpl TryFromIntError
impl TryFromIntError
Sourcepub const fn kind(&self) -> &IntErrorKind
🔬This is a nightly-only experimental API. (try_from_int_error_kind)
pub const fn kind(&self) -> &IntErrorKind
try_from_int_error_kind)Outputs the detailed cause of converting an integer failing.