#[repr(C)]pub struct WebEventMouse {
pub x: js_number,
pub y: js_number,
pub button: u8,
pub buttons: u8,
pub mods: KeyMods,
pub etype: WebEventKind,
pub timestamp: JsInstant,
}event and web only.Expand description
๐ซ ๐ A web API Mouse Event.
๐ sys/os/browser/web
๐ฆ size_of::<WebEventMouse>() == 32 bytes / 256 bits
โ๏ธOption<T>
Represents a JavaScript mouse event containing relevant properties.
Compatibility
Browser Back/Forward mouse buttons are backend-dependent.
Chromium exposes them as DOM mouse events (button 3/4, buttons 8/16).
Firefox currently may consume them for history navigation before the page
receives mousedown/mouseup.
Fields
x: js_numberThe X-coordinate of the mouse event relative to the viewport.
y: js_numberThe Y-coordinate of the mouse event relative to the viewport.
Raw DOM-compatible button value.
Uses 255 to represent DOM button = -1, meaning no button changed.
Raw DOM buttons bitmask for buttons currently held down.
mods: KeyModsA bitmask of active keyboard modifiers during the mouse event.
etype: WebEventKindThe type of mouse event (Click, MouseDown, MouseMove, etc.).
timestamp: JsInstantThe JavaScript event timestamp.
Implementations
Sourceimpl WebEventMouse
impl WebEventMouse
Sourcepub const fn new(
x: js_number,
y: js_number,
button: u8,
buttons: u8,
mods: KeyMods,
etype: WebEventKind,
timestamp: JsInstant,
) -> Self
pub const fn new( x: js_number, y: js_number, button: u8, buttons: u8, mods: KeyMods, etype: WebEventKind, timestamp: JsInstant, ) -> Self
Returns a new WebEventMouse.
Sourceimpl WebEventMouse
impl WebEventMouse
Returns the normalized triggering button, or None when no button changed.
Returns the raw DOM-compatible button value.
Returns 255 for DOM button = -1, meaning no button changed.
Returns the normalized held-button set.
Returns the raw DOM buttons bitmask.
Sourcepub const fn to_kind_timed(self) -> EventKindTimed
pub const fn to_kind_timed(self) -> EventKindTimed
Converts WebEventMouse to EventKindTimed.
Sourcepub const fn from_event_mouse_timed(
from: Timed<EventMouse, Option<EventTimestamp>>,
) -> WebEventMouse
pub const fn from_event_mouse_timed( from: Timed<EventMouse, Option<EventTimestamp>>, ) -> WebEventMouse
Converts a timed normalized EventMouse back to WebEventMouse.