Default

Trait Default 

1.0.0 (const: unstable) ยท Source
pub trait Default: Sized {
    // Required method
    fn default() -> Self;
}
๐ŸŒฑ core A trait for giving a type a useful default value. (Derivable)


๐Ÿ“code re-exported from core::default



๐Ÿ“œ
A trait for giving a type a useful default value.

Sometimes, you want to fall back to some kind of default value, and donโ€™t particularly care what it is. This comes up often with structs that define a set of options:

struct SomeOptions {
    foo: i32,
    bar: f32,
}

How can we define some default values? You can use Default:

#[derive(Default)]
struct SomeOptions {
    foo: i32,
    bar: f32,
}

fn main() {
    let options: SomeOptions = Default::default();
}

Now, you get all of the default values. Rust implements Default for various primitive types.

If you want to override a particular option, but still retain the other defaults:

fn main() {
    let options = SomeOptions { foo: 42, ..Default::default() };
}

Derivable

This trait can be used with #[derive] if all of the typeโ€™s fields implement Default. When derived, it will use the default value for each fieldโ€™s type.

enums

When using #[derive(Default)] on an enum, you need to choose which unit variant will be default. You do this by placing the #[default] attribute on the variant.

#[derive(Default)]
enum Kind {
    #[default]
    A,
    B,
    C,
}

You cannot use the #[default] attribute on non-unit or non-exhaustive variants.

The #[default] attribute was stabilized in Rust 1.62.0.

How can I implement Default?

Provide an implementation for the default() method that returns the value of your type that should be the default:

enum Kind {
    A,
    B,
    C,
}

impl Default for Kind {
    fn default() -> Self { Kind::A }
}

Examples

#[derive(Default)]
struct SomeOptions {
    foo: i32,
    bar: f32,
}

Required Methods

1.0.0 (const: unstable) ยท Source

fn default() -> Self

Returns the โ€œdefault valueโ€ for a type.

Default values are often some kind of initial value, identity value, or anything else that may make sense as a default.

Examples

Using built-in default values:

let i: i8 = Default::default();
let (x, y): (Option<String>, f64) = Default::default();
let (a, b, (c, d)): (i32, u32, (bool, bool)) = Default::default();

Making your own:

enum Kind {
    A,
    B,
    C,
}

impl Default for Kind {
    fn default() -> Self { Kind::A }
}

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

1.10.0 (const: unstable) ยท Source

impl Default for &CStr

1.9.0 ยท Source

impl Default for &OsStr

1.28.0 (const: unstable) ยท Source

impl Default for &mut str

1.0.0 (const: unstable) ยท Source

impl Default for &str

1.0.0 (const: unstable) ยท Source

impl Default for ()

Source

impl Default for Abi

Source

impl Default for Adler32

Source

impl Default for Alignment

Returns Alignment::MIN, which is valid for any type.

Source

impl Default for AngleDirection

Source

impl Default for AngleKind

Source

impl Default for AnsiColor3

Available on crate feature term only.
Source

impl Default for AppControlSet

1.80.0 ยท Source

impl Default for alloc::sync::Arc<CStr>

Available on non-no_global_oom_handling only.
1.80.0 ยท Source

impl Default for alloc::sync::Arc<str>

Available on non-no_global_oom_handling only.


impl Default for devela::zall::Arc<str>

Available on non-portable_atomic_no_min_const_generics only.
1.0.0 (const: unstable) ยท Source

impl Default for AsciiChar

Source

impl Default for AsciiSet

1.0.0 ยท Source

impl Default for core::sync::atomic::Atomic<bool>

Available on target_has_atomic_load_store=8 only.
1.34.0 ยท Source

impl Default for core::sync::atomic::Atomic<i8>

1.34.0 ยท Source

impl Default for core::sync::atomic::Atomic<i16>

1.34.0 ยท Source

impl Default for core::sync::atomic::Atomic<i32>

1.34.0 ยท Source

impl Default for core::sync::atomic::Atomic<i64>

1.0.0 ยท Source

impl Default for core::sync::atomic::Atomic<isize>

1.34.0 ยท Source

impl Default for core::sync::atomic::Atomic<u8>

1.34.0 ยท Source

impl Default for core::sync::atomic::Atomic<u16>

1.34.0 ยท Source

impl Default for core::sync::atomic::Atomic<u32>

1.34.0 ยท Source

impl Default for core::sync::atomic::Atomic<u64>

1.0.0 ยท Source

impl Default for core::sync::atomic::Atomic<usize>



impl Default for AtomicBool



impl Default for AtomicF32



impl Default for AtomicF64



impl Default for AtomicI8



impl Default for AtomicI16



impl Default for AtomicI32



impl Default for AtomicI64



impl Default for AtomicI128



impl Default for AtomicIsize



impl Default for AtomicU8



impl Default for AtomicU16



impl Default for AtomicU32



impl Default for AtomicU64



impl Default for AtomicU128



impl Default for AtomicUsize

Source

impl Default for AudioChannel

Available on crate feature audio only.
Source

impl Default for AudioChannels

Available on crate feature audio only.
Source

impl Default for AudioDeviceDir

Source

impl Default for AudioStreamDir

Source

impl Default for BinTag4

Source

impl Default for BitfieldExample

Available on crate features _docs_examples only.
1.17.0 ยท Source

impl Default for Box<CStr>

1.17.0 ยท Source

impl Default for Box<OsStr>

1.17.0 ยท Source

impl Default for Box<str>

Available on non-no_global_oom_handling only.
Source

impl Default for Boxed

Available on crate feature alloc only.


impl Default for BrokenDownTime

Source

impl Default for ByteString

1.10.0 ยท Source

impl Default for CString

Source

impl Default for CharAscii

Source

impl Default for ColorDepth

Source

impl Default for std::sync::nonpoison::condvar::Condvar

1.10.0 ยท Source

impl Default for devela::zall::Condvar



impl Default for CpuId<CpuIdReaderNative>

Available on x86 and target feature sse and non-SGX, or x86-64 and non-SGX only.


impl Default for Date



impl Default for DateTime



impl Default for DateTimeRound



impl Default for DefaultCustom



impl Default for DefaultHashBuilder

1.13.0 (const: unstable) ยท Source

impl Default for DefaultHasher

Source

impl Default for DefaultRandomSource

Source

impl Default for DeviceId

Available on crate feature event only.
Source

impl Default for DiagLevel



impl Default for Disambiguation

1.3.0 ยท Source

impl Default for Duration

Source

impl Default for ElementNotFound

1.0.0 ยท Source

impl Default for devela::zall::IoEmpty

Source

impl Default for EnumSetExample

Available on doc or test only.
1.0.0 ยท Source

impl Default for Error

Source

impl Default for Event

Available on crate feature event only.
Source

impl Default for EventButton

Available on crate feature event only.
Source

impl Default for EventButtonState

Available on crate feature event only.
Source

impl Default for EventButtons

Available on crate feature event only.
Source

impl Default for EventKey

Available on crate feature event only.
Source

impl Default for EventKeyFfi

Available on ffiยทยท only.
Source

impl Default for EventKind

Available on crate feature event only.
Source

impl Default for EventTag

Available on crate feature event only.
Source

impl Default for EventTagSet

Available on crate feature event only.
Source

impl Default for EventTarget

Available on crate feature event only.
Source

impl Default for EventTimestamp

Available on crate feature event only.
Source

impl Default for EventTimestampMode

Available on crate feature event only.
Source

impl Default for EventWheelUnit

Available on crate feature event only.
1.75.0 ยท Source

impl Default for ExitCode

The default value is ExitCode::SUCCESS

1.73.0 ยท Source

impl Default for ExitStatus

The default value is one which indicates successful completion.

Source

impl Default for ExitStatusError

Source

impl Default for FailedErrorConversion

1.75.0 ยท Source

impl Default for FileTimes



impl Default for FinderBuilder



impl Default for FixedState



impl Default for FixedState

Source

impl Default for FmtNumConf

Source

impl Default for FmtNumGroup

Source

impl Default for FmtNumShape

Source

impl Default for FmtNumSign

Source

impl Default for FormattingOptions

Source

impl Default for Global

Source

impl Default for GraphemeMachine

Available on crate feature grapheme only.
Source

impl Default for GraphemeString

Available on crate feature grapheme only.
Source

impl Default for HasherFnv<u32>

Source

impl Default for HasherFnv<u64>

Source

impl Default for HasherFnv<u128>

Source

impl Default for HasherFnv<usize>

Source

impl Default for HasherFx<u32>

Source

impl Default for HasherFx<u64>

Source

impl Default for HasherFx<usize>

Source

impl Default for HasherPengy



impl Default for ISOWeekDate

Source

impl Default for IdPinBox

Available on crate feature alloc only.
Source

impl Default for IncompatibleBounds

Source

impl Default for IndexOutOfBounds

Source

impl Default for InvalidAxisLength

Source

impl Default for InvalidValue

Source

impl Default for JsTextRenderMetrics

Available on crate feature js only.
Source

impl Default for JsTextRenderMetricsFull

Available on crate feature js only.
Source

impl Default for JsTimeout

Available on crate feature js only.
Source

impl Default for Key

Available on crate feature event only.
Source

impl Default for KeyAlreadyExists

Source

impl Default for KeyFfi

Available on ffiยทยท only.
Source

impl Default for KeyMods

Available on crate feature event only.
Source

impl Default for KeyState

Available on crate feature event only.
Source

impl Default for Lcg16

Available on crate feature rand only.

Creates a new PRNG initialized with the default fixed seed.

Source

impl Default for LinuxRandomMode

Available on crate feature linux only.
Source

impl Default for LinuxSigactionFlags

Available on crate feature linux only.
Source

impl Default for LinuxSignalSet

Available on crate feature linux only.
Source

impl Default for LinuxSigset

Available on crate feature linux only.
Source

impl Default for LinuxStat

Available on crate feature linux only.
Source

impl Default for LinuxTermios

Available on crate feature linux only.
Source

impl Default for LinuxTermiosCc

Available on crate feature linux only.
Source

impl Default for LinuxTermiosCharSize

Available on crate feature linux only.
Source

impl Default for LinuxTermiosControlFlags

Available on crate feature linux only.
Source

impl Default for LinuxTermiosInputFlags

Available on crate feature linux only.
Source

impl Default for LinuxTermiosLocalFlags

Available on crate feature linux only.
Source

impl Default for LinuxTermiosOutputFlags

Available on crate feature linux only.
Source

impl Default for LinuxTimespec

Available on crate feature linux only.
Source

impl Default for Md5

Available on crate features _docs_examples only.
Source

impl Default for MemHedgeCtrl

Source

impl Default for MemHedgeError

Source

impl Default for MemHedgeState

Source

impl Default for MismatchedDimensions

Source

impl Default for MismatchedIndices

Source

impl Default for MismatchedSizes

Source

impl Default for NoInverse

Source

impl Default for NodeEmpty

Source

impl Default for NodeLinkNotSet

Source

impl Default for NodeLinkNotUnique

Source

impl Default for NonMaxU8

Source

impl Default for NonMaxU16

Source

impl Default for NonMaxU32

Source

impl Default for NonMaxU64

Source

impl Default for NonMaxU128

Source

impl Default for NonMaxUsize

Source

impl Default for NonMinI8

Source

impl Default for NonMinI16

Source

impl Default for NonMinI32

Source

impl Default for NonMinI64

Source

impl Default for NonMinI128

Source

impl Default for NonMinIsize

Source

impl Default for NonNegativeRequired

Source

impl Default for NonZeroRequired

Source

impl Default for NotEnoughElements

Source

impl Default for NotEnoughSpace

Source

impl Default for NotImplemented

Source

impl Default for NotSupported



impl Default for OffsetConflict



impl Default for OffsetRound

1.9.0 ยท Source

impl Default for OsString

Source

impl Default for Overflow

Source

impl Default for PartiallyAdded

1.17.0 ยท Source

impl Default for PathBuf

Source

impl Default for Pcg32

Creates a new PRNG initialized with the default fixed seed.

Source

impl Default for PcmLayout

Available on crate feature audio only.
Source

impl Default for PcmSample

Available on crate feature audio only.
Source

impl Default for PcmSpec

Available on crate feature audio only.
1.33.0 ยท Source

impl Default for PhantomPinned

Source

impl Default for PositiveRequired



impl Default for PosixCustom



impl Default for PrefilterConfig

Source

impl Default for RandQualities

1.7.0 ยท Source

impl Default for devela::zall::RandomState



impl Default for RandomState



impl Default for RandomState

1.0.0 (const: unstable) ยท Source

impl Default for RangeFull

Source

impl Default for RasterFormat

1.80.0 ยท Source

impl Default for Rc<CStr>

Available on non-no_global_oom_handling only.
1.80.0 ยท Source

impl Default for Rc<str>

Available on non-no_global_oom_handling only.
Source

impl Default for ReprMode

Source

impl Default for RunCap

Source

impl Default for RunCapAudio

Source

impl Default for RunCapColor

Source

impl Default for RunCapImage

Source

impl Default for RunCapInput

Source

impl Default for RunCapSystem

Source

impl Default for RunCapText

Source

impl Default for RunCapWindow

Source

impl Default for RunCycle

Source

impl Default for RunPhase

Source

impl Default for RunSystemInfo



impl Default for SeedableRandomState



impl Default for SeedableRandomState

Source

impl Default for Sha1

Available on crate features _docs_examples only.
Source

impl Default for Sha256

Available on crate features _docs_examples only.
Source

impl Default for Sha512

Available on crate features _docs_examples only.
Source

impl Default for ShellQuote

Available on crate feature shell only.
Source

impl Default for Sign



impl Default for SignedDuration



impl Default for SignedDurationRound

1.0.0 ยท Source

impl Default for Sink

1.0.0 ยท Source

impl Default for SipHasher

Source

impl Default for SixelChar

Available on crate feature term only.
Source

impl Default for SixelColor

Available on crate feature term only.


impl Default for Span



impl Default for SpanFieldwise



impl Default for SpanParser



impl Default for SpanPrinter



impl Default for SpanRound<'static>

Source

impl Default for SplitMix64

Creates SplitMix64::INIT as the default value.

Source

impl Default for StdRand

Available on crate feature std only.
1.0.0 (const: unstable) ยท Source

impl Default for String

1.28.0 ยท Source

impl Default for System

Source

impl Default for TermCaps

Available on crate feature term only.
Source

impl Default for TermColor

Available on crate feature term only.
Source

impl Default for TermColorKind

Available on crate feature term only.
Source

impl Default for TermColorMode

Available on crate feature term only.
Source

impl Default for TermColors

Available on crate feature term only.
Source

impl Default for TermInputParser

Available on crate features event and term only.
Source

impl Default for TermLineMode

Available on crate feature term only.
Source

impl Default for TermMode

Available on crate feature term only.
Source

impl Default for TermPollPolicy

Available on crate feature term only.
Source

impl Default for TermSize

Available on crate feature term only.
Source

impl Default for TermStyle

Available on crate feature term only.
Source

impl Default for TermStyleExt

Available on crate feature term only.
Source

impl Default for TermelMeta

Available on crate feature term only.
Source

impl Default for TermelOccupancy

Available on crate feature term only.
Source

impl Default for TextCursor

Source

impl Default for TextFit

Source

impl Default for TextIndex

Source

impl Default for TextLayout



impl Default for Time

Source

impl Default for TimeDelta

Source

impl Default for TimeFake

Available on target_has_atomic=64 only.


impl Default for TimeRound

Source

impl Default for TimeScale

Source

impl Default for TimeUnixI64

Source

impl Default for TimeUnixU32

Source

impl Default for Timeout



impl Default for Timestamp



impl Default for TimestampRound

Source

impl Default for UnexpectedEof

Source

impl Default for UnitBi

Available on crate feature unit only.
Source

impl Default for UnitSi

Available on crate feature unit only.
Source

impl Default for ValueKind

Source

impl Default for ValueKind4

Source

impl Default for Version

Source

impl Default for WebElement

Available on crate feature web only.
Source

impl Default for WebEventKind

Available on crate features event and web only.
Source

impl Default for WebKeyLocation

Available on crate features event and web only.
Source

impl Default for WebWindowState

Available on crate feature web only.
Source

impl Default for WebWorker

Available on crate feature web only.
Source

impl Default for WindowId

Available on crate feature event only.
Source

impl Default for XRasterRenderer

Source

impl Default for Xabc

Available on crate feature rand only.

Creates a new PRNG initialized with the default fixed seed.

Source

impl Default for XorShift16

Creates a new PRNG initialized with the default fixed seed.

Source

impl Default for XorShift32

Creates a new PRNG initialized with the default fixed seed.

Source

impl Default for XorShift64

Creates a new PRNG initialized with the default fixed seed.

Source

impl Default for XorShift128

Creates a new PRNG initialized with the default fixed seed.

Source

impl Default for XorShift128p

Creates a new PRNG initialized with the default fixed seed.

Source

impl Default for Xoroshiro128pp

Available on crate feature rand only.

Creates a new PRNG initialized with the default fixed seed.

Source

impl Default for Xyza8a

Available on crate feature rand only.

Creates a new PRNG initialized with the default fixed seed.

Source

impl Default for Xyza8b

Available on crate feature rand only.


impl Default for Zoned



impl Default for ZonedRound

1.0.0 (const: unstable) ยท Source

impl Default for bool

1.0.0 (const: unstable) ยท Source

impl Default for char

Source

impl Default for char7

Source

impl Default for char8

Source

impl Default for char16

Source

impl Default for charu

Source

impl Default for charu_niche

1.0.0 (const: unstable) ยท Source

impl Default for f16

1.0.0 (const: unstable) ยท Source

impl Default for f32

1.0.0 (const: unstable) ยท Source

impl Default for f64

Source

impl Default for f32bits

Source

impl Default for f32bits_niche



impl Default for f32x4



impl Default for f32x8



impl Default for f32x16

Source

impl Default for f64bits

Source

impl Default for f64bits_niche



impl Default for f64x2



impl Default for f64x4



impl Default for f64x8

1.0.0 (const: unstable) ยท Source

impl Default for f128

Source

impl Default for g_bvec2

Available on crate feature glsl only.
Source

impl Default for g_bvec3

Available on crate feature glsl only.
Source

impl Default for g_bvec4

Available on crate feature glsl only.
Source

impl Default for g_dmat2

Available on crate feature glsl only.
Source

impl Default for g_dmat3

Available on crate feature glsl only.
Source

impl Default for g_dmat4

Available on crate feature glsl only.
Source

impl Default for g_dvec2

Available on crate feature glsl only.
Source

impl Default for g_dvec3

Available on crate feature glsl only.
Source

impl Default for g_dvec4

Available on crate feature glsl only.
Source

impl Default for g_ivec2

Available on crate feature glsl only.
Source

impl Default for g_ivec3

Available on crate feature glsl only.
Source

impl Default for g_ivec4

Available on crate feature glsl only.
Source

impl Default for g_mat2

Available on crate feature glsl only.
Source

impl Default for g_mat3

Available on crate feature glsl only.
Source

impl Default for g_mat4

Available on crate feature glsl only.
Source

impl Default for g_mat2x3

Available on crate feature glsl only.
Source

impl Default for g_mat2x4

Available on crate feature glsl only.
Source

impl Default for g_mat3x2

Available on crate feature glsl only.
Source

impl Default for g_mat3x4

Available on crate feature glsl only.
Source

impl Default for g_mat4x2

Available on crate feature glsl only.
Source

impl Default for g_mat4x3

Available on crate feature glsl only.
Source

impl Default for g_uvec2

Available on crate feature glsl only.
Source

impl Default for g_uvec3

Available on crate feature glsl only.
Source

impl Default for g_uvec4

Available on crate feature glsl only.
Source

impl Default for g_vec2

Available on crate feature glsl only.
Source

impl Default for g_vec3

Available on crate feature glsl only.
Source

impl Default for g_vec4

Available on crate feature glsl only.
Source

impl Default for g_vertex2

Available on crate feature glsl only.
Source

impl Default for g_vertex3

Available on crate feature glsl only.
1.0.0 (const: unstable) ยท Source

impl Default for i8



impl Default for i8x16



impl Default for i8x32

1.0.0 (const: unstable) ยท Source

impl Default for i16

1.0.0 (const: unstable) ยท Source

impl Default for i32

1.0.0 (const: unstable) ยท Source

impl Default for i64



impl Default for i16x8



impl Default for i16x16



impl Default for i16x32



impl Default for i32x4



impl Default for i32x8



impl Default for i32x16



impl Default for i64x2



impl Default for i64x4



impl Default for i64x8

1.0.0 (const: unstable) ยท Source

impl Default for i128

1.0.0 (const: unstable) ยท Source

impl Default for isize



impl Default for m128



impl Default for m256



impl Default for m512



impl Default for m128d



impl Default for m128i



impl Default for m256d



impl Default for m256i



impl Default for m512d



impl Default for m512i

1.0.0 (const: unstable) ยท Source

impl Default for u8



impl Default for u8x16



impl Default for u8x32

1.0.0 (const: unstable) ยท Source

impl Default for u16

1.0.0 (const: unstable) ยท Source

impl Default for u32

1.0.0 (const: unstable) ยท Source

impl Default for u64



impl Default for u16x8



impl Default for u16x16



impl Default for u16x32



impl Default for u32x4



impl Default for u32x8



impl Default for u32x16



impl Default for u64x2



impl Default for u64x4



impl Default for u64x8

1.0.0 (const: unstable) ยท Source

impl Default for u128

1.0.0 (const: unstable) ยท Source

impl Default for usize

1.70.0 ยท Source

impl<'a, K, V> Default for alloc::collections::btree::map::Iter<'a, K, V>
where K: 'a, V: 'a,

1.70.0 ยท Source

impl<'a, K, V> Default for alloc::collections::btree::map::IterMut<'a, K, V>
where K: 'a, V: 'a,

Source

impl<'a, T: Default + 'a> Default for ConstList<'a, T>

Source

impl<'a> Default for &'a ByteStr

Source

impl<'a> Default for &'a mut ByteStr

Source

impl<'a> Default for AnsiLink<'a>

Available on crate feature term only.
Source

impl<'a> Default for PhantomContravariantLifetime<'a>

Source

impl<'a> Default for PhantomCovariantLifetime<'a>

Source

impl<'a> Default for PhantomInvariantLifetime<'a>

Source

impl<'a> Default for TextScanner<'a>

Source

impl<'a> Default for VersionFull<'a>

1.70.0 ยท Source

impl<A, B> Default for Chain<A, B>
where A: Default, B: Default,

1.97.0 ยท Source

impl<A> Default for RepeatN<A>

Creates an empty iterator, like repeat_n(value, 0) but without needing any such value at hand.

Source

impl<A> Default for VecChunk<A>

Available on crate feature alloc only.
1.11.0 ยท Source

impl<B> Default for Cow<'_, B>
where B: ToOwned + ?Sized, <B as ToOwned>::Owned: Default,

Source

impl<DST: ?Sized, BUF: DstBuf + Default> Default for DstQueue<DST, BUF>

Available on crate feature unsafe_layout only.
Source

impl<DST: ?Sized, BUF: DstBuf + Default> Default for DstStack<DST, BUF>

Available on crate feature unsafe_layout only.
1.7.0 (const: unstable) ยท Source

impl<H> Default for BuildHasherDefault<H>

1.70.0 ยท Source

impl<I> Default for Cloned<I>
where I: Default,

1.70.0 ยท Source

impl<I> Default for Copied<I>
where I: Default,

1.70.0 ยท Source

impl<I> Default for Enumerate<I>
where I: Default,

1.70.0 ยท Source

impl<I> Default for Flatten<I>
where I: Default + Iterator, <I as Iterator>::Item: IntoIterator,

1.70.0 ยท Source

impl<I> Default for Fuse<I>
where I: Default,

1.70.0 ยท Source

impl<I> Default for Rev<I>
where I: Default,

1.0.0 (const: unstable) ยท Source

impl<Idx> Default for core::ops::range::Range<Idx>
where Idx: Default,

1.96.0 (const: unstable) ยท Source

impl<Idx> Default for devela::zall::Range<Idx>
where Idx: Default,



impl<K, A> Default for IntoIter<K, A>
where A: Allocator,

1.70.0 ยท Source

impl<K, V, A> Default for alloc::collections::btree::map::IntoIter<K, V, A>
where A: Allocator + Default + Clone,



impl<K, V, A> Default for IntoIter<K, V, A>
where A: Allocator,

1.70.0 ยท Source

impl<K, V, A> Default for alloc::collections::btree::map::IntoKeys<K, V, A>
where A: Allocator + Default + Clone,



impl<K, V, A> Default for IntoKeys<K, V, A>
where A: Allocator,

1.70.0 ยท Source

impl<K, V, A> Default for alloc::collections::btree::map::IntoValues<K, V, A>
where A: Allocator + Default + Clone,



impl<K, V, A> Default for IntoValues<K, V, A>
where A: Allocator,



impl<K, V, S, A> Default for devela::zall::HashMap<K, V, S, A>
where S: Default, A: Default + Allocator,

1.0.0 (const: unstable) ยท Source

impl<K, V, S> Default for std::collections::hash::map::HashMap<K, V, S>
where S: Default,

1.0.0 ยท Source

impl<K, V> Default for BTreeMap<K, V>

1.83.0 ยท Source

impl<K, V> Default for std::collections::hash::map::IntoIter<K, V>

1.83.0 ยท Source

impl<K, V> Default for std::collections::hash::map::IntoKeys<K, V>

1.83.0 ยท Source

impl<K, V> Default for std::collections::hash::map::IntoValues<K, V>

1.83.0 ยท Source

impl<K, V> Default for std::collections::hash::map::Iter<'_, K, V>



impl<K, V> Default for Iter<'_, K, V>

1.83.0 ยท Source

impl<K, V> Default for std::collections::hash::map::IterMut<'_, K, V>



impl<K, V> Default for IterMut<'_, K, V>

1.83.0 ยท Source

impl<K, V> Default for std::collections::hash::map::Keys<'_, K, V>

1.70.0 ยท Source

impl<K, V> Default for alloc::collections::btree::map::Keys<'_, K, V>



impl<K, V> Default for Keys<'_, K, V>

1.70.0 ยท Source

impl<K, V> Default for alloc::collections::btree::map::Range<'_, K, V>

1.82.0 ยท Source

impl<K, V> Default for RangeMut<'_, K, V>

1.83.0 ยท Source

impl<K, V> Default for std::collections::hash::map::Values<'_, K, V>

1.70.0 ยท Source

impl<K, V> Default for alloc::collections::btree::map::Values<'_, K, V>



impl<K, V> Default for Values<'_, K, V>

1.83.0 ยท Source

impl<K, V> Default for std::collections::hash::map::ValuesMut<'_, K, V>

1.82.0 ยท Source

impl<K, V> Default for alloc::collections::btree::map::ValuesMut<'_, K, V>



impl<K, V> Default for ValuesMut<'_, K, V>

1.83.0 ยท Source

impl<K> Default for std::collections::hash::set::IntoIter<K>

1.83.0 ยท Source

impl<K> Default for std::collections::hash::set::Iter<'_, K>



impl<K> Default for Iter<'_, K>

Source

impl<N: Default, H: Default> Default for Mismatch<N, H>

Source

impl<P: Default, E: Default, const D: usize> Default for Region<P, E, D>

Source

impl<P: Default, E: Default, const D: usize> Default for RegionStrided<P, E, D>

Source

impl<P> Default for MaybeDangling<P>
where P: Default + ?Sized,



impl<R> Default for UnwrapErr<R>
where R: Default + TryRng,

Source

impl<S: Default, C: Default> Default for TermPen<S, C>

Available on crate feature term only.
Source

impl<S: Default, V: Default> Default for Own<S, V>



impl<T, A> Default for HashTable<T, A>
where A: Allocator + Default,

1.70.0 ยท Source

impl<T, A> Default for alloc::collections::btree::set::IntoIter<T, A>
where A: Allocator + Default + Clone,

1.70.0 ยท Source

impl<T, A> Default for alloc::vec::into_iter::IntoIter<T, A>
where A: Allocator + Default,



impl<T, A> Default for IntoIter<T, A>
where A: Allocator,



impl<T, S, A> Default for devela::zall::HashSet<T, S, A>
where S: Default, A: Default + Allocator,

1.0.0 (const: unstable) ยท Source

impl<T, S> Default for std::collections::hash::set::HashSet<T, S>
where S: Default,

Source

impl<T, const CAP: usize> Default for BufferLinearStaticExample<T, [MaybeUninit<T>; CAP]>

Available on crate features _docs_examples only.
Source

impl<T, const CAP: usize> Default for BufferLinearStaticExample<T, [Option<T>; CAP]>

Available on crate features _docs_examples only.
Source

impl<T, const CAP: usize> Default for BufferRingStaticExample<T, [Option<T>; CAP]>

Available on crate features _docs_examples only.
1.89.0 ยท Source

impl<T, const N: usize> Default for core::array::iter::IntoIter<T, N>

Source

impl<T, const N: usize> Default for Mask<T, N>
where T: MaskElement,

Source

impl<T, const N: usize> Default for Simd<T, N>
where T: SimdElement + Default,

Source

impl<T, const VARIANT: u32, const FIELD: u32> Default for FieldRepresentingType<T, VARIANT, FIELD>
where T: ?Sized,

Source

impl<T: Clone> Default for EnumExample<'_, '_, T>

Available on doc or test only.
Source

impl<T: Default + Copy> Default for MaybeNiche<T>

Source

impl<T: Default + Copy> Default for NonNiche<T>

Source

impl<T: Default, B: Default> Default for PcmBuf<T, B>

Available on crate feature audio only.
Source

impl<T: Default, E: Default> Default for CoroManager<T, E>

Source

impl<T: Default, N: Default> Default for CycleCount<T, N>

Source

impl<T: Default, S: Default, C: Default, M: Default> Default for Termel<T, S, C, M>

Available on crate feature term only.
Source

impl<T: Default, const C: usize, const R: usize, const CR: usize, const RMAJ: bool> Default for Array2d<T, C, R, CR, RMAJ, Bare>

Source

impl<T: Default, const C: usize, const R: usize, const CR: usize, const RMAJ: bool> Default for Array2d<T, C, R, CR, RMAJ, Boxed>

Available on crate feature alloc only.
Source

impl<T: Default, const CAP: usize, IDX: Default> Default for Destaque<T, CAP, IDX, Bare>

Available on _destaqueยทยท only.
Source

impl<T: Default, const CAP: usize, IDX: Default> Default for Destaque<T, CAP, IDX, Boxed>

Available on _destaqueยทยท and crate feature alloc only.
Source

impl<T: Default, const CAP: usize, IDX: Default> Default for Stack<T, CAP, IDX, Bare>

Available on _stackยทยท only.
Source

impl<T: Default, const CAP: usize, IDX: Default> Default for Stack<T, CAP, IDX, Boxed>

Available on crate feature alloc only.
Source

impl<T: Default, const CAP: usize, S: Default + Storage> Default for ArrayUninit<T, CAP, S>
where S::Stored<[MaybeUninit<T>; CAP]>: Default,

Available on crate features unsafe_array only.
Source

impl<T: Default, const CAP: usize> Default for Array<T, CAP, Bare>

Source

impl<T: Default, const CAP: usize> Default for Array<T, CAP, Boxed>

Available on crate feature alloc only.
Source

impl<T: Default, const D: usize> Default for Distance<T, D>

Source

impl<T: Default, const D: usize> Default for Extent<T, D>

Source

impl<T: Default, const D: usize> Default for Orientation<T, D>

Source

impl<T: Default, const D: usize> Default for Point<T, D>

Source

impl<T: Default, const D: usize> Default for Position<T, D>

Source

impl<T: Default, const D: usize> Default for Stride<T, D>

Source

impl<T: Default, const D: usize> Default for Vector<T, D>

Available on crate feature lin only.
Source

impl<T: Default, const LINEAR: bool, const LIGHTNESS: bool> Default for Lum<T, LINEAR, LIGHTNESS>

Available on crate feature color only.
Source

impl<T: Default, const LINEAR: bool, const PREMUL: bool> Default for Rgba<T, LINEAR, PREMUL>

Available on crate feature color only.
Source

impl<T: Default, const LINEAR: bool> Default for Rgb<T, LINEAR>

Available on crate feature color only.
Source

impl<T: Default, const SPIN: usize, const YIELD: usize, const SLEEP: u64> Default for SpinLock<T, SPIN, YIELD, SLEEP>

Available on crate feature unsafe_sync only.
Source

impl<T: Default> Default for Angle<T>

Source

impl<T: Default> Default for BareBox<T>

Source

impl<T: Default> Default for CacheAlign<T>

Source

impl<T: Default> Default for Cast<T>

Source

impl<T: Default> Default for Cycle<T>

Source

impl<T: Default> Default for Textel<T>

Source

impl<T: MemPod, const CAP: usize> Default for DstArray<T, CAP>

Available on crate feature unsafe_layout only.
1.0.0 (const: unstable) ยท Source

impl<T> Default for &[T]

1.5.0 (const: unstable) ยท Source

impl<T> Default for &mut [T]

1.0.0 (const: unstable) ยท Source

impl<T> Default for (Tโ‚, Tโ‚‚, โ€ฆ, Tโ‚™)
where T: Default,

This trait is implemented for tuples up to twelve items long.

1.88.0 ยท Source

impl<T> Default for *const T
where T: Thin + ?Sized,

1.88.0 ยท Source

impl<T> Default for *mut T
where T: Thin + ?Sized,

1.0.0 ยท Source

impl<T> Default for alloc::sync::Arc<T>
where T: Default,

Available on non-no_global_oom_handling only.


impl<T> Default for devela::zall::Arc<T>
where T: Default,

1.80.0 ยท Source

impl<T> Default for alloc::sync::Arc<[T]>

Available on non-no_global_oom_handling only.


impl<T> Default for devela::zall::Arc<[T]>

Available on non-portable_atomic_no_min_const_generics only.
1.62.0 ยท Source

impl<T> Default for AssertUnwindSafe<T>
where T: Default,

1.0.0 ยท Source

impl<T> Default for core::sync::atomic::Atomic<*mut T>

Available on target_has_atomic_load_store=ptr only.


impl<T> Default for devela::zall::Atomic<T>
where T: Default,



impl<T> Default for AtomicPtr<T>

1.0.0 ยท Source

impl<T> Default for BTreeSet<T>

1.0.0 ยท Source

impl<T> Default for BinaryHeap<T>

1.0.0 ยท Source

impl<T> Default for Box<T>
where T: Default,

Available on non-no_global_oom_handling only.
1.0.0 ยท Source

impl<T> Default for Box<[T]>

Available on non-no_global_oom_handling only.
Source

impl<T> Default for BufferLinearAllocExample<T, Vec<T>>

Available on crate features _docs_examples only.
1.0.0 (const: unstable) ยท Source

impl<T> Default for Cell<T>
where T: Default,

1.0.0 ยท Source

impl<T> Default for Cursor<T>
where T: Default,

1.2.0 (const: unstable) ยท Source

impl<T> Default for core::iter::sources::empty::Empty<T>

Source

impl<T> Default for Interval<T>

Provides a default value for Interval, the unbounded interval $(-\infty, \infty)$.

This choice emphasizes neutrality and generality, where the interval encompasses all possible values of T. It:

  • Represents a neutral and maximal range for generic use cases.
  • Avoids reliance on Default for T, making it applicable to all types.
  • Aligns with mathematical conventions, where unbounded intervals are a natural default.
1.70.0 ยท Source

impl<T> Default for alloc::collections::binary_heap::IntoIter<T>

1.70.0 ยท Source

impl<T> Default for alloc::collections::linked_list::IntoIter<T>

1.70.0 ยท Source

impl<T> Default for core::slice::iter::Iter<'_, T>

1.82.0 ยท Source

impl<T> Default for alloc::collections::binary_heap::Iter<'_, T>

1.70.0 ยท Source

impl<T> Default for alloc::collections::btree::set::Iter<'_, T>

1.70.0 ยท Source

impl<T> Default for alloc::collections::linked_list::Iter<'_, T>

1.82.0 ยท Source

impl<T> Default for alloc::collections::vec_deque::iter::Iter<'_, T>



impl<T> Default for Iter<'_, T>



impl<T> Default for IterBuckets<'_, T>



impl<T> Default for IterHash<'_, T>



impl<T> Default for IterHashBuckets<'_, T>



impl<T> Default for IterHashMut<'_, T>

1.70.0 ยท Source

impl<T> Default for core::slice::iter::IterMut<'_, T>

1.70.0 ยท Source

impl<T> Default for alloc::collections::linked_list::IterMut<'_, T>

1.82.0 ยท Source

impl<T> Default for alloc::collections::vec_deque::iter_mut::IterMut<'_, T>



impl<T> Default for IterMut<'_, T>

1.80.0 (const: unstable) ยท Source

impl<T> Default for LazyCell<T>
where T: Default,

1.80.0 (const: unstable) ยท Source

impl<T> Default for LazyLock<T>
where T: Default,

1.0.0 ยท Source

impl<T> Default for LinkedList<T>

1.20.0 ยท Source

impl<T> Default for ManuallyDrop<T>
where T: Default + ?Sized,

Source

impl<T> Default for std::sync::nonpoison::mutex::Mutex<T>
where T: Default,

1.10.0 ยท Source

impl<T> Default for devela::zall::Mutex<T>
where T: Default,

1.70.0 (const: unstable) ยท Source

impl<T> Default for OnceCell<T>

1.70.0 (const: unstable) ยท Source

impl<T> Default for OnceLock<T>

1.0.0 (const: unstable) ยท Source

impl<T> Default for Option<T>

Source

impl<T> Default for PhantomContravariant<T>
where T: ?Sized,

Source

impl<T> Default for PhantomCovariant<T>
where T: ?Sized,

1.0.0 (const: unstable) ยท Source

impl<T> Default for PhantomData<T>
where T: ?Sized,

Source

impl<T> Default for PhantomInvariant<T>
where T: ?Sized,

1.91.0 ยท Source

impl<T> Default for Pin<Arc<T>>
where Arc<T>: Default, T: ?Sized,

Available on non-no_global_oom_handling only.


impl<T> Default for Pin<Arc<T>>
where Arc<T>: Default, T: ?Sized,

1.91.0 ยท Source

impl<T> Default for Pin<Box<T>>
where Box<T>: Default, T: ?Sized,

Available on non-no_global_oom_handling only.
1.91.0 ยท Source

impl<T> Default for Pin<Rc<T>>
where Rc<T>: Default, T: ?Sized,

Available on non-no_global_oom_handling only.
1.70.0 ยท Source

impl<T> Default for alloc::collections::btree::set::Range<'_, T>

1.0.0 ยท Source

impl<T> Default for Rc<T>
where T: Default,

Available on non-no_global_oom_handling only.
1.80.0 ยท Source

impl<T> Default for Rc<[T]>

Available on non-no_global_oom_handling only.
Source

impl<T> Default for ReentrantLock<T>
where T: Default,

1.0.0 (const: unstable) ยท Source

impl<T> Default for RefCell<T>
where T: Default,

1.19.0 (const: unstable) ยท Source

impl<T> Default for Reverse<T>
where T: Default,

Source

impl<T> Default for std::sync::nonpoison::rwlock::RwLock<T>
where T: Default,

1.10.0 ยท Source

impl<T> Default for devela::zall::RwLock<T>
where T: Default,

1.74.0 ยท Source

impl<T> Default for Saturating<T>
where T: Default,

Source

impl<T> Default for SyncUnsafeCell<T>
where T: Default,

Source

impl<T> Default for SyncView<T>
where T: Default,

Source

impl<T> Default for TypeResource<T>

1.10.0 (const: unstable) ยท Source

impl<T> Default for UnsafeCell<T>
where T: Default,



impl<T> Default for UnsafeIter<'_, T>

Source

impl<T> Default for UnsafePinned<T>
where T: Default,

1.0.0 (const: unstable) ยท Source

impl<T> Default for Vec<T>

1.0.0 ยท Source

impl<T> Default for VecDeque<T>

1.10.0 ยท Source

impl<T> Default for devela::zall::RcWeak<T>

1.10.0 ยท Source

impl<T> Default for alloc::sync::Weak<T>



impl<T> Default for devela::zall::ArcWeak<T>

1.0.0 ยท Source

impl<T> Default for Wrapping<T>
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 0]

1.4.0 ยท Source

impl<T> Default for [T; 1]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 2]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 3]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 4]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 5]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 6]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 7]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 8]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 9]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 10]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 11]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 12]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 13]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 14]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 15]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 16]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 17]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 18]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 19]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 20]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 21]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 22]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 23]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 24]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 25]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 26]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 27]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 28]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 29]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 30]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 31]
where T: Default,

1.4.0 ยท Source

impl<T> Default for [T; 32]
where T: Default,

Source

impl<V: Default, Q: Default> Default for ValueQuant<V, Q>

Source

impl<V: Default, T: Default> Default for Timed<V, T>

Source

impl<V: Default, const N: usize> Default for MapStaticConstU8Example<u8, V, N>

Source

impl<V: Default, const N: usize> Default for MapStaticTypeIdExample<u64, V, N>

Source

impl<V: Default, const N: usize> Default for MapStaticU16Example<u16, V, N>

Source

impl<Y: Default, MO: Default, D: Default, H: Default, M: Default, S: Default, MS: Default, US: Default, NS: Default> Default for TimeSplit<Y, MO, D, H, M, S, MS, US, NS>

Source

impl<const A: usize, const B: usize, const C: usize> Default for XorShift8<A, B, C>

Creates a new PRNG initialized with the default fixed seed.

Source

impl<const CAP: usize, const MSG_LEN: usize> Default for LoggerStatic<CAP, MSG_LEN>

Source

impl<const CAP: usize> Default for ArenaExample<CAP>

Source

impl<const CAP: usize> Default for EventQueue<CAP>

Available on crate feature event only.
Source

impl<const CAP: usize> Default for GraphemeNonul<CAP>

Available on crate feature grapheme only.
Source

impl<const CAP: usize> Default for GraphemeU8<CAP>

Available on crate feature grapheme only.
Source

impl<const CAP: usize> Default for SixelPalette<CAP>

Available on crate feature term only.
Source

impl<const CAP: usize> Default for StringNonul<CAP>

Source

impl<const CAP: usize> Default for StringSmallAlloc<CAP>

Available on crate feature alloc only.
Source

impl<const CAP: usize> Default for StringU8<CAP>

Source

impl<const DENSE: usize, const SPARSE: usize> Default for SparseSetArray<DENSE, SPARSE>

Source

impl<const LEN: usize, _0: Default, _1, _2, _3, _4, _5, _6, _7, _8, _9, _10, _11> Default for Oneof<LEN, _0, _1, _2, _3, _4, _5, _6, _7, _8, _9, _10, _11>

Source

impl<const MAX_COLORS: usize> Default for SixelEncoder<MAX_COLORS>

Available on crate feature term only.
Source

impl<const RADIX: usize, const LUT: bool, const PAD: bool, const CASE: bool, CODE> Default for Base<RADIX, LUT, PAD, CASE, CODE>