NumConst

Trait NumConst 

pub trait NumConst: PartialEq<Self::Num> {
    type Num;
Show 18 associated constants and 12 methods const NUM_IS_BIG: bool; const NUM_IS_INT: bool; const NUM_IS_FLOAT: bool; const NUM_IS_FIXED: bool; const NUM_IS_SIGNED: bool; const NUM_IS_NICHE: bool; const NUM_ZERO: Option<Self::Num>; const NUM_ONE: Option<Self::Num>; const NUM_TWO: Option<Self::Num>; const NUM_THREE: Option<Self::Num>; const NUM_NEG_ONE: Option<Self::Num>; const NUM_MIN: Option<Self::Num>; const NUM_MAX: Option<Self::Num>; const NUM_MIN_POSITIVE: Option<Self::Num>; const NUM_MAX_NEGATIVE: Option<Self::Num>; const NUM_MIN_NORM: Option<Self::Num>; const NUM_MAX_NORM: Option<Self::Num>; const NUM_MAX_POWER_OF_TWO: Option<Self::Num>; // Provided methods fn is_num_zero(&self) -> bool { ... } fn is_num_one(&self) -> bool { ... } fn is_num_two(&self) -> bool { ... } fn is_num_three(&self) -> bool { ... } fn is_num_neg_one(&self) -> bool { ... } fn is_num_min(&self) -> bool { ... } fn is_num_max(&self) -> bool { ... } fn is_num_min_positive(&self) -> bool { ... } fn is_num_max_negative(&self) -> bool { ... } fn is_num_min_norm(&self) -> bool { ... } fn is_num_max_norm(&self) -> bool { ... } fn is_num_max_power_of_two(&self) -> bool { ... }
}
Fundamental numeric constants for both integer and floating-point types.


📍 num/dom


Required Associated Constants

const NUM_IS_BIG: bool

Whether the number can represent big quantities.

const NUM_IS_INT: bool

Whether the number uses an integer representation.

const NUM_IS_FLOAT: bool

Whether the number uses a floating-point representation.

const NUM_IS_FIXED: bool

Whether the number uses a fixed-point representation.

const NUM_IS_SIGNED: bool

Whether the number includes the sign.

const NUM_IS_NICHE: bool

Whether the number has a memory niche optimization.

const NUM_ZERO: Option<Self::Num>

The additive identity (0), if applicable.

const NUM_ONE: Option<Self::Num>

The multiplicative identity (1).

const NUM_TWO: Option<Self::Num>

The only even prime and the fundamental doubling factor (2).

const NUM_THREE: Option<Self::Num>

The smallest odd prime and the first nontrivial divisor (3).

const NUM_NEG_ONE: Option<Self::Num>

The additive inverse of ONE (-1), if applicable.

const NUM_MIN: Option<Self::Num>

The smallest representable value.

const NUM_MAX: Option<Self::Num>

The greatest representable value.

const NUM_MIN_POSITIVE: Option<Self::Num>

The smallest representable positive value.

const NUM_MAX_NEGATIVE: Option<Self::Num>

The greatest representable negative value, if applicable.

const NUM_MIN_NORM: Option<Self::Num>

The smallest normalized value (e.g. 0.0 for float, MIN for integers).

const NUM_MAX_NORM: Option<Self::Num>

The greatest normalized value (e.g. 1.0 for float, MAX for integers).

const NUM_MAX_POWER_OF_TWO: Option<Self::Num>

The maximum representable power of two within the type’s range.

This is constructed using exact bit manipulation rather than arithmetic operations to ensure consistent results across all platforms.

Required Associated Types

type Num

The underlying numeric type implementing this trait.

Provided Methods

fn is_num_zero(&self) -> bool

Whether self is equal to NUM_ZERO.

fn is_num_one(&self) -> bool

Whether self is equal to NUM_ONE.

fn is_num_two(&self) -> bool

Whether self is equal to NUM_TWO.

fn is_num_three(&self) -> bool

Whether self is equal to NUM_THREE.

fn is_num_neg_one(&self) -> bool

Whether self is equal to NUM_NEG_ONE.

fn is_num_min(&self) -> bool

Whether self is equal to NUM_MIN.

fn is_num_max(&self) -> bool

Whether self is equal to NUM_MAX.

fn is_num_min_positive(&self) -> bool

Whether self is equal to Some(NUM_MIN_POSITIVE).

fn is_num_max_negative(&self) -> bool

Whether self is equal to NUM_MAX_NEGATIVE.

fn is_num_min_norm(&self) -> bool

Whether self is equal to NUM_MIN_NORM.

fn is_num_max_norm(&self) -> bool

Whether self is equal to NUM_MAX_NORM.

fn is_num_max_power_of_two(&self) -> bool

Whether self is equal to NUM_MAX_POWER_OF_TWO.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl NumConst for f32

Source

impl NumConst for f64

Source

impl NumConst for i8

Source

impl NumConst for i16

Source

impl NumConst for i32

Source

impl NumConst for i64

Source

impl NumConst for i128

Source

impl NumConst for isize

Source

impl NumConst for u8

Source

impl NumConst for u16

Source

impl NumConst for u32

Source

impl NumConst for u64

Source

impl NumConst for u128

Source

impl NumConst for usize

Implementors

Source

impl NumConst for NonZeroI8

Source

impl NumConst for NonZeroI16

Source

impl NumConst for NonZeroI32

Source

impl NumConst for NonZeroI64

Source

impl NumConst for NonZeroI128

Source

impl NumConst for NonZeroIsize

Source

impl NumConst for NonZeroU8

Source

impl NumConst for NonZeroU16

Source

impl NumConst for NonZeroU32

Source

impl NumConst for NonZeroU64

Source

impl NumConst for NonZeroU128

Source

impl NumConst for NonZeroUsize