NonMaxU16

Type Alias NonMaxU16 

pub type NonMaxU16 = NonValueU16<{ u16::MAX }>;
⚗️ An unsigned integer that is known not to equal its MAX value.


📍 num/grain/niche


Unlike the NonValue* types in general, this type alias implements the Default and ConstInit traits.

Aliased Type

pub struct NonMaxU16(/* private fields */);