NonMinIsize

Type Alias NonMinIsize 

pub type NonMinIsize = NonValueIsize<{ isize::MIN }>;
⚗️ A signed integer that is known not to equal its MIN value.


📍 num/grain/niche


Unlike the NonValue* types in general, this type alias implements the Default and ConstInit traits.

Aliased Type

pub struct NonMinIsize(/* private fields */);