Region2

Type Alias Region2 

pub type Region2<P, E> = Region<P, E, 2>;
📐 A 2-dimensional Region.


📍 geom/metric


Aliased Type

pub struct Region2<P, E> {
    pub pos: Position<P, 2>,
    pub ext: Extent<E, 2>,
}

Fields

pos: Position<P, 2>
ext: Extent<E, 2>

Implementations

Source

impl<P: Copy, E: Copy> Region2<P, E>

pub const fn x(self) -> P

Returns a copy of the first position dimension x.

pub const fn y(self) -> P

Returns a copy of the second position dimension y.

pub const fn w(self) -> E

Returns a copy of the first extent dimension width.

pub const fn h(self) -> E

Returns a copy of the second extent dimension height.