pub type c_off_t = i64;Expand description
⚙️ ⅀
Equivalent to C’s off_t type.
POSIX signed integer type used to represent file offsets and sizes.
pub type c_off_t = i64;⚙️ ⅀
Equivalent to C’s off_t type.
POSIX signed integer type used to represent file offsets and sizes.