c_ulonglong

Type Alias c_ulonglong 

1.64.0 · Source
pub type c_ulonglong = u64;
⚙️ core Equivalent to the corresponding C type.


📍lang::prog::ffi::c re-exported from core::ffi



📜
Equivalent to C’s unsigned long long type.

This type will almost always be u64, but may differ on some systems. The C standard technically only requires that this type be an unsigned integer with the size of a long long, although in practice, no system would have a long long that is not a u64, as most systems do not have a standardised u128 type.