pub type js_undefined = ();Available on crate feature
js only.Expand description
⚙️ ∅
The JavaScript undefined value.
In Rust, undefined is represented as the unit type (), as it carries no meaningful value.
pub type js_undefined = ();js only.⚙️ ∅
The JavaScript undefined value.
In Rust, undefined is represented as the unit type (), as it carries no meaningful value.