pub enum NicheValueError {
Overflow(Option<Sign>),
InvalidValue,
}Expand description
Variants
Overflow(Option<Sign>)
โ ๐ฉ An arithmetic overflow error, with an optional associated sign.
InvalidValue
๐ฉ An invalid value was received for the given type or operation.
Implementations
Sourceimpl NicheValueError
impl NicheValueError
Sourcepub const fn from_overflow(_f: Overflow) -> NicheValueError
pub const fn from_overflow(_f: Overflow) -> NicheValueError
const
method equivalent to From<Overflow> for NicheValueError.
Sourceimpl NicheValueError
impl NicheValueError
Sourcepub const fn from_invalid_value(_f: InvalidValue) -> NicheValueError
pub const fn from_invalid_value(_f: InvalidValue) -> NicheValueError
const
method equivalent to From<InvalidValue> for NicheValueError.