pub struct BitSpan<T> {
pub start: u32,
pub end: u32,
pub width: u32,
pub mask: T,
pub max: T,
}Expand description
▫️ 🗃️ A contiguous span of bits in an integer carrier.
📍 bin
Stores the bounds and derived masks for a packed field.
Fields
start: u32First bit in the span.
end: u32Last bit in the span.
width: u32Number of bits in the span.
mask: TShifted mask covering the span.
max: TMaximum value that fits in the span.
Implementations
Sourceimpl<T> BitSpan<T>
impl<T> BitSpan<T>
Sourcepub const fn from_parts(start: u32, end: u32, mask: T, max: T) -> Self
pub const fn from_parts(start: u32, end: u32, mask: T, max: T) -> Self
Sourceimpl<T: Copy> BitSpan<T>
impl<T: Copy> BitSpan<T>
Sourcepub const fn contains_bit(self, bit: u32) -> bool
pub const fn contains_bit(self, bit: u32) -> bool
Returns whether bit is inside the span.
Sourcepub const fn contains_span(self, other: Self) -> bool
pub const fn contains_span(self, other: Self) -> bool
Returns whether other is fully inside self.
Sourcepub const fn is_disjoint(self, other: Self) -> bool
pub const fn is_disjoint(self, other: Self) -> bool
Returns whether both spans share no bits.
Sourceimpl BitSpan<u8>
impl BitSpan<u8>
Sourcepub const fn try_new(start: u32, end: u32) -> Result<Self, MismatchedBounds> ⓘ
pub const fn try_new(start: u32, end: u32) -> Result<Self, MismatchedBounds> ⓘ
Returns a new checked bit span.
Errors
Returns an error if start > end or if end exceeds the carrier width.
Sourcepub const fn value_fits(self, value: u8) -> bool
pub const fn value_fits(self, value: u8) -> bool
Returns whether value fits in this span.
Sourcepub const fn set_value(self, bits: u8, value: u8) -> u8
pub const fn set_value(self, bits: u8, value: u8) -> u8
Returns bits with the span value replaced.
The value is masked to fit the span width.
Sourcepub const fn try_set_value(
self,
bits: u8,
value: u8,
) -> Result<u8, MismatchedBounds> ⓘ
pub const fn try_set_value( self, bits: u8, value: u8, ) -> Result<u8, MismatchedBounds> ⓘ
Returns bits with the checked span value replaced.
Errors
Returns an error if the span is invalid
or if value does not fit within the span width.
Sourcepub const fn is_full_in(self, bits: u8) -> bool
pub const fn is_full_in(self, bits: u8) -> bool
Returns whether every span bit is set in bits.
Sourcepub const fn is_zero_in(self, bits: u8) -> bool
pub const fn is_zero_in(self, bits: u8) -> bool
Returns whether no span bit is set in bits.
Sourceimpl BitSpan<u16>
impl BitSpan<u16>
Sourcepub const fn try_new(start: u32, end: u32) -> Result<Self, MismatchedBounds> ⓘ
pub const fn try_new(start: u32, end: u32) -> Result<Self, MismatchedBounds> ⓘ
Returns a new checked bit span.
Errors
Returns an error if start > end or if end exceeds the carrier width.
Sourcepub const fn value_fits(self, value: u16) -> bool
pub const fn value_fits(self, value: u16) -> bool
Returns whether value fits in this span.
Sourcepub const fn set_value(self, bits: u16, value: u16) -> u16
pub const fn set_value(self, bits: u16, value: u16) -> u16
Returns bits with the span value replaced.
The value is masked to fit the span width.
Sourcepub const fn try_set_value(
self,
bits: u16,
value: u16,
) -> Result<u16, MismatchedBounds> ⓘ
pub const fn try_set_value( self, bits: u16, value: u16, ) -> Result<u16, MismatchedBounds> ⓘ
Returns bits with the checked span value replaced.
Errors
Returns an error if the span is invalid
or if value does not fit within the span width.
Sourcepub const fn is_full_in(self, bits: u16) -> bool
pub const fn is_full_in(self, bits: u16) -> bool
Returns whether every span bit is set in bits.
Sourcepub const fn is_zero_in(self, bits: u16) -> bool
pub const fn is_zero_in(self, bits: u16) -> bool
Returns whether no span bit is set in bits.
Sourceimpl BitSpan<u32>
impl BitSpan<u32>
Sourcepub const fn try_new(start: u32, end: u32) -> Result<Self, MismatchedBounds> ⓘ
pub const fn try_new(start: u32, end: u32) -> Result<Self, MismatchedBounds> ⓘ
Returns a new checked bit span.
Errors
Returns an error if start > end or if end exceeds the carrier width.
Sourcepub const fn value_fits(self, value: u32) -> bool
pub const fn value_fits(self, value: u32) -> bool
Returns whether value fits in this span.
Sourcepub const fn set_value(self, bits: u32, value: u32) -> u32
pub const fn set_value(self, bits: u32, value: u32) -> u32
Returns bits with the span value replaced.
The value is masked to fit the span width.
Sourcepub const fn try_set_value(
self,
bits: u32,
value: u32,
) -> Result<u32, MismatchedBounds> ⓘ
pub const fn try_set_value( self, bits: u32, value: u32, ) -> Result<u32, MismatchedBounds> ⓘ
Returns bits with the checked span value replaced.
Errors
Returns an error if the span is invalid
or if value does not fit within the span width.
Sourcepub const fn is_full_in(self, bits: u32) -> bool
pub const fn is_full_in(self, bits: u32) -> bool
Returns whether every span bit is set in bits.
Sourcepub const fn is_zero_in(self, bits: u32) -> bool
pub const fn is_zero_in(self, bits: u32) -> bool
Returns whether no span bit is set in bits.
Sourceimpl BitSpan<u64>
impl BitSpan<u64>
Sourcepub const fn try_new(start: u32, end: u32) -> Result<Self, MismatchedBounds> ⓘ
pub const fn try_new(start: u32, end: u32) -> Result<Self, MismatchedBounds> ⓘ
Returns a new checked bit span.
Errors
Returns an error if start > end or if end exceeds the carrier width.
Sourcepub const fn value_fits(self, value: u64) -> bool
pub const fn value_fits(self, value: u64) -> bool
Returns whether value fits in this span.
Sourcepub const fn set_value(self, bits: u64, value: u64) -> u64
pub const fn set_value(self, bits: u64, value: u64) -> u64
Returns bits with the span value replaced.
The value is masked to fit the span width.
Sourcepub const fn try_set_value(
self,
bits: u64,
value: u64,
) -> Result<u64, MismatchedBounds> ⓘ
pub const fn try_set_value( self, bits: u64, value: u64, ) -> Result<u64, MismatchedBounds> ⓘ
Returns bits with the checked span value replaced.
Errors
Returns an error if the span is invalid
or if value does not fit within the span width.
Sourcepub const fn is_full_in(self, bits: u64) -> bool
pub const fn is_full_in(self, bits: u64) -> bool
Returns whether every span bit is set in bits.
Sourcepub const fn is_zero_in(self, bits: u64) -> bool
pub const fn is_zero_in(self, bits: u64) -> bool
Returns whether no span bit is set in bits.
Sourceimpl BitSpan<u128>
impl BitSpan<u128>
Sourcepub const fn try_new(start: u32, end: u32) -> Result<Self, MismatchedBounds> ⓘ
pub const fn try_new(start: u32, end: u32) -> Result<Self, MismatchedBounds> ⓘ
Returns a new checked bit span.
Errors
Returns an error if start > end or if end exceeds the carrier width.
Sourcepub const fn value_fits(self, value: u128) -> bool
pub const fn value_fits(self, value: u128) -> bool
Returns whether value fits in this span.
Sourcepub const fn set_value(self, bits: u128, value: u128) -> u128
pub const fn set_value(self, bits: u128, value: u128) -> u128
Returns bits with the span value replaced.
The value is masked to fit the span width.
Sourcepub const fn try_set_value(
self,
bits: u128,
value: u128,
) -> Result<u128, MismatchedBounds> ⓘ
pub const fn try_set_value( self, bits: u128, value: u128, ) -> Result<u128, MismatchedBounds> ⓘ
Returns bits with the checked span value replaced.
Errors
Returns an error if the span is invalid
or if value does not fit within the span width.
Sourcepub const fn is_full_in(self, bits: u128) -> bool
pub const fn is_full_in(self, bits: u128) -> bool
Returns whether every span bit is set in bits.
Sourcepub const fn is_zero_in(self, bits: u128) -> bool
pub const fn is_zero_in(self, bits: u128) -> bool
Returns whether no span bit is set in bits.
Sourceimpl BitSpan<usize>
impl BitSpan<usize>
Sourcepub const fn try_new(start: u32, end: u32) -> Result<Self, MismatchedBounds> ⓘ
pub const fn try_new(start: u32, end: u32) -> Result<Self, MismatchedBounds> ⓘ
Returns a new checked bit span.
Errors
Returns an error if start > end or if end exceeds the carrier width.
Sourcepub const fn value_fits(self, value: usize) -> bool
pub const fn value_fits(self, value: usize) -> bool
Returns whether value fits in this span.
Sourcepub const fn set_value(self, bits: usize, value: usize) -> usize
pub const fn set_value(self, bits: usize, value: usize) -> usize
Returns bits with the span value replaced.
The value is masked to fit the span width.
Sourcepub const fn try_set_value(
self,
bits: usize,
value: usize,
) -> Result<usize, MismatchedBounds> ⓘ
pub const fn try_set_value( self, bits: usize, value: usize, ) -> Result<usize, MismatchedBounds> ⓘ
Returns bits with the checked span value replaced.
Errors
Returns an error if the span is invalid
or if value does not fit within the span width.
Sourcepub const fn is_full_in(self, bits: usize) -> bool
pub const fn is_full_in(self, bits: usize) -> bool
Returns whether every span bit is set in bits.
Sourcepub const fn is_zero_in(self, bits: usize) -> bool
pub const fn is_zero_in(self, bits: usize) -> bool
Returns whether no span bit is set in bits.