pub struct BitfieldExample { /* private fields */ }_docs_examples and (crate features _docs_examples) only.Expand description
✨ ▫️ 🫗 🗃️ A compact packet header.
It has been generated with the bitfield! macro like this:
bitfield! {
/// A compact packet header.
pub struct BitfieldExample(u16) {
KIND = 0..=3;
VERSION = 4..=7;
LENGTH = 8..=15;
}
}Implementations
Sourceimpl BitfieldExample
Named bit field masks.
These constants represent each field’s occupied bit range, not a field value.
impl BitfieldExample
Named bit field masks.
These constants represent each field’s occupied bit range, not a field value.
Use them with mask-level methods such as
contains_mask, with_mask and without_mask.
Sourceimpl BitfieldExample
impl BitfieldExample
Sourcepub const fn is_full(self) -> bool
pub const fn is_full(self) -> bool
Returns true if the raw bits exactly equal the declared field mask.
Sourcepub const fn fields_are_zero(self) -> bool
pub const fn fields_are_zero(self) -> bool
Returns true if all declared field bits are clear.
Sourcepub const fn fields_are_full(self) -> bool
pub const fn fields_are_full(self) -> bool
Returns true if all declared field bits are set.
Sourcepub const fn contains_mask(self, other: Self) -> bool
pub const fn contains_mask(self, other: Self) -> bool
Returns true if all bits in other are set in self.
This is a mask-level predicate. When used with a named field constant, it checks whether every bit occupied by that field is set.
Sourcepub const fn has_extra_bits(self) -> bool
pub const fn has_extra_bits(self) -> bool
Returns true if any bit outside the declared field mask is set.
Sourcepub const fn clear_fields(&mut self)
pub const fn clear_fields(&mut self)
Clears all declared field bits, preserving bits outside the declared field mask.
Sourcepub const fn without_fields(self) -> Self
pub const fn without_fields(self) -> Self
Returns self with all declared field bits cleared, preserving extra bits.
Sourcepub const fn with_mask(self, other: Self) -> Self
pub const fn with_mask(self, other: Self) -> Self
Returns self with all bits in other set.
This is a mask-level operation. Use with_FIELD(value) to replace a field value.
Sourcepub const fn with_mask_if(self, condition: bool, other: Self) -> Self
pub const fn with_mask_if(self, condition: bool, other: Self) -> Self
Returns self with all bits in other set if condition is true.
Sourcepub const fn without_mask(self, other: Self) -> Self
pub const fn without_mask(self, other: Self) -> Self
Returns self with all bits in other cleared.
This is a mask-level operation. It clears the occupied bits, regardless of the current field value.
Sourcepub const fn without_mask_if(self, condition: bool, other: Self) -> Self
pub const fn without_mask_if(self, condition: bool, other: Self) -> Self
Returns self with all bits in other cleared if condition is true.
Sourceimpl BitfieldExample
impl BitfieldExample
Sourcepub const fn with_kind(self, value: u16) -> Self
pub const fn with_kind(self, value: u16) -> Self
Returns self with the field value replaced, masking it to fit the field width.
Sourcepub const fn try_with_kind(self, value: u16) -> Result<Self, MismatchedCapacity> ⓘ
pub const fn try_with_kind(self, value: u16) -> Result<Self, MismatchedCapacity> ⓘ
Returns self with the checked field value replaced, if it fits.
Sourcepub const fn set_kind(&mut self, value: u16)
pub const fn set_kind(&mut self, value: u16)
Replaces the field value, masking it to fit the field width.
Sourcepub const fn try_set_kind(
&mut self,
value: u16,
) -> Result<(), MismatchedCapacity> ⓘ
pub const fn try_set_kind( &mut self, value: u16, ) -> Result<(), MismatchedCapacity> ⓘ
Replaces the field value, if it fits.
Sourcepub const fn clear_kind(&mut self)
pub const fn clear_kind(&mut self)
Clears the field value.
Sourcepub const fn is_kind_zero(self) -> bool
pub const fn is_kind_zero(self) -> bool
Returns true if the field value is zero.
Sourcepub const fn is_kind_max(self) -> bool
pub const fn is_kind_max(self) -> bool
Returns true if the field value equals its maximum.
Sourceimpl BitfieldExample
impl BitfieldExample
Sourcepub const fn get_version(self) -> u16
pub const fn get_version(self) -> u16
Returns the field value.
Sourcepub const fn with_version(self, value: u16) -> Self
pub const fn with_version(self, value: u16) -> Self
Returns self with the field value replaced, masking it to fit the field width.
Sourcepub const fn try_with_version(
self,
value: u16,
) -> Result<Self, MismatchedCapacity> ⓘ
pub const fn try_with_version( self, value: u16, ) -> Result<Self, MismatchedCapacity> ⓘ
Returns self with the checked field value replaced, if it fits.
Sourcepub const fn set_version(&mut self, value: u16)
pub const fn set_version(&mut self, value: u16)
Replaces the field value, masking it to fit the field width.
Sourcepub const fn try_set_version(
&mut self,
value: u16,
) -> Result<(), MismatchedCapacity> ⓘ
pub const fn try_set_version( &mut self, value: u16, ) -> Result<(), MismatchedCapacity> ⓘ
Replaces the field value, if it fits.
Sourcepub const fn clear_version(&mut self)
pub const fn clear_version(&mut self)
Clears the field value.
Sourcepub const fn is_version_zero(self) -> bool
pub const fn is_version_zero(self) -> bool
Returns true if the field value is zero.
Sourcepub const fn is_version_max(self) -> bool
pub const fn is_version_max(self) -> bool
Returns true if the field value equals its maximum.
Sourcepub const fn version_span() -> BitSpan<u16>
pub const fn version_span() -> BitSpan<u16>
Returns metadata for this field.
Sourceimpl BitfieldExample
impl BitfieldExample
Sourcepub const fn get_length(self) -> u16
pub const fn get_length(self) -> u16
Returns the field value.
Sourcepub const fn with_length(self, value: u16) -> Self
pub const fn with_length(self, value: u16) -> Self
Returns self with the field value replaced, masking it to fit the field width.
Sourcepub const fn try_with_length(
self,
value: u16,
) -> Result<Self, MismatchedCapacity> ⓘ
pub const fn try_with_length( self, value: u16, ) -> Result<Self, MismatchedCapacity> ⓘ
Returns self with the checked field value replaced, if it fits.
Sourcepub const fn set_length(&mut self, value: u16)
pub const fn set_length(&mut self, value: u16)
Replaces the field value, masking it to fit the field width.
Sourcepub const fn try_set_length(
&mut self,
value: u16,
) -> Result<(), MismatchedCapacity> ⓘ
pub const fn try_set_length( &mut self, value: u16, ) -> Result<(), MismatchedCapacity> ⓘ
Replaces the field value, if it fits.
Sourcepub const fn clear_length(&mut self)
pub const fn clear_length(&mut self)
Clears the field value.
Sourcepub const fn is_length_zero(self) -> bool
pub const fn is_length_zero(self) -> bool
Returns true if the field value is zero.
Sourcepub const fn is_length_max(self) -> bool
pub const fn is_length_max(self) -> bool
Returns true if the field value equals its maximum.
Sourcepub const fn length_span() -> BitSpan<u16>
pub const fn length_span() -> BitSpan<u16>
Returns metadata for this field.