pub struct FdBorrowed<'fd> { /* private fields */ }std only.Expand description
📁 🍃
std
A borrowed file descriptor.
📍sys/os/fd re-exported from std::os::fd ::BorrowedFd as FdBorrowed
📜
A borrowed file descriptor.
This has a lifetime parameter to tie it to the lifetime of something that owns the file descriptor. For the duration of that lifetime, it is guaranteed that nobody will close the file descriptor.
This uses repr(transparent) and has the representation of a host file
descriptor, so it can be used in FFI in places where a file descriptor is
passed as an argument, it is not captured or consumed, and it never has the
value -1.
This type does not have a ToOwned
implementation. Calling .to_owned() on a variable of this type will call
it on &BorrowedFd and use Clone::clone() like ToOwned does for all
types implementing Clone. The result will be descriptor borrowed under
the same lifetime.
To obtain an OwnedFd, you can use BorrowedFd::try_clone_to_owned
instead, but this is not supported on all platforms.
Implementations
Sourceimpl BorrowedFd<'_>
impl BorrowedFd<'_>
1.63.0 (const: 1.63.0) · Sourcepub const unsafe fn borrow_raw(fd: i32) -> BorrowedFd<'_>
pub const unsafe fn borrow_raw(fd: i32) -> BorrowedFd<'_>
Sourceimpl BorrowedFd<'_>
impl BorrowedFd<'_>