pub struct Iter;Expand description
Implementations
Sourceimpl Iter
Core methods.
impl Iter
Core methods.
Sourcepub const fn empty<T>() -> Empty<T> โ
pub const fn empty<T>() -> Empty<T> โ
Creates an iterator that yields nothing.
See core::iter::empty.
Sourcepub fn from_coroutine<G>(coroutine: G) -> FromCoroutine<G> โ
Available on nightly_coro only.
pub fn from_coroutine<G>(coroutine: G) -> FromCoroutine<G> โ
nightly_coro only.Creates a new iterator where each iteration calls the provided coroutine.
See core::iter::from_coroutine.
Sourcepub fn from_fn<T, F>(f: F) -> FromFn<F> โ
pub fn from_fn<T, F>(f: F) -> FromFn<F> โ
Creates an iterator that calls the given closure F: FnMut() -> Option<T>.
See core::iter::from_fn.
Sourcepub fn once<T>(value: T) -> Once<T> โ
pub fn once<T>(value: T) -> Once<T> โ
Creates an iterator that yields an element exactly once.
See core::iter::once.
Sourcepub fn once_with<A, F>(make: F) -> OnceWith<F> โwhere
F: FnOnce() -> A,
pub fn once_with<A, F>(make: F) -> OnceWith<F> โwhere
F: FnOnce() -> A,
Creates an iterator that lazily generates a value exactly once.
See core::iter::once_with.
Sourcepub fn repeat<T>(elt: T) -> Repeat<T> โwhere
T: Clone,
pub fn repeat<T>(elt: T) -> Repeat<T> โwhere
T: Clone,
Creates an iterator that endlessly repeats a single element.
See core::iter::repeat.
Sourcepub fn repeat_n<T>(element: T, count: usize) -> RepeatN<T> โwhere
T: Clone,
pub fn repeat_n<T>(element: T, count: usize) -> RepeatN<T> โwhere
T: Clone,
Creates a new iterator that repeats a single element a given number of times.
See core::iter::repeat_n.
Sourcepub fn repeat_with<A, F>(repeater: F) -> RepeatWith<F> โwhere
F: FnMut() -> A,
pub fn repeat_with<A, F>(repeater: F) -> RepeatWith<F> โwhere
F: FnMut() -> A,
Creates an iterator that endlessly repeats calling F: FnMut() -> A.
See core::iter::repeat_with.
Sourcepub fn successors<T, F>(first: Option<T>, succ: F) -> Successors<T, F> โ
pub fn successors<T, F>(first: Option<T>, succ: F) -> Successors<T, F> โ
Creates an iterator where each successive item is computed based on the previous.
See core::iter::successors.
Sourcepub fn zip<A, B>(
a: A,
b: B,
) -> Zip<<A as IntoIterator>::IntoIter, <B as IntoIterator>::IntoIter> โwhere
A: IntoIterator,
B: IntoIterator,
pub fn zip<A, B>(
a: A,
b: B,
) -> Zip<<A as IntoIterator>::IntoIter, <B as IntoIterator>::IntoIter> โwhere
A: IntoIterator,
B: IntoIterator,
Converts the arguments to iterators and zips them.
See core::iter::zip.