pub struct LinuxTermiosControlFlags { /* private fields */ }linux only.Expand description
๐ง ๐ฎ โ
LinuxTermios control flags.
๐ sys/os/linux/io/term
๐ฆ size_of::<LinuxTermiosControlFlags>() == 2 bytes / 16 bits
NOTE: CSIZE/CS5/CS6/CS7/CS8 are a masked character-size field,
not independent flags. Prefer LinuxTermios::set_char_size when changing it.
Implementations
Sourceimpl LinuxTermiosControlFlags
Named constants
impl LinuxTermiosControlFlags
Named constants
Sourceimpl LinuxTermiosControlFlags
Convenience methods derived from each named constant.
impl LinuxTermiosControlFlags
Convenience methods derived from each named constant.
Sourcepub const fn contains_csize(self) -> bool
pub const fn contains_csize(self) -> bool
Returns true if the set contains all bits in CSIZE.
Sourcepub const fn intersects_csize(self) -> bool
pub const fn intersects_csize(self) -> bool
Returns true if the set shares any bit with CSIZE.
Sourcepub const fn with_csize(self) -> Self
pub const fn with_csize(self) -> Self
Returns self with CSIZE inserted.
Sourcepub const fn with_csize_if(self, condition: bool) -> Self
pub const fn with_csize_if(self, condition: bool) -> Self
Returns self with CSIZE inserted if condition is true.
Sourcepub const fn without_csize(self) -> Self
pub const fn without_csize(self) -> Self
Returns self with CSIZE removed.
Sourcepub const fn set_csize_if(&mut self, condition: bool)
pub const fn set_csize_if(&mut self, condition: bool)
Sets CSIZE if condition is true.
Sourcepub const fn unset_csize(&mut self)
pub const fn unset_csize(&mut self)
Unsets CSIZE.
Sourcepub const fn contains_cs6(self) -> bool
pub const fn contains_cs6(self) -> bool
Returns true if all bits in CS6 are present.
Sourcepub const fn intersects_cs6(self) -> bool
pub const fn intersects_cs6(self) -> bool
Returns true if the set shares any bit with CS6.
Sourcepub const fn with_cs6_if(self, condition: bool) -> Self
pub const fn with_cs6_if(self, condition: bool) -> Self
Returns self with CS6 inserted if condition is true.
Sourcepub const fn without_cs6(self) -> Self
pub const fn without_cs6(self) -> Self
Returns self with CS6 removed.
Sourcepub const fn set_cs6_if(&mut self, condition: bool)
pub const fn set_cs6_if(&mut self, condition: bool)
Sets CS6 if condition is true.
Sourcepub const fn contains_cs7(self) -> bool
pub const fn contains_cs7(self) -> bool
Returns true if all bits in CS7 are present.
Sourcepub const fn intersects_cs7(self) -> bool
pub const fn intersects_cs7(self) -> bool
Returns true if the set shares any bit with CS7.
Sourcepub const fn with_cs7_if(self, condition: bool) -> Self
pub const fn with_cs7_if(self, condition: bool) -> Self
Returns self with CS7 inserted if condition is true.
Sourcepub const fn without_cs7(self) -> Self
pub const fn without_cs7(self) -> Self
Returns self with CS7 removed.
Sourcepub const fn set_cs7_if(&mut self, condition: bool)
pub const fn set_cs7_if(&mut self, condition: bool)
Sets CS7 if condition is true.
Sourcepub const fn contains_cs8(self) -> bool
pub const fn contains_cs8(self) -> bool
Returns true if the set contains all bits in CS8.
Sourcepub const fn intersects_cs8(self) -> bool
pub const fn intersects_cs8(self) -> bool
Returns true if the set shares any bit with CS8.
Sourcepub const fn with_cs8_if(self, condition: bool) -> Self
pub const fn with_cs8_if(self, condition: bool) -> Self
Returns self with CS8 inserted if condition is true.
Sourcepub const fn without_cs8(self) -> Self
pub const fn without_cs8(self) -> Self
Returns self with CS8 removed.
Sourcepub const fn set_cs8_if(&mut self, condition: bool)
pub const fn set_cs8_if(&mut self, condition: bool)
Sets CS8 if condition is true.
Sourcepub const fn has_cstopb(self) -> bool
pub const fn has_cstopb(self) -> bool
Returns true if CSTOPB is present.
Sourcepub const fn contains_cstopb(self) -> bool
pub const fn contains_cstopb(self) -> bool
Returns true if all bits in CSTOPB are present.
Sourcepub const fn intersects_cstopb(self) -> bool
pub const fn intersects_cstopb(self) -> bool
Returns true if the set shares any bit with CSTOPB.
Sourcepub const fn with_cstopb(self) -> Self
pub const fn with_cstopb(self) -> Self
Returns self with CSTOPB inserted.
Sourcepub const fn with_cstopb_if(self, condition: bool) -> Self
pub const fn with_cstopb_if(self, condition: bool) -> Self
Returns self with CSTOPB inserted if condition is true.
Sourcepub const fn without_cstopb(self) -> Self
pub const fn without_cstopb(self) -> Self
Returns self with CSTOPB removed.
Sourcepub const fn set_cstopb(&mut self)
pub const fn set_cstopb(&mut self)
Sets CSTOPB.
Sourcepub const fn set_cstopb_if(&mut self, condition: bool)
pub const fn set_cstopb_if(&mut self, condition: bool)
Sets CSTOPB if condition is true.
Sourcepub const fn unset_cstopb(&mut self)
pub const fn unset_cstopb(&mut self)
Unsets CSTOPB.
Sourcepub const fn contains_cread(self) -> bool
pub const fn contains_cread(self) -> bool
Returns true if all bits in CREAD are present.
Sourcepub const fn intersects_cread(self) -> bool
pub const fn intersects_cread(self) -> bool
Returns true if the set shares any bit with CREAD.
Sourcepub const fn with_cread(self) -> Self
pub const fn with_cread(self) -> Self
Returns self with CREAD inserted.
Sourcepub const fn with_cread_if(self, condition: bool) -> Self
pub const fn with_cread_if(self, condition: bool) -> Self
Returns self with CREAD inserted if condition is true.
Sourcepub const fn without_cread(self) -> Self
pub const fn without_cread(self) -> Self
Returns self with CREAD removed.
Sourcepub const fn set_cread_if(&mut self, condition: bool)
pub const fn set_cread_if(&mut self, condition: bool)
Sets CREAD if condition is true.
Sourcepub const fn unset_cread(&mut self)
pub const fn unset_cread(&mut self)
Unsets CREAD.
Sourcepub const fn has_parenb(self) -> bool
pub const fn has_parenb(self) -> bool
Returns true if PARENB is present.
Sourcepub const fn contains_parenb(self) -> bool
pub const fn contains_parenb(self) -> bool
Returns true if all bits in PARENB are present.
Sourcepub const fn intersects_parenb(self) -> bool
pub const fn intersects_parenb(self) -> bool
Returns true if the set shares any bit with PARENB.
Sourcepub const fn with_parenb(self) -> Self
pub const fn with_parenb(self) -> Self
Returns self with PARENB inserted.
Sourcepub const fn with_parenb_if(self, condition: bool) -> Self
pub const fn with_parenb_if(self, condition: bool) -> Self
Returns self with PARENB inserted if condition is true.
Sourcepub const fn without_parenb(self) -> Self
pub const fn without_parenb(self) -> Self
Returns self with PARENB removed.
Sourcepub const fn set_parenb(&mut self)
pub const fn set_parenb(&mut self)
Sets PARENB.
Sourcepub const fn set_parenb_if(&mut self, condition: bool)
pub const fn set_parenb_if(&mut self, condition: bool)
Sets PARENB if condition is true.
Sourcepub const fn unset_parenb(&mut self)
pub const fn unset_parenb(&mut self)
Unsets PARENB.
Sourcepub const fn has_parodd(self) -> bool
pub const fn has_parodd(self) -> bool
Returns true if PARODD is present.
Sourcepub const fn contains_parodd(self) -> bool
pub const fn contains_parodd(self) -> bool
Returns true if all bits in PARODD are present.
Sourcepub const fn intersects_parodd(self) -> bool
pub const fn intersects_parodd(self) -> bool
Returns true if the set shares any bit with PARODD.
Sourcepub const fn with_parodd(self) -> Self
pub const fn with_parodd(self) -> Self
Returns self with PARODD inserted.
Sourcepub const fn with_parodd_if(self, condition: bool) -> Self
pub const fn with_parodd_if(self, condition: bool) -> Self
Returns self with PARODD inserted if condition is true.
Sourcepub const fn without_parodd(self) -> Self
pub const fn without_parodd(self) -> Self
Returns self with PARODD removed.
Sourcepub const fn set_parodd(&mut self)
pub const fn set_parodd(&mut self)
Sets PARODD.
Sourcepub const fn set_parodd_if(&mut self, condition: bool)
pub const fn set_parodd_if(&mut self, condition: bool)
Sets PARODD if condition is true.
Sourcepub const fn unset_parodd(&mut self)
pub const fn unset_parodd(&mut self)
Unsets PARODD.
Sourcepub const fn contains_hupcl(self) -> bool
pub const fn contains_hupcl(self) -> bool
Returns true if all bits in HUPCL are present.
Sourcepub const fn intersects_hupcl(self) -> bool
pub const fn intersects_hupcl(self) -> bool
Returns true if the set shares any bit with HUPCL.
Sourcepub const fn with_hupcl(self) -> Self
pub const fn with_hupcl(self) -> Self
Returns self with HUPCL inserted.
Sourcepub const fn with_hupcl_if(self, condition: bool) -> Self
pub const fn with_hupcl_if(self, condition: bool) -> Self
Returns self with HUPCL inserted if condition is true.
Sourcepub const fn without_hupcl(self) -> Self
pub const fn without_hupcl(self) -> Self
Returns self with HUPCL removed.
Sourcepub const fn set_hupcl_if(&mut self, condition: bool)
pub const fn set_hupcl_if(&mut self, condition: bool)
Sets HUPCL if condition is true.
Sourcepub const fn unset_hupcl(&mut self)
pub const fn unset_hupcl(&mut self)
Unsets HUPCL.
Sourcepub const fn has_clocal(self) -> bool
pub const fn has_clocal(self) -> bool
Returns true if CLOCAL is present.
Sourcepub const fn contains_clocal(self) -> bool
pub const fn contains_clocal(self) -> bool
Returns true if all bits in CLOCAL are present.
Sourcepub const fn intersects_clocal(self) -> bool
pub const fn intersects_clocal(self) -> bool
Returns true if the set shares any bit with CLOCAL.
Sourcepub const fn with_clocal(self) -> Self
pub const fn with_clocal(self) -> Self
Returns self with CLOCAL inserted.
Sourcepub const fn with_clocal_if(self, condition: bool) -> Self
pub const fn with_clocal_if(self, condition: bool) -> Self
Returns self with CLOCAL inserted if condition is true.
Sourcepub const fn without_clocal(self) -> Self
pub const fn without_clocal(self) -> Self
Returns self with CLOCAL removed.
Sourcepub const fn set_clocal(&mut self)
pub const fn set_clocal(&mut self)
Sets CLOCAL.
Sourcepub const fn set_clocal_if(&mut self, condition: bool)
pub const fn set_clocal_if(&mut self, condition: bool)
Sets CLOCAL if condition is true.
Sourcepub const fn unset_clocal(&mut self)
pub const fn unset_clocal(&mut self)
Unsets CLOCAL.
Sourceimpl LinuxTermiosControlFlags
Common set methods
impl LinuxTermiosControlFlags
Common set methods
Sourceimpl LinuxTermiosControlFlags
Set operations
impl LinuxTermiosControlFlags
Set operations
Sourcepub const fn intersects(self, other: Self) -> bool
pub const fn intersects(self, other: Self) -> bool
Returns true if self and other share any bit.
Sourcepub const fn is_subset(self, other: Self) -> bool
pub const fn is_subset(self, other: Self) -> bool
Returns true if all bits in self are also set in other.
Sourcepub const fn is_superset(self, other: Self) -> bool
pub const fn is_superset(self, other: Self) -> bool
Returns true if all bits in other are also set in self.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
Returns the intersection of self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns the difference of self and other.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
Returns the symmetric difference of self and other.
Sourceimpl LinuxTermiosControlFlags
Mutating set operations
impl LinuxTermiosControlFlags
Mutating set operations