pub struct Stderr { /* private fields */ }std only.Expand description
๐
std
A handle to the standard error stream of a process.
๐sys/io re-exported from std::io
๐
A handle to the standard error stream of a process.
For more information, see the io::stderr method.
Note: Windows Portability Considerations
When operating in a console, the Windows implementation of this stream does not support non-UTF-8 byte sequences. Attempting to write bytes that are not valid UTF-8 will return an error.
In a process with a detached console, such as one using
#![windows_subsystem = "windows"], or in a child process spawned from such a process,
the contained handle will be null. In such cases, the standard libraryโs Read and
Write will do nothing and silently succeed. All other I/O operations, via the
standard library or via raw Windows API calls, will fail.
Implementations
Sourceimpl Stderr
impl Stderr
1.0.0 ยท Sourcepub fn lock(&self) -> StderrLock<'static> โ
pub fn lock(&self) -> StderrLock<'static> โ
Locks this handle to the standard error stream, returning a writable guard.
The lock is released when the returned lock goes out of scope. The
returned guard also implements the Write trait for writing data.
Examples
use std::io::{self, Write};
fn foo() -> io::Result<()> {
let stderr = io::stderr();
let mut handle = stderr.lock();
handle.write_all(b"hello world")?;
Ok(())
}Trait Implementations
1.63.0 ยท Sourceimpl AsFd for Stderr
impl AsFd for Stderr
Sourcefn as_fd(&self) -> BorrowedFd<'_>
fn as_fd(&self) -> BorrowedFd<'_>
1.70.0 ยท Sourceimpl IsTerminal for Stderr
impl IsTerminal for Stderr
Sourcefn is_terminal(&self) -> bool
fn is_terminal(&self) -> bool
true if the descriptor/handle refers to a terminal/tty. Read moreimpl RefUnwindSafe for Stderr
Sourceimpl StdioExt for Stderr
impl StdioExt for Stderr
Sourcefn set_fd<T>(&mut self, fd: T) -> Result<(), Error> โ
fn set_fd<T>(&mut self, fd: T) -> Result<(), Error> โ
stdio_swap)fd. Read moreSourceimpl TextOut for Stderr
Emits UTF-8 text to the process standard error stream.
impl TextOut for Stderr
Emits UTF-8 text to the process standard error stream.
Sourcefn write_text(&mut self, text: &str) -> Result<(), Self::Error> โ
fn write_text(&mut self, text: &str) -> Result<(), Self::Error> โ
text without appending a line ending.Sourcefn write_line(&mut self, text: &str) -> Result<(), Self::Error> โ
fn write_line(&mut self, text: &str) -> Result<(), Self::Error> โ
text followed by \n.impl UnwindSafe for Stderr
1.0.0 ยท Sourceimpl Write for Stderr
impl Write for Stderr
Sourcefn write(&mut self, buf: &[u8]) -> Result<usize, Error> โ
fn write(&mut self, buf: &[u8]) -> Result<usize, Error> โ
Sourcefn is_write_vectored(&self) -> bool
fn is_write_vectored(&self) -> bool
can_vector)Sourcefn flush(&mut self) -> Result<(), Error> โ
fn flush(&mut self) -> Result<(), Error> โ
Sourcefn write_all(&mut self, buf: &[u8]) -> Result<(), Error> โ
fn write_all(&mut self, buf: &[u8]) -> Result<(), Error> โ
Sourcefn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<(), Error> โ
fn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<(), Error> โ
write_all_vectored)1.48.0 ยท Sourceimpl Write for &Stderr
impl Write for &Stderr
Sourcefn write(&mut self, buf: &[u8]) -> Result<usize, Error> โ
fn write(&mut self, buf: &[u8]) -> Result<usize, Error> โ
Sourcefn is_write_vectored(&self) -> bool
fn is_write_vectored(&self) -> bool
can_vector)Sourcefn flush(&mut self) -> Result<(), Error> โ
fn flush(&mut self) -> Result<(), Error> โ
Sourcefn write_all(&mut self, buf: &[u8]) -> Result<(), Error> โ
fn write_all(&mut self, buf: &[u8]) -> Result<(), Error> โ
Sourcefn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<(), Error> โ
fn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<(), Error> โ
write_all_vectored)Auto Trait Implementations
impl Freeze for Stderr
impl Send for Stderr
impl Sync for Stderr
impl Unpin for Stderr
impl UnsafeUnpin for Stderr