pub struct TimeDelta { /* private fields */ }Expand description
Implementations
Sourceimpl TimeDelta
Additional APIs involving SystemInstant.
impl TimeDelta
Additional APIs involving SystemInstant.
Sourcepub fn after(&self, instant: SystemInstant) -> SystemInstant
Available on crate feature std only.
pub fn after(&self, instant: SystemInstant) -> SystemInstant
std only.Adds a TimeDelta to an instant, moving forward or backward in time.
Panics
Panics if the result is outside the valid range of SystemInstant.
Sourcepub fn checked_after(&self, instant: SystemInstant) -> Option<SystemInstant> โ
Available on crate feature std only.
pub fn checked_after(&self, instant: SystemInstant) -> Option<SystemInstant> โ
std only.Adds a TimeDelta to an instant
Returns None if the result is outside the valid range.
Sourceimpl TimeDelta
Basic methods
impl TimeDelta
Basic methods
Sourcepub const fn new(secs: i64, nanos: i32) -> TimeDelta
pub const fn new(secs: i64, nanos: i32) -> TimeDelta
Creates a new TimeDelta from the given number of whole seconds and additional nanoseconds.
If the absolute value of the nanoseconds is greater than or equal to 1 second, then the excess balances into the number of whole seconds.
Panics
When the absolute value of the nanoseconds is greater than or equal
to 1 second and the excess that carries over to the number of whole
seconds overflows i64.
This never panics when nanos is less than 1_000_000_000.
Sourcepub const fn from_secs(secs: i64) -> TimeDelta
pub const fn from_secs(secs: i64) -> TimeDelta
Creates a new TimeDelta from the given number of whole seconds.
Sourcepub const fn from_millis(millis: i64) -> TimeDelta
pub const fn from_millis(millis: i64) -> TimeDelta
Creates a new TimeDelta from the given number of whole milliseconds.
Note that since this accepts an i64, this method cannot be used
to construct the full range of possible time delta values. In
particular, TimeDelta::as_millis returns an i128, and this
may be a value that would otherwise overflow an i64.
Sourcepub const fn from_micros(micros: i64) -> TimeDelta
pub const fn from_micros(micros: i64) -> TimeDelta
Creates a new TimeDelta from the given number of whole microseconds.
Note that since this accepts an i64, this method cannot be used
to construct the full range of possible time delta values. In
particular, TimeDelta::as_micros returns an i128, and this
may be a value that would otherwise overflow an i64.
Sourcepub const fn from_nanos(nanos: i64) -> TimeDelta
pub const fn from_nanos(nanos: i64) -> TimeDelta
Creates a new TimeDelta from the given number of whole nanoseconds.
Note that since this accepts an i64, this method cannot be used
to construct the full range of possible time delta values. In
particular, TimeDelta::as_nanos returns an i128, which may
be a value that would otherwise overflow an i64.
Sourcepub const fn from_hours(hours: i64) -> TimeDelta
pub const fn from_hours(hours: i64) -> TimeDelta
Creates a new TimeDelta from the given number of hours.
Every hour is exactly 3,600 seconds.
Panics
Panics if the number of hours, after being converted to nanoseconds,
overflows the minimum or maximum TimeDelta values.
Sourcepub const fn from_mins(minutes: i64) -> TimeDelta
pub const fn from_mins(minutes: i64) -> TimeDelta
Creates a new TimeDelta from the given number of minutes.
Every minute is exactly 60 seconds.
Panics
Panics if the number of minutes, after being converted to nanoseconds,
overflows the minimum or maximum TimeDelta values.
Sourcepub const fn as_secs(&self) -> i64
pub const fn as_secs(&self) -> i64
Returns the number of whole seconds in this duration.
The value returned is negative when the duration is negative.
This does not include any fractional component corresponding to units
less than a second. To access those, use one of the subsec methods
such as TimeDelta::subsec_nanos.
Sourcepub const fn subsec_millis(&self) -> i32
pub const fn subsec_millis(&self) -> i32
Returns the fractional part of this duration in whole milliseconds.
The value returned is negative when the duration is negative. It is
guaranteed that the range of the value returned is in the inclusive
range -999..=999.
To get the length of the total duration represented in milliseconds,
use TimeDelta::as_millis.
Sourcepub const fn subsec_micros(&self) -> i32
pub const fn subsec_micros(&self) -> i32
Returns the fractional part of this duration in whole microseconds.
The value returned is negative when the duration is negative. It is
guaranteed that the range of the value returned is in the inclusive
range -999_999..=999_999.
To get the length of the total duration represented in microseconds,
use TimeDelta::as_micros.
Sourcepub const fn subsec_nanos(&self) -> i32
pub const fn subsec_nanos(&self) -> i32
Returns the fractional part of this duration in whole nanoseconds.
The value returned is negative when the duration is negative. It is
guaranteed that the range of the value returned is in the inclusive
range -999_999_999..=999_999_999.
To get the length of the total duration represented in nanoseconds,
use TimeDelta::as_nanos.
Sourcepub const fn as_millis(&self) -> i128
pub const fn as_millis(&self) -> i128
Returns the total duration in units of whole milliseconds.
The value returned is negative when the duration is negative.
To get only the fractional component of this duration in units of
whole milliseconds, use TimeDelta::subsec_millis.
Sourcepub const fn as_micros(&self) -> i128
pub const fn as_micros(&self) -> i128
Returns the total duration in units of whole microseconds.
The value returned is negative when the duration is negative.
To get only the fractional component of this duration in units of
whole microseconds, use TimeDelta::subsec_micros.
Sourcepub const fn as_nanos(&self) -> i128
pub const fn as_nanos(&self) -> i128
Returns the total duration in units of whole nanoseconds.
The value returned is negative when the duration is negative.
To get only the fractional component of this duration in units of
whole nanoseconds, use TimeDelta::subsec_nanos.
Sourceimpl TimeDelta
Additional methods not found in the standard library.
impl TimeDelta
Additional methods not found in the standard library.
In most cases, these APIs exist as a result of the fact that this duration is signed.
Sourcepub const fn as_hours(&self) -> i64
pub const fn as_hours(&self) -> i64
Returns the number of whole hours in this duration.
The value returned is negative when the duration is negative.
This does not include any fractional component corresponding to units less than an hour.
Sourcepub const fn as_mins(&self) -> i64
pub const fn as_mins(&self) -> i64
Returns the number of whole minutes in this duration.
The value returned is negative when the duration is negative.
This does not include any fractional component corresponding to units less than a minute.
Sourcepub const fn abs(self) -> TimeDelta
pub const fn abs(self) -> TimeDelta
Returns the absolute value of this time delta.
If this duration is positive, then this returns the original duration unchanged.
Panics
This panics when the seconds component of this time delta is equal to i64::MIN.
Sourcepub const fn neg_abs(self) -> TimeDelta
pub const fn neg_abs(self) -> TimeDelta
Returns the negative absolute value of this time delta.
If this duration is negative, then this returns the original duration unchanged.
Panics
This panics when the seconds component of this time delta is equal to i64::MIN.
Sourcepub const fn checked_neg(self) -> Option<TimeDelta> โ
pub const fn checked_neg(self) -> Option<TimeDelta> โ
Returns this duration with its sign flipped.
If this duration is zero, then this returns the duration unchanged.
This returns none if the negation does not exist. This occurs in
precisely the cases when TimeDelta::as_secs is equal to i64::MIN.
Sourcepub const fn signum(self) -> i8
pub const fn signum(self) -> i8
Returns a number that represents the sign of this duration.
- When
TimeDelta::is_zerois true, this returns0. - When
TimeDelta::is_positiveis true, this returns1. - When
TimeDelta::is_negativeis true, this returns-1.
The above cases are mutually exclusive.
Sourcepub const fn is_positive(&self) -> bool
pub const fn is_positive(&self) -> bool
Returns true when this duration is positive. That is, greater than TimeDelta::ZERO.
Sourcepub const fn is_negative(&self) -> bool
pub const fn is_negative(&self) -> bool
Returns true when this duration is negative. That is, less than TimeDelta::ZERO.
Sourceimpl TimeDelta
Operations.
impl TimeDelta
Operations.
Sourcepub const fn checked_add(self, rhs: TimeDelta) -> Option<TimeDelta> โ
pub const fn checked_add(self, rhs: TimeDelta) -> Option<TimeDelta> โ
Add two time deltas together. If overflow occurs, then None is returned.
Sourcepub const fn saturating_add(self, rhs: TimeDelta) -> TimeDelta
pub const fn saturating_add(self, rhs: TimeDelta) -> TimeDelta
Add two time deltas together. If overflow occurs, then arithmetic saturates.
Sourcepub const fn checked_sub(self, rhs: TimeDelta) -> Option<TimeDelta> โ
pub const fn checked_sub(self, rhs: TimeDelta) -> Option<TimeDelta> โ
Subtract one time delta from another. If overflow occurs, then None is returned.
Sourcepub const fn saturating_sub(self, rhs: TimeDelta) -> TimeDelta
pub const fn saturating_sub(self, rhs: TimeDelta) -> TimeDelta
Add two time deltas together. If overflow occurs, then arithmetic saturates.
Sourceimpl TimeDelta
Operations involving integers.
impl TimeDelta
Operations involving integers.
Sourcepub const fn checked_mul(self, rhs: i32) -> Option<TimeDelta> โ
pub const fn checked_mul(self, rhs: i32) -> Option<TimeDelta> โ
Multiply this time delta by an integer.
If the multiplication overflows, then None is returned.
Sourcepub const fn saturating_mul(self, rhs: i32) -> TimeDelta
pub const fn saturating_mul(self, rhs: i32) -> TimeDelta
Multiply this time delta by an integer.
If the multiplication overflows, then the result saturates to either the minimum or maximum duration depending on the sign of the product.
Sourceimpl TimeDelta
Operations involving floating-point numbers.
impl TimeDelta
Operations involving floating-point numbers.
Sourcepub const fn as_secs_f64(&self) -> f64
pub const fn as_secs_f64(&self) -> f64
Returns the number of seconds, with a possible fractional nanosecond component.
Sourcepub const fn as_secs_f32(&self) -> f32
pub const fn as_secs_f32(&self) -> f32
Returns the number of seconds, with a possible fractional nanosecond component.
Sourcepub const fn from_secs_f64(secs: f64) -> TimeDelta
pub const fn from_secs_f64(secs: f64) -> TimeDelta
Returns a time delta corresponding to the number of seconds.
The number given may have a fractional nanosecond component.
Panics
Panics if the given float overflows the minimum or maximum time delta values.
Sourcepub const fn from_secs_f32(secs: f32) -> TimeDelta
pub const fn from_secs_f32(secs: f32) -> TimeDelta
Returns a time delta corresponding to the number of seconds.
The number given may have a fractional nanosecond component.
Panics
Panics if the given float overflows the minimum or maximum time delta values.
Sourcepub const fn try_from_secs_f64(secs: f64) -> Result<TimeDelta, &'static str> โ
pub const fn try_from_secs_f64(secs: f64) -> Result<TimeDelta, &'static str> โ
Returns a time delta corresponding to the number of seconds.
The number given may have a fractional nanosecond component.
If the given float overflows the minimum or maximum time delta values, then an error is returned.
Sourcepub const fn try_from_secs_f32(secs: f32) -> Result<TimeDelta, &'static str> โ
pub const fn try_from_secs_f32(secs: f32) -> Result<TimeDelta, &'static str> โ
Returns a time delta corresponding to the number of seconds.
The number given may have a fractional nanosecond component.
Returns an error if the given float overflows the minimum or maximum time delta values.
Sourcepub const fn as_millis_f64(&self) -> f64
pub const fn as_millis_f64(&self) -> f64
Returns the number of milliseconds, with a possible fractional nanosecond component.
Sourcepub const fn as_millis_f32(&self) -> f32
pub const fn as_millis_f32(&self) -> f32
Returns the number of milliseconds, with a possible fractional nanosecond component.
Sourcepub const fn from_millis_f64(millis: f64) -> TimeDelta
pub const fn from_millis_f64(millis: f64) -> TimeDelta
Returns a time delta corresponding to the number of milliseconds.
The number given may have a fractional nanosecond component.
Panics
Panics if the given float overflows the minimum or maximum time delta values.
Sourcepub const fn try_from_millis_f64(millis: f64) -> Result<TimeDelta, &'static str> โ
pub const fn try_from_millis_f64(millis: f64) -> Result<TimeDelta, &'static str> โ
Returns a time delta corresponding to the number of milliseconds.
The number given may have a fractional nanosecond component.
Returns an error if the given float overflows the minimum or maximum time delta values.
Sourcepub const fn mul_f64(self, rhs: f64) -> TimeDelta
pub const fn mul_f64(self, rhs: f64) -> TimeDelta
Returns the result of multiplying this duration by the given 64-bit float.
Panics
This panics if the result is not finite or overflows a TimeDelta.
Sourcepub const fn mul_f32(self, rhs: f32) -> TimeDelta
pub const fn mul_f32(self, rhs: f32) -> TimeDelta
Returns the result of multiplying this duration by the given 32-bit float.
Panics
This panics if the result is not finite or overflows a TimeDelta.
Sourcepub const fn div_f64(self, rhs: f64) -> TimeDelta
pub const fn div_f64(self, rhs: f64) -> TimeDelta
Returns the result of dividing this duration by the given f64.
Panics
This panics if the result is not finite or overflows a TimeDelta.
Sourcepub const fn div_f32(self, rhs: f32) -> TimeDelta
pub const fn div_f32(self, rhs: f32) -> TimeDelta
Returns the result of dividing this duration by the given f32.
Panics
This panics if the result is not finite or overflows a TimeDelta.
Sourcepub const fn div_delta_f64(self, rhs: TimeDelta) -> f64
pub const fn div_delta_f64(self, rhs: TimeDelta) -> f64
Divides this time delta by another time delta.
Sourcepub const fn div_delta_f32(self, rhs: TimeDelta) -> f32
pub const fn div_delta_f32(self, rhs: TimeDelta) -> f32
Divides this time delta by another time delta.
Sourceimpl TimeDelta
impl TimeDelta
Sourcepub const fn from_duration(duration: Duration) -> Self
pub const fn from_duration(duration: Duration) -> Self
Converts a Duration to a TimeDelta.
Sourcepub const fn to_duration(&self) -> Option<Duration> โ
pub const fn to_duration(&self) -> Option<Duration> โ
Converts a TimeDelta to a Duration if it is non-negative.
Returns None if the TimeDelta is negative.
Sourcepub const fn abs_duration(self) -> Duration
pub const fn abs_duration(self) -> Duration
Returns the absolute value of this time delta as a Duration.
This method cannot panic because the absolute value of TimeDelta::MIN
is always representable in a Duration.
Sourcepub const fn checked_add_duration(&self, duration: Duration) -> Option<Self> โ
pub const fn checked_add_duration(&self, duration: Duration) -> Option<Self> โ
Adds a Duration to this TimeDelta.
Returns None if the result overflows.
Sourcepub const fn checked_sub_duration(&self, duration: Duration) -> Option<Self> โ
pub const fn checked_sub_duration(&self, duration: Duration) -> Option<Self> โ
Subtracts a Duration from this TimeDelta.
Returns None if the result underflows.
Sourceimpl TimeDelta
impl TimeDelta