pub type NonMaxU16 = NonValueU16<{ u16::MAX }>;
⅀ ⚗️ An unsigned integer that is known not to equal its MAX value.
MAX
📍 num/grain/niche
num/grain/niche
Unlike the NonValue* types in general, this type alias implements the Default and ConstInit traits.
NonValue*
Default
ConstInit
pub struct NonMaxU16(/* private fields */);
Makes use of the unsafe_niche feature if enabled.
unsafe_niche