pub type NonMinIsize = NonValueIsize<{ isize::MIN }>;
⅀ ⚗️ A signed integer that is known not to equal its MIN value.
MIN
📍 num/grain/niche
num/grain/niche
Unlike the NonValue* types in general, this type alias implements the Default and ConstInit traits.
NonValue*
Default
ConstInit
pub struct NonMinIsize(/* private fields */);
Makes use of the unsafe_niche feature if enabled.
unsafe_niche