pub type Region2<P, E> = Region<P, E, 2>;
📐 A 2-dimensional Region.
Region
📍 geom/metric
geom/metric
pub struct Region2<P, E> { pub pos: Position<P, 2>, pub ext: Extent<E, 2>, }
pos: Position<P, 2>
ext: Extent<E, 2>
Returns a copy of the first position dimension x.
x
Returns a copy of the second position dimension y.
y
Returns a copy of the first extent dimension width.
w
Returns a copy of the second extent dimension height.
h